##################################################
# ZipCodeResolver_services_server.py
#      Generated by ZSI.generate.wsdl2dispatch.ServiceModuleWriter
#
##################################################

from ZipCodeResolver_services import *
from ZSI.ServiceContainer import ServiceSOAPBinding

class ZipCodeResolver(ServiceSOAPBinding):
    soapAction = {}
    root = {}
    _wsdl = """<?xml version=\"1.0\" ?>
<definitions targetNamespace=\"http://webservices.eraserver.net/\" xmlns=\"http://schemas.xmlsoap.org/wsdl/\" xmlns:http=\"http://schemas.xmlsoap.org/wsdl/http/\" xmlns:mime=\"http://schemas.xmlsoap.org/wsdl/mime/\" xmlns:s=\"http://www.w3.org/2001/XMLSchema\" xmlns:s0=\"http://webservices.eraserver.net/\" xmlns:soap=\"http://schemas.xmlsoap.org/wsdl/soap/\" xmlns:soapenc=\"http://schemas.xmlsoap.org/soap/encoding/\" xmlns:tm=\"http://microsoft.com/wsdl/mime/textMatching/\">
  <types>
    <s:schema elementFormDefault=\"qualified\" targetNamespace=\"http://webservices.eraserver.net/\">
      <s:element name=\"FullZipCode\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"accessCode\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"address\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"city\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"state\" type=\"s:string\"/>
          </s:sequence>
        </s:complexType>
      </s:element>
      <s:element name=\"FullZipCodeResponse\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FullZipCodeResult\" type=\"s:string\"/>
          </s:sequence>
        </s:complexType>
      </s:element>
      <s:element name=\"ShortZipCode\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"accessCode\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"address\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"city\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"state\" type=\"s:string\"/>
          </s:sequence>
        </s:complexType>
      </s:element>
      <s:element name=\"ShortZipCodeResponse\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ShortZipCodeResult\" type=\"s:string\"/>
          </s:sequence>
        </s:complexType>
      </s:element>
      <s:element name=\"CorrectedAddressHtml\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"accessCode\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"address\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"city\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"state\" type=\"s:string\"/>
          </s:sequence>
        </s:complexType>
      </s:element>
      <s:element name=\"CorrectedAddressHtmlResponse\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CorrectedAddressHtmlResult\" type=\"s:string\"/>
          </s:sequence>
        </s:complexType>
      </s:element>
      <s:element name=\"CorrectedAddressXml\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"accessCode\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"address\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"city\" type=\"s:string\"/>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"state\" type=\"s:string\"/>
          </s:sequence>
        </s:complexType>
      </s:element>
      <s:element name=\"CorrectedAddressXmlResponse\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"CorrectedAddressXmlResult\" type=\"s0:USPSAddress\"/>
          </s:sequence>
        </s:complexType>
      </s:element>
      <s:complexType name=\"USPSAddress\">
        <s:sequence>
          <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Street\" type=\"s:string\"/>
          <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"City\" type=\"s:string\"/>
          <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"State\" type=\"s:string\"/>
          <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ShortZIP\" type=\"s:string\"/>
          <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FullZIP\" type=\"s:string\"/>
        </s:sequence>
      </s:complexType>
      <s:element name=\"VersionInfo\">
        <s:complexType/>
      </s:element>
      <s:element name=\"VersionInfoResponse\">
        <s:complexType>
          <s:sequence>
            <s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"VersionInfoResult\" type=\"s:string\"/>
          </s:sequence>
        </s:complexType>
      </s:element>
      <s:element name=\"string\" nillable=\"true\" type=\"s:string\"/>
      <s:element name=\"USPSAddress\" type=\"s0:USPSAddress\"/>
    </s:schema>
  </types>
  <message name=\"FullZipCodeSoapIn\">
    <part element=\"s0:FullZipCode\" name=\"parameters\"/>
  </message>
  <message name=\"FullZipCodeSoapOut\">
    <part element=\"s0:FullZipCodeResponse\" name=\"parameters\"/>
  </message>
  <message name=\"ShortZipCodeSoapIn\">
    <part element=\"s0:ShortZipCode\" name=\"parameters\"/>
  </message>
  <message name=\"ShortZipCodeSoapOut\">
    <part element=\"s0:ShortZipCodeResponse\" name=\"parameters\"/>
  </message>
  <message name=\"CorrectedAddressHtmlSoapIn\">
    <part element=\"s0:CorrectedAddressHtml\" name=\"parameters\"/>
  </message>
  <message name=\"CorrectedAddressHtmlSoapOut\">
    <part element=\"s0:CorrectedAddressHtmlResponse\" name=\"parameters\"/>
  </message>
  <message name=\"CorrectedAddressXmlSoapIn\">
    <part element=\"s0:CorrectedAddressXml\" name=\"parameters\"/>
  </message>
  <message name=\"CorrectedAddressXmlSoapOut\">
    <part element=\"s0:CorrectedAddressXmlResponse\" name=\"parameters\"/>
  </message>
  <message name=\"VersionInfoSoapIn\">
    <part element=\"s0:VersionInfo\" name=\"parameters\"/>
  </message>
  <message name=\"VersionInfoSoapOut\">
    <part element=\"s0:VersionInfoResponse\" name=\"parameters\"/>
  </message>
  <message name=\"FullZipCodeHttpGetIn\">
    <part name=\"accessCode\" type=\"s:string\"/>
    <part name=\"address\" type=\"s:string\"/>
    <part name=\"city\" type=\"s:string\"/>
    <part name=\"state\" type=\"s:string\"/>
  </message>
  <message name=\"FullZipCodeHttpGetOut\">
    <part element=\"s0:string\" name=\"Body\"/>
  </message>
  <message name=\"ShortZipCodeHttpGetIn\">
    <part name=\"accessCode\" type=\"s:string\"/>
    <part name=\"address\" type=\"s:string\"/>
    <part name=\"city\" type=\"s:string\"/>
    <part name=\"state\" type=\"s:string\"/>
  </message>
  <message name=\"ShortZipCodeHttpGetOut\">
    <part element=\"s0:string\" name=\"Body\"/>
  </message>
  <message name=\"CorrectedAddressHtmlHttpGetIn\">
    <part name=\"accessCode\" type=\"s:string\"/>
    <part name=\"address\" type=\"s:string\"/>
    <part name=\"city\" type=\"s:string\"/>
    <part name=\"state\" type=\"s:string\"/>
  </message>
  <message name=\"CorrectedAddressHtmlHttpGetOut\">
    <part element=\"s0:string\" name=\"Body\"/>
  </message>
  <message name=\"CorrectedAddressXmlHttpGetIn\">
    <part name=\"accessCode\" type=\"s:string\"/>
    <part name=\"address\" type=\"s:string\"/>
    <part name=\"city\" type=\"s:string\"/>
    <part name=\"state\" type=\"s:string\"/>
  </message>
  <message name=\"CorrectedAddressXmlHttpGetOut\">
    <part element=\"s0:USPSAddress\" name=\"Body\"/>
  </message>
  <message name=\"VersionInfoHttpGetIn\"/>
  <message name=\"VersionInfoHttpGetOut\">
    <part element=\"s0:string\" name=\"Body\"/>
  </message>
  <message name=\"FullZipCodeHttpPostIn\">
    <part name=\"accessCode\" type=\"s:string\"/>
    <part name=\"address\" type=\"s:string\"/>
    <part name=\"city\" type=\"s:string\"/>
    <part name=\"state\" type=\"s:string\"/>
  </message>
  <message name=\"FullZipCodeHttpPostOut\">
    <part element=\"s0:string\" name=\"Body\"/>
  </message>
  <message name=\"ShortZipCodeHttpPostIn\">
    <part name=\"accessCode\" type=\"s:string\"/>
    <part name=\"address\" type=\"s:string\"/>
    <part name=\"city\" type=\"s:string\"/>
    <part name=\"state\" type=\"s:string\"/>
  </message>
  <message name=\"ShortZipCodeHttpPostOut\">
    <part element=\"s0:string\" name=\"Body\"/>
  </message>
  <message name=\"CorrectedAddressHtmlHttpPostIn\">
    <part name=\"accessCode\" type=\"s:string\"/>
    <part name=\"address\" type=\"s:string\"/>
    <part name=\"city\" type=\"s:string\"/>
    <part name=\"state\" type=\"s:string\"/>
  </message>
  <message name=\"CorrectedAddressHtmlHttpPostOut\">
    <part element=\"s0:string\" name=\"Body\"/>
  </message>
  <message name=\"CorrectedAddressXmlHttpPostIn\">
    <part name=\"accessCode\" type=\"s:string\"/>
    <part name=\"address\" type=\"s:string\"/>
    <part name=\"city\" type=\"s:string\"/>
    <part name=\"state\" type=\"s:string\"/>
  </message>
  <message name=\"CorrectedAddressXmlHttpPostOut\">
    <part element=\"s0:USPSAddress\" name=\"Body\"/>
  </message>
  <message name=\"VersionInfoHttpPostIn\"/>
  <message name=\"VersionInfoHttpPostOut\">
    <part element=\"s0:string\" name=\"Body\"/>
  </message>
  <portType name=\"ZipCodeResolverSoap\">
    <operation name=\"FullZipCode\">
      <documentation>Given a valid accesscode, street address, city, and state, returns the ZIP code in NNNNN-NNNN format. If an error occurs, returns 00000-0000 instead. Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:FullZipCodeSoapIn\"/>
      <output message=\"s0:FullZipCodeSoapOut\"/>
    </operation>
    <operation name=\"ShortZipCode\">
      <documentation>Given a valid street address, city, and state, returns the ZIP code in NNNNN format. If an error occurs, returns 00000 instead. Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:ShortZipCodeSoapIn\"/>
      <output message=\"s0:ShortZipCodeSoapOut\"/>
    </operation>
    <operation name=\"CorrectedAddressHtml\">
      <documentation>Given a valid street address, city, and state, returns an HTML version of the USPS corrected address including the ZIP Code in NNNNN-NNNN format. If an error occurs, returns 'ERROR - unable to return corrected address'.  Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:CorrectedAddressHtmlSoapIn\"/>
      <output message=\"s0:CorrectedAddressHtmlSoapOut\"/>
    </operation>
    <operation name=\"CorrectedAddressXml\">
      <documentation>Given a valid street address, city, and state, returns an USPSADDRESS structure with STREET, CITY, STATE, and SHORTZIP and FULLZIP elements. If an error occurs all elements in the structure are empty.  Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:CorrectedAddressXmlSoapIn\"/>
      <output message=\"s0:CorrectedAddressXmlSoapOut\"/>
    </operation>
    <operation name=\"VersionInfo\">
      <documentation>Returns the web service name, current version, date and copyright information.</documentation>
      <input message=\"s0:VersionInfoSoapIn\"/>
      <output message=\"s0:VersionInfoSoapOut\"/>
    </operation>
  </portType>
  <portType name=\"ZipCodeResolverHttpGet\">
    <operation name=\"FullZipCode\">
      <documentation>Given a valid accesscode, street address, city, and state, returns the ZIP code in NNNNN-NNNN format. If an error occurs, returns 00000-0000 instead. Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:FullZipCodeHttpGetIn\"/>
      <output message=\"s0:FullZipCodeHttpGetOut\"/>
    </operation>
    <operation name=\"ShortZipCode\">
      <documentation>Given a valid street address, city, and state, returns the ZIP code in NNNNN format. If an error occurs, returns 00000 instead. Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:ShortZipCodeHttpGetIn\"/>
      <output message=\"s0:ShortZipCodeHttpGetOut\"/>
    </operation>
    <operation name=\"CorrectedAddressHtml\">
      <documentation>Given a valid street address, city, and state, returns an HTML version of the USPS corrected address including the ZIP Code in NNNNN-NNNN format. If an error occurs, returns 'ERROR - unable to return corrected address'.  Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:CorrectedAddressHtmlHttpGetIn\"/>
      <output message=\"s0:CorrectedAddressHtmlHttpGetOut\"/>
    </operation>
    <operation name=\"CorrectedAddressXml\">
      <documentation>Given a valid street address, city, and state, returns an USPSADDRESS structure with STREET, CITY, STATE, and SHORTZIP and FULLZIP elements. If an error occurs all elements in the structure are empty.  Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:CorrectedAddressXmlHttpGetIn\"/>
      <output message=\"s0:CorrectedAddressXmlHttpGetOut\"/>
    </operation>
    <operation name=\"VersionInfo\">
      <documentation>Returns the web service name, current version, date and copyright information.</documentation>
      <input message=\"s0:VersionInfoHttpGetIn\"/>
      <output message=\"s0:VersionInfoHttpGetOut\"/>
    </operation>
  </portType>
  <portType name=\"ZipCodeResolverHttpPost\">
    <operation name=\"FullZipCode\">
      <documentation>Given a valid accesscode, street address, city, and state, returns the ZIP code in NNNNN-NNNN format. If an error occurs, returns 00000-0000 instead. Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:FullZipCodeHttpPostIn\"/>
      <output message=\"s0:FullZipCodeHttpPostOut\"/>
    </operation>
    <operation name=\"ShortZipCode\">
      <documentation>Given a valid street address, city, and state, returns the ZIP code in NNNNN format. If an error occurs, returns 00000 instead. Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:ShortZipCodeHttpPostIn\"/>
      <output message=\"s0:ShortZipCodeHttpPostOut\"/>
    </operation>
    <operation name=\"CorrectedAddressHtml\">
      <documentation>Given a valid street address, city, and state, returns an HTML version of the USPS corrected address including the ZIP Code in NNNNN-NNNN format. If an error occurs, returns 'ERROR - unable to return corrected address'.  Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:CorrectedAddressHtmlHttpPostIn\"/>
      <output message=\"s0:CorrectedAddressHtmlHttpPostOut\"/>
    </operation>
    <operation name=\"CorrectedAddressXml\">
      <documentation>Given a valid street address, city, and state, returns an USPSADDRESS structure with STREET, CITY, STATE, and SHORTZIP and FULLZIP elements. If an error occurs all elements in the structure are empty.  Use accessCode of '0' or '9999' for testing.</documentation>
      <input message=\"s0:CorrectedAddressXmlHttpPostIn\"/>
      <output message=\"s0:CorrectedAddressXmlHttpPostOut\"/>
    </operation>
    <operation name=\"VersionInfo\">
      <documentation>Returns the web service name, current version, date and copyright information.</documentation>
      <input message=\"s0:VersionInfoHttpPostIn\"/>
      <output message=\"s0:VersionInfoHttpPostOut\"/>
    </operation>
  </portType>
  <binding name=\"ZipCodeResolverSoap\" type=\"s0:ZipCodeResolverSoap\">
    <soap:binding style=\"document\" transport=\"http://schemas.xmlsoap.org/soap/http\"/>
    <operation name=\"FullZipCode\">
      <soap:operation soapAction=\"http://webservices.eraserver.net/FullZipCode\" style=\"document\"/>
      <input>
        <soap:body use=\"literal\"/>
      </input>
      <output>
        <soap:body use=\"literal\"/>
      </output>
    </operation>
    <operation name=\"ShortZipCode\">
      <soap:operation soapAction=\"http://webservices.eraserver.net/ShortZipCode\" style=\"document\"/>
      <input>
        <soap:body use=\"literal\"/>
      </input>
      <output>
        <soap:body use=\"literal\"/>
      </output>
    </operation>
    <operation name=\"CorrectedAddressHtml\">
      <soap:operation soapAction=\"http://webservices.eraserver.net/CorrectedAddressHtml\" style=\"document\"/>
      <input>
        <soap:body use=\"literal\"/>
      </input>
      <output>
        <soap:body use=\"literal\"/>
      </output>
    </operation>
    <operation name=\"CorrectedAddressXml\">
      <soap:operation soapAction=\"http://webservices.eraserver.net/CorrectedAddressXml\" style=\"document\"/>
      <input>
        <soap:body use=\"literal\"/>
      </input>
      <output>
        <soap:body use=\"literal\"/>
      </output>
    </operation>
    <operation name=\"VersionInfo\">
      <soap:operation soapAction=\"http://webservices.eraserver.net/VersionInfo\" style=\"document\"/>
      <input>
        <soap:body use=\"literal\"/>
      </input>
      <output>
        <soap:body use=\"literal\"/>
      </output>
    </operation>
  </binding>
  <binding name=\"ZipCodeResolverHttpGet\" type=\"s0:ZipCodeResolverHttpGet\">
    <http:binding verb=\"GET\"/>
    <operation name=\"FullZipCode\">
      <http:operation location=\"/FullZipCode\"/>
      <input>
        <http:urlEncoded/>
      </input>
      <output>
        <mime:mimeXml part=\"Body\"/>
      </output>
    </operation>
    <operation name=\"ShortZipCode\">
      <http:operation location=\"/ShortZipCode\"/>
      <input>
        <http:urlEncoded/>
      </input>
      <output>
        <mime:mimeXml part=\"Body\"/>
      </output>
    </operation>
    <operation name=\"CorrectedAddressHtml\">
      <http:operation location=\"/CorrectedAddressHtml\"/>
      <input>
        <http:urlEncoded/>
      </input>
      <output>
        <mime:mimeXml part=\"Body\"/>
      </output>
    </operation>
    <operation name=\"CorrectedAddressXml\">
      <http:operation location=\"/CorrectedAddressXml\"/>
      <input>
        <http:urlEncoded/>
      </input>
      <output>
        <mime:mimeXml part=\"Body\"/>
      </output>
    </operation>
    <operation name=\"VersionInfo\">
      <http:operation location=\"/VersionInfo\"/>
      <input>
        <http:urlEncoded/>
      </input>
      <output>
        <mime:mimeXml part=\"Body\"/>
      </output>
    </operation>
  </binding>
  <binding name=\"ZipCodeResolverHttpPost\" type=\"s0:ZipCodeResolverHttpPost\">
    <http:binding verb=\"POST\"/>
    <operation name=\"FullZipCode\">
      <http:operation location=\"/FullZipCode\"/>
      <input>
        <mime:content type=\"application/x-www-form-urlencoded\"/>
      </input>
      <output>
        <mime:mimeXml part=\"Body\"/>
      </output>
    </operation>
    <operation name=\"ShortZipCode\">
      <http:operation location=\"/ShortZipCode\"/>
      <input>
        <mime:content type=\"application/x-www-form-urlencoded\"/>
      </input>
      <output>
        <mime:mimeXml part=\"Body\"/>
      </output>
    </operation>
    <operation name=\"CorrectedAddressHtml\">
      <http:operation location=\"/CorrectedAddressHtml\"/>
      <input>
        <mime:content type=\"application/x-www-form-urlencoded\"/>
      </input>
      <output>
        <mime:mimeXml part=\"Body\"/>
      </output>
    </operation>
    <operation name=\"CorrectedAddressXml\">
      <http:operation location=\"/CorrectedAddressXml\"/>
      <input>
        <mime:content type=\"application/x-www-form-urlencoded\"/>
      </input>
      <output>
        <mime:mimeXml part=\"Body\"/>
      </output>
    </operation>
    <operation name=\"VersionInfo\">
      <http:operation location=\"/VersionInfo\"/>
      <input>
        <mime:content type=\"application/x-www-form-urlencoded\"/>
      </input>
      <output>
        <mime:mimeXml part=\"Body\"/>
      </output>
    </operation>
  </binding>
  <service name=\"ZipCodeResolver\">
    <documentation>Given a valid street address, city, and state, this service returns the proper ZIP code, ZIP code+4, or USPS corrected address. NOTE: This service is meant for non-commercial, personal use only.</documentation>
    <port binding=\"s0:ZipCodeResolverSoap\" name=\"ZipCodeResolverSoap\">
      <soap:address location=\"http://webservices.eraserver.net/zipcoderesolver/zipcoderesolver.asmx\"/>
    </port>
    <port binding=\"s0:ZipCodeResolverHttpGet\" name=\"ZipCodeResolverHttpGet\">
      <http:address location=\"http://webservices.eraserver.net/zipcoderesolver/zipcoderesolver.asmx\"/>
    </port>
    <port binding=\"s0:ZipCodeResolverHttpPost\" name=\"ZipCodeResolverHttpPost\">
      <http:address location=\"http://webservices.eraserver.net/zipcoderesolver/zipcoderesolver.asmx\"/>
    </port>
  </service>
</definitions>"""

    def __init__(self, post='/zipcoderesolver/zipcoderesolver.asmx', **kw):
        ServiceSOAPBinding.__init__(self, post)

    def soap_FullZipCode(self, ps):
        self.request = ps.Parse(FullZipCodeSoapIn.typecode)
        return FullZipCodeSoapOut()

    soapAction['http://webservices.eraserver.net/FullZipCode'] = 'soap_FullZipCode'
    root[(FullZipCodeSoapIn.typecode.nspname,FullZipCodeSoapIn.typecode.pname)] = 'soap_FullZipCode'

    def soap_ShortZipCode(self, ps):
        self.request = ps.Parse(ShortZipCodeSoapIn.typecode)
        return ShortZipCodeSoapOut()

    soapAction['http://webservices.eraserver.net/ShortZipCode'] = 'soap_ShortZipCode'
    root[(ShortZipCodeSoapIn.typecode.nspname,ShortZipCodeSoapIn.typecode.pname)] = 'soap_ShortZipCode'

    def soap_CorrectedAddressHtml(self, ps):
        self.request = ps.Parse(CorrectedAddressHtmlSoapIn.typecode)
        return CorrectedAddressHtmlSoapOut()

    soapAction['http://webservices.eraserver.net/CorrectedAddressHtml'] = 'soap_CorrectedAddressHtml'
    root[(CorrectedAddressHtmlSoapIn.typecode.nspname,CorrectedAddressHtmlSoapIn.typecode.pname)] = 'soap_CorrectedAddressHtml'

    def soap_CorrectedAddressXml(self, ps):
        self.request = ps.Parse(CorrectedAddressXmlSoapIn.typecode)
        return CorrectedAddressXmlSoapOut()

    soapAction['http://webservices.eraserver.net/CorrectedAddressXml'] = 'soap_CorrectedAddressXml'
    root[(CorrectedAddressXmlSoapIn.typecode.nspname,CorrectedAddressXmlSoapIn.typecode.pname)] = 'soap_CorrectedAddressXml'

    def soap_VersionInfo(self, ps):
        self.request = ps.Parse(VersionInfoSoapIn.typecode)
        return VersionInfoSoapOut()

    soapAction['http://webservices.eraserver.net/VersionInfo'] = 'soap_VersionInfo'
    root[(VersionInfoSoapIn.typecode.nspname,VersionInfoSoapIn.typecode.pname)] = 'soap_VersionInfo'

    def soap_FullZipCode(self, ps):
        self.request = ps.Parse(FullZipCodeHttpGetIn.typecode)
        return FullZipCodeHttpGetOut()

    soapAction[''] = 'soap_FullZipCode'
    root[(FullZipCodeHttpGetIn.typecode.nspname,FullZipCodeHttpGetIn.typecode.pname)] = 'soap_FullZipCode'

    def soap_ShortZipCode(self, ps):
        self.request = ps.Parse(ShortZipCodeHttpGetIn.typecode)
        return ShortZipCodeHttpGetOut()

    soapAction[''] = 'soap_ShortZipCode'
    root[(ShortZipCodeHttpGetIn.typecode.nspname,ShortZipCodeHttpGetIn.typecode.pname)] = 'soap_ShortZipCode'

    def soap_CorrectedAddressHtml(self, ps):
        self.request = ps.Parse(CorrectedAddressHtmlHttpGetIn.typecode)
        return CorrectedAddressHtmlHttpGetOut()

    soapAction[''] = 'soap_CorrectedAddressHtml'
    root[(CorrectedAddressHtmlHttpGetIn.typecode.nspname,CorrectedAddressHtmlHttpGetIn.typecode.pname)] = 'soap_CorrectedAddressHtml'

    def soap_CorrectedAddressXml(self, ps):
        self.request = ps.Parse(CorrectedAddressXmlHttpGetIn.typecode)
        return CorrectedAddressXmlHttpGetOut()

    soapAction[''] = 'soap_CorrectedAddressXml'
    root[(CorrectedAddressXmlHttpGetIn.typecode.nspname,CorrectedAddressXmlHttpGetIn.typecode.pname)] = 'soap_CorrectedAddressXml'

    def soap_VersionInfo(self, ps):
        self.request = ps.Parse(VersionInfoHttpGetIn.typecode)
        return VersionInfoHttpGetOut()

    soapAction[''] = 'soap_VersionInfo'
    root[(VersionInfoHttpGetIn.typecode.nspname,VersionInfoHttpGetIn.typecode.pname)] = 'soap_VersionInfo'

    def soap_FullZipCode(self, ps):
        self.request = ps.Parse(FullZipCodeHttpPostIn.typecode)
        return FullZipCodeHttpPostOut()

    soapAction[''] = 'soap_FullZipCode'
    root[(FullZipCodeHttpPostIn.typecode.nspname,FullZipCodeHttpPostIn.typecode.pname)] = 'soap_FullZipCode'

    def soap_ShortZipCode(self, ps):
        self.request = ps.Parse(ShortZipCodeHttpPostIn.typecode)
        return ShortZipCodeHttpPostOut()

    soapAction[''] = 'soap_ShortZipCode'
    root[(ShortZipCodeHttpPostIn.typecode.nspname,ShortZipCodeHttpPostIn.typecode.pname)] = 'soap_ShortZipCode'

    def soap_CorrectedAddressHtml(self, ps):
        self.request = ps.Parse(CorrectedAddressHtmlHttpPostIn.typecode)
        return CorrectedAddressHtmlHttpPostOut()

    soapAction[''] = 'soap_CorrectedAddressHtml'
    root[(CorrectedAddressHtmlHttpPostIn.typecode.nspname,CorrectedAddressHtmlHttpPostIn.typecode.pname)] = 'soap_CorrectedAddressHtml'

    def soap_CorrectedAddressXml(self, ps):
        self.request = ps.Parse(CorrectedAddressXmlHttpPostIn.typecode)
        return CorrectedAddressXmlHttpPostOut()

    soapAction[''] = 'soap_CorrectedAddressXml'
    root[(CorrectedAddressXmlHttpPostIn.typecode.nspname,CorrectedAddressXmlHttpPostIn.typecode.pname)] = 'soap_CorrectedAddressXml'

    def soap_VersionInfo(self, ps):
        self.request = ps.Parse(VersionInfoHttpPostIn.typecode)
        return VersionInfoHttpPostOut()

    soapAction[''] = 'soap_VersionInfo'
    root[(VersionInfoHttpPostIn.typecode.nspname,VersionInfoHttpPostIn.typecode.pname)] = 'soap_VersionInfo'

