##################################################
# CommonService_services_server.py
#      Generated by ZSI.generate.wsdl2dispatch.ServiceModuleWriter
#
##################################################

from CommonService_services import *
from ZSI.ServiceContainer import ServiceSOAPBinding

class RouteService(ServiceSOAPBinding):
    soapAction = {}
    root = {}
    _wsdl = """<?xml version=\"1.0\" ?>
<wsdl:definitions targetNamespace=\"http://s.mappoint.net/mappoint-30/\" xmlns:http=\"http://schemas.xmlsoap.org/wsdl/http/\" xmlns:mime=\"http://schemas.xmlsoap.org/wsdl/mime/\" xmlns:s=\"http://www.w3.org/2001/XMLSchema\" xmlns:soap=\"http://schemas.xmlsoap.org/wsdl/soap/\" xmlns:soapenc=\"http://schemas.xmlsoap.org/soap/encoding/\" xmlns:tm=\"http://microsoft.com/wsdl/mime/textMatching/\" xmlns:tns=\"http://s.mappoint.net/mappoint-30/\" xmlns:wsdl=\"http://schemas.xmlsoap.org/wsdl/\">
	<wsdl:types>
		<s:schema elementFormDefault=\"qualified\" targetNamespace=\"http://s.mappoint.net/mappoint-30/\">
			<s:element name=\"GetVersionInfo\">
				<s:complexType/>
			</s:element>
			<s:element name=\"GetVersionInfoResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetVersionInfoResult\" type=\"tns:ArrayOfVersionInfo\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfVersionInfo\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"VersionInfo\" nillable=\"true\" type=\"tns:VersionInfo\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"VersionInfo\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Component\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Version\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"CustomerInfoHeader\" type=\"tns:CustomerInfoHeader\"/>
			<s:complexType name=\"CustomerInfoHeader\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"CustomLogEntry\" type=\"s:short\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"UserInfoHeader\" type=\"tns:UserInfoHeader\"/>
			<s:complexType name=\"UserInfoHeader\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Culture\" type=\"tns:CultureInfo\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"DefaultDistanceUnit\" type=\"tns:DistanceUnit\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Context\" type=\"tns:CountryRegionContext\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"CultureInfo\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Lcid\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"DistanceUnit\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Kilometer\"/>
					<s:enumeration value=\"Mile\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"CountryRegionContext\">
				<s:sequence>
					<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Iso2\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetCountryRegionInfo\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"entityIDs\" type=\"tns:ArrayOfInt\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfInt\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"int\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetCountryRegionInfoResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetCountryRegionInfoResult\" type=\"tns:ArrayOfCountryRegionInfo\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfCountryRegionInfo\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"CountryRegionInfo\" nillable=\"true\" type=\"tns:CountryRegionInfo\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"CountryRegionInfo\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"EntityID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Iso2\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Iso3\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FriendlyName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"OfficialName\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"LatLong\">
				<s:sequence>
					<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Latitude\" type=\"s:double\"/>
					<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Longitude\" type=\"s:double\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetEntityTypes\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"dataSourceName\" type=\"s:string\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetEntityTypesResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetEntityTypesResult\" type=\"tns:ArrayOfEntityType\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfEntityType\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"EntityType\" nillable=\"true\" type=\"tns:EntityType\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"EntityType\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DisplayName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ParentName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Definition\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Properties\" type=\"tns:ArrayOfEntityProperty\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfEntityProperty\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Property\" nillable=\"true\" type=\"tns:EntityProperty\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"EntityProperty\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DisplayName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataType\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetDataSourceInfo\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"dataSourceNames\" type=\"tns:ArrayOfString\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfString\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"string\" nillable=\"true\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetDataSourceInfoResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetDataSourceInfoResult\" type=\"tns:ArrayOfDataSource\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfDataSource\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"DataSource\" nillable=\"true\" type=\"tns:DataSource\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"DataSource\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Version\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Description\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Capability\" type=\"tns:DataSourceCapability\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityExtent\" type=\"tns:ArrayOfInt\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"DataSourceCapability\">
				<s:list>
					<s:simpleType>
						<s:restriction base=\"s:string\">
							<s:enumeration value=\"CanDrawMaps\"/>
							<s:enumeration value=\"CanFindPlaces\"/>
							<s:enumeration value=\"CanFindNearby\"/>
							<s:enumeration value=\"CanRoute\"/>
							<s:enumeration value=\"CanFindAddress\"/>
							<s:enumeration value=\"HasIcons\"/>
							<s:enumeration value=\"DataServiceQuery\"/>
						</s:restriction>
					</s:simpleType>
				</s:list>
			</s:simpleType>
			<s:element name=\"GetGreatCircleDistances\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"latLongs\" type=\"tns:ArrayOfLatLong\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfLatLong\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"LatLong\" nillable=\"true\" type=\"tns:LatLong\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetGreatCircleDistancesResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetGreatCircleDistancesResult\" type=\"tns:ArrayOfDouble\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfDouble\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"double\" type=\"s:double\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"Find\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"InputPlace\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityTypeNames\" type=\"tns:ArrayOfString\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"FindOptions\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Range\" type=\"tns:FindRange\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"SearchContext\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ResultMask\" type=\"tns:FindResultMask\"/>
					<s:element default=\"0.85\" maxOccurs=\"1\" minOccurs=\"0\" name=\"ThresholdScore\" type=\"s:double\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"FindRange\">
				<s:sequence>
					<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"StartIndex\" type=\"s:int\"/>
					<s:element default=\"25\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Count\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"FindResultMask\">
				<s:list>
					<s:simpleType>
						<s:restriction base=\"s:string\">
							<s:enumeration value=\"LatLongFlag\"/>
							<s:enumeration value=\"EntityFlag\"/>
							<s:enumeration value=\"AddressFlag\"/>
							<s:enumeration value=\"BestMapViewFlag\"/>
							<s:enumeration value=\"MatchDetailsFlag\"/>
						</s:restriction>
					</s:simpleType>
				</s:list>
			</s:simpleType>
			<s:element name=\"FindResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindResults\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"NumberFound\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"StartIndex\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Results\" type=\"tns:ArrayOfFindResult\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"TopScore\" type=\"s:double\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfFindResult\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"FindResult\" nillable=\"true\" type=\"tns:FindResult\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"FindResult\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Score\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FoundLocation\" type=\"tns:Location\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Location\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Entity\" type=\"tns:Entity\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Address\" type=\"tns:Address\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"BestMapView\" type=\"tns:MapViewRepresentations\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Entity\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DisplayName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"TypeName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Properties\" type=\"tns:ArrayOfEntityPropertyValue\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfEntityPropertyValue\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Property\" nillable=\"true\" type=\"tns:EntityPropertyValue\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"EntityPropertyValue\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Value\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Address\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"AddressLine\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PrimaryCity\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"SecondaryCity\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Subdivision\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PostalCode\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CountryRegion\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FormattedAddress\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"MapViewRepresentations\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ByScale\" type=\"tns:ViewByScale\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ByHeightWidth\" type=\"tns:ViewByHeightWidth\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ByBoundingRectangle\" type=\"tns:ViewByBoundingRectangle\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ViewByScale\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:MapView\">
						<s:sequence>
							<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"MapScale\" type=\"s:double\"/>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CenterPoint\" type=\"tns:LatLong\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:complexType abstract=\"true\" name=\"MapView\"/>
			<s:complexType name=\"ViewByBoundingLocations\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:MapView\">
						<s:sequence>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Locations\" type=\"tns:ArrayOfLocation\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:complexType name=\"ArrayOfLocation\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Location\" nillable=\"true\" type=\"tns:Location\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ViewByHeightWidth\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:MapView\">
						<s:sequence>
							<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Height\" type=\"s:double\"/>
							<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Width\" type=\"s:double\"/>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CenterPoint\" type=\"tns:LatLong\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:complexType name=\"ViewByBoundingRectangle\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:MapView\">
						<s:sequence>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"BoundingRectangle\" type=\"tns:LatLongRectangle\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:complexType name=\"LatLongRectangle\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Southwest\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Northeast\" type=\"tns:LatLong\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"MapPointConstants\">
				<s:sequence>
					<s:element default=\"6378.2\" maxOccurs=\"1\" minOccurs=\"0\" name=\"EarthRadiusInKilometers\" type=\"s:double\"/>
					<s:element default=\"3.1415926535897931\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Pi\" type=\"s:double\"/>
					<s:element default=\"0.017453292519943295\" maxOccurs=\"1\" minOccurs=\"0\" name=\"RadiansPerDegree\" type=\"s:double\"/>
					<s:element default=\"57.295779513082323\" maxOccurs=\"1\" minOccurs=\"0\" name=\"DegreesPerRadian\" type=\"s:double\"/>
					<s:element default=\"0.621371192237334\" maxOccurs=\"1\" minOccurs=\"0\" name=\"MilesPerKilometer\" type=\"s:double\"/>
					<s:element default=\"1.609344\" maxOccurs=\"1\" minOccurs=\"0\" name=\"KilometersPerMile\" type=\"s:double\"/>
					<s:element default=\"0.0003048\" maxOccurs=\"1\" minOccurs=\"0\" name=\"KilometersPerFoot\" type=\"s:double\"/>
					<s:element default=\"3280.8398950131232\" maxOccurs=\"1\" minOccurs=\"0\" name=\"FeetPerKilometer\" type=\"s:double\"/>
					<s:element default=\"0.85\" maxOccurs=\"1\" minOccurs=\"0\" name=\"FindScoreThreshold\" type=\"s:double\"/>
					<s:element default=\"96\" maxOccurs=\"1\" minOccurs=\"0\" name=\"AssumedDpi\" type=\"s:int\"/>
					<s:element default=\"3.280839895013123\" maxOccurs=\"1\" minOccurs=\"0\" name=\"FeetPerMeter\" type=\"s:double\"/>
					<s:element default=\"0.3048\" maxOccurs=\"1\" minOccurs=\"0\" name=\"MetersPerFoot\" type=\"s:double\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType abstract=\"true\" name=\"SpatialFilter\"/>
			<s:complexType name=\"LatLongSpatialFilter\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:SpatialFilter\">
						<s:sequence>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:complexType name=\"LatLongRectangleSpatialFilter\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:SpatialFilter\">
						<s:sequence>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"BoundingRectangle\" type=\"tns:LatLongRectangle\"/>
							<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"PolygonRectangleRelation\" type=\"tns:SpatialRelation\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:simpleType name=\"SpatialRelation\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"WithinArea\"/>
					<s:enumeration value=\"TouchesArea\"/>
				</s:restriction>
			</s:simpleType>
			<s:element name=\"CustomerInfoFindHeader\" type=\"tns:CustomerInfoFindHeader\"/>
			<s:complexType name=\"CustomerInfoFindHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:CustomerInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"UserInfoFindHeader\" type=\"tns:UserInfoFindHeader\"/>
			<s:complexType name=\"UserInfoFindHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:UserInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"FindAddress\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindAddressSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindAddressSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"InputAddress\" type=\"tns:Address\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindAddressResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindAddressResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"ParseAddress\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"inputAddress\" type=\"s:string\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"countryRegion\" type=\"s:string\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"ParseAddressResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ParseAddressResult\" type=\"tns:Address\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetLocationInfo\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"location\" type=\"tns:LatLong\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"dataSourceName\" type=\"s:string\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"options\" type=\"tns:GetInfoOptions\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"GetInfoOptions\">
				<s:sequence>
					<s:element default=\"true\" maxOccurs=\"1\" minOccurs=\"0\" name=\"IncludeAddresses\" type=\"s:boolean\"/>
					<s:element default=\"true\" maxOccurs=\"1\" minOccurs=\"0\" name=\"IncludeAllEntityTypes\" type=\"s:boolean\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityTypesToReturn\" type=\"tns:ArrayOfString\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetLocationInfoResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetLocationInfoResult\" type=\"tns:ArrayOfLocation\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"FindNearby\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindNearbySpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindNearbySpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Distance\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Filter\" type=\"tns:FindFilter\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"FindFilter\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityTypeName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PropertyNames\" type=\"tns:ArrayOfString\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"WhereClause\" type=\"tns:WhereClause\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"SortProperties\" type=\"tns:ArrayOfSortProperty\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Expression\" type=\"tns:FilterExpression\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"WhereClause\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"SearchProperties\" type=\"tns:ArrayOfEntityPropertyValue\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"SearchOperator\" type=\"tns:SearchOperatorFlag\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"SearchOperatorFlag\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"And\"/>
					<s:enumeration value=\"Or\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"ArrayOfSortProperty\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"SortProperty\" nillable=\"true\" type=\"tns:SortProperty\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"SortProperty\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PropertyName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Direction\" type=\"tns:SortDirection\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"SortDirection\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Ascending\"/>
					<s:enumeration value=\"Descending\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"FilterExpression\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Text\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Parameters\" type=\"tns:ArrayOfAnyType\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfAnyType\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"anyType\" nillable=\"true\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindNearbyResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindNearbyResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"FindByProperty\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindByPropertySpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindByPropertySpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Filter\" type=\"tns:FindFilter\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindByPropertyResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindByPropertyResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"FindByID\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindByIDSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindByIDSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Filter\" type=\"tns:FindFilter\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityIDs\" type=\"tns:ArrayOfInt\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindByIDResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindByIDResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"FindNearRoute\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindNearRouteSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindNearRouteSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Distance\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Filter\" type=\"tns:FindFilter\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Route\" type=\"tns:Route\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Route\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Specification\" type=\"tns:RouteSpecification\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Itinerary\" type=\"tns:RouteItinerary\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculatedRepresentation\" type=\"tns:CalculatedRouteRepresentation\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"RouteSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Segments\" type=\"tns:ArrayOfSegmentSpecification\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ResultMask\" type=\"tns:RouteResultMask\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DriverProfile\" type=\"tns:DriverProfile\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfSegmentSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"SegmentSpecification\" nillable=\"true\" type=\"tns:SegmentSpecification\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"SegmentSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Waypoint\" type=\"tns:Waypoint\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:SegmentOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Waypoint\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Location\" type=\"tns:Location\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Snap\" type=\"tns:SnapType\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculatedLocation\" type=\"tns:Location\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"SnapType\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Normal\"/>
					<s:enumeration value=\"City\"/>
					<s:enumeration value=\"NearestRoad\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"SegmentOptions\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Preference\" type=\"tns:SegmentPreference\"/>
					<s:element default=\"true\" maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculateSegmentMapView\" type=\"s:boolean\"/>
					<s:element default=\"true\" maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculateDirectionMapView\" type=\"s:boolean\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"SegmentPreference\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Quickest\"/>
					<s:enumeration value=\"Shortest\"/>
				</s:restriction>
			</s:simpleType>
			<s:simpleType name=\"RouteResultMask\">
				<s:list>
					<s:simpleType>
						<s:restriction base=\"s:string\">
							<s:enumeration value=\"Itinerary\"/>
							<s:enumeration value=\"CalculatedRouteRepresentation\"/>
						</s:restriction>
					</s:simpleType>
				</s:list>
			</s:simpleType>
			<s:complexType name=\"DriverProfile\">
				<s:sequence>
					<s:element default=\"-1\" maxOccurs=\"1\" minOccurs=\"0\" name=\"DayStartTime\" type=\"s:int\"/>
					<s:element default=\"-1\" maxOccurs=\"1\" minOccurs=\"0\" name=\"DayEndTime\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"RouteItinerary\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Segments\" type=\"tns:ArrayOfSegment\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"TripTime\" type=\"s:long\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"DrivingTime\" type=\"s:long\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Distance\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"View\" type=\"tns:MapViewRepresentations\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfSegment\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Segment\" nillable=\"true\" type=\"tns:Segment\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Segment\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Waypoint\" type=\"tns:Waypoint\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Directions\" type=\"tns:ArrayOfDirection\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"TripTime\" type=\"s:long\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"DrivingTime\" type=\"s:long\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Distance\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"View\" type=\"tns:MapViewRepresentations\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfDirection\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Direction\" nillable=\"true\" type=\"tns:Direction\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Direction\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"DirectionType\" type=\"tns:DirectionType\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Action\" type=\"tns:DirectionAction\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"BearingOutOfTurn\" type=\"s:float\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"BearingIntoTurn\" type=\"s:float\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Duration\" type=\"s:long\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Distance\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Towards\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Instruction\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FormattedInstruction\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"View\" type=\"tns:MapViewRepresentations\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"DirectionType\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Driving\"/>
					<s:enumeration value=\"Border\"/>
					<s:enumeration value=\"StartOfDay\"/>
					<s:enumeration value=\"EndOfDay\"/>
					<s:enumeration value=\"Warning\"/>
					<s:enumeration value=\"Waypoint\"/>
				</s:restriction>
			</s:simpleType>
			<s:simpleType name=\"DirectionAction\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Other\"/>
					<s:enumeration value=\"Depart\"/>
					<s:enumeration value=\"Arrive\"/>
					<s:enumeration value=\"TurnLeft\"/>
					<s:enumeration value=\"TurnRight\"/>
					<s:enumeration value=\"BearLeft\"/>
					<s:enumeration value=\"BearRight\"/>
					<s:enumeration value=\"Merge\"/>
					<s:enumeration value=\"Continue\"/>
					<s:enumeration value=\"TurnBack\"/>
					<s:enumeration value=\"TakeRoundabout\"/>
					<s:enumeration value=\"ConstructionDelay\"/>
					<s:enumeration value=\"ConstructionStop\"/>
					<s:enumeration value=\"NameChange\"/>
					<s:enumeration value=\"LeftLeft\"/>
					<s:enumeration value=\"LeftRight\"/>
					<s:enumeration value=\"RightLeft\"/>
					<s:enumeration value=\"RightRight\"/>
					<s:enumeration value=\"TakeRamp\"/>
					<s:enumeration value=\"TakeRampLeft\"/>
					<s:enumeration value=\"TakeRampRight\"/>
					<s:enumeration value=\"KeepStraight\"/>
					<s:enumeration value=\"KeepLeft\"/>
					<s:enumeration value=\"KeepRight\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"CalculatedRouteRepresentation\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Bits\" type=\"s:base64Binary\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindNearRouteResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindNearRouteResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"FindPolygon\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindPolygonSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindPolygonSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Filter\" type=\"tns:FindFilter\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"SpatialFilter\" type=\"tns:SpatialFilter\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindPolygonResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindPolygonResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"CalculateSimpleRoute\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"latLongs\" type=\"tns:ArrayOfLatLong\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"dataSourceName\" type=\"s:string\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"preference\" type=\"tns:SegmentPreference\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"CalculateSimpleRouteResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculateSimpleRouteResult\" type=\"tns:Route\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"CustomerInfoRouteHeader\" type=\"tns:CustomerInfoRouteHeader\"/>
			<s:complexType name=\"CustomerInfoRouteHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:CustomerInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"UserInfoRouteHeader\" type=\"tns:UserInfoRouteHeader\"/>
			<s:complexType name=\"UserInfoRouteHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:UserInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"CalculateRoute\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:RouteSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"CalculateRouteResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculateRouteResult\" type=\"tns:Route\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetMap\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:MapSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"MapSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Polygons\" type=\"tns:ArrayOfPolygon\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"HighlightedEntityIDs\" type=\"tns:ArrayOfInt\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"HideEntityTypes\" type=\"tns:ArrayOfString\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:MapOptions\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Pushpins\" type=\"tns:ArrayOfPushpin\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Route\" type=\"tns:Route\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Views\" type=\"tns:ArrayOfMapView\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfPolygon\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Polygon\" nillable=\"true\" type=\"tns:Polygon\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Polygon\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"EntityID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"BorderColor\" type=\"tns:ElementColor\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FillColor\" type=\"tns:ElementColor\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Label\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ElementColor\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"A\" type=\"s:unsignedByte\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"R\" type=\"s:unsignedByte\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"G\" type=\"s:unsignedByte\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"B\" type=\"s:unsignedByte\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"MapOptions\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"RouteHighlightColor\" type=\"tns:RouteHighlightColor\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ConstructionDelayHighlightColor\" type=\"tns:RouteHighlightColor\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ConstructionClosureHighlightColor\" type=\"tns:RouteHighlightColor\"/>
					<s:element default=\"Smaller\" maxOccurs=\"1\" minOccurs=\"0\" name=\"FontSize\" type=\"tns:MapFontSize\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Format\" type=\"tns:ImageFormat\"/>
					<s:element default=\"false\" maxOccurs=\"1\" minOccurs=\"0\" name=\"IsOverviewMap\" type=\"s:boolean\"/>
					<s:element default=\"ReturnImage\" maxOccurs=\"1\" minOccurs=\"0\" name=\"ReturnType\" type=\"tns:MapReturnType\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"PanHorizontal\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"PanVertical\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Style\" type=\"tns:MapStyle\"/>
					<s:element default=\"1\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Zoom\" type=\"s:double\"/>
					<s:element default=\"false\" maxOccurs=\"1\" minOccurs=\"0\" name=\"PreventIconCollisions\" type=\"s:boolean\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"RouteHighlightColor\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"DefaultColor\"/>
					<s:enumeration value=\"Green\"/>
					<s:enumeration value=\"Yellow\"/>
					<s:enumeration value=\"Cyan\"/>
					<s:enumeration value=\"Red\"/>
				</s:restriction>
			</s:simpleType>
			<s:simpleType name=\"MapFontSize\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Smallest\"/>
					<s:enumeration value=\"Smaller\"/>
					<s:enumeration value=\"Medium\"/>
					<s:enumeration value=\"Larger\"/>
					<s:enumeration value=\"Largest\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"ImageFormat\">
				<s:sequence>
					<s:element default=\"image/gif\" maxOccurs=\"1\" minOccurs=\"0\" name=\"MimeType\" type=\"s:string\"/>
					<s:element default=\"240\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Height\" type=\"s:int\"/>
					<s:element default=\"296\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Width\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"MapReturnType\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"ReturnImage\"/>
					<s:enumeration value=\"ReturnUrl\"/>
					<s:enumeration value=\"ReturnSecureUrl\"/>
				</s:restriction>
			</s:simpleType>
			<s:simpleType name=\"MapStyle\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"DefaultStyle\"/>
					<s:enumeration value=\"Locator\"/>
					<s:enumeration value=\"Terrain\"/>
					<s:enumeration value=\"Road\"/>
					<s:enumeration value=\"Political\"/>
					<s:enumeration value=\"Small\"/>
					<s:enumeration value=\"LocatorBW\"/>
					<s:enumeration value=\"TerrainBW\"/>
					<s:enumeration value=\"RoadBW\"/>
					<s:enumeration value=\"PoliticalBW\"/>
					<s:enumeration value=\"SmallBW\"/>
					<s:enumeration value=\"Comprehensive\"/>
					<s:enumeration value=\"PhysicalFeatures\"/>
					<s:enumeration value=\"Tectonic\"/>
					<s:enumeration value=\"EarthByDay\"/>
					<s:enumeration value=\"EarthByNight\"/>
					<s:enumeration value=\"Ecoregions\"/>
					<s:enumeration value=\"Climate\"/>
					<s:enumeration value=\"TemperatureJanuary\"/>
					<s:enumeration value=\"TemperatureJuly\"/>
					<s:enumeration value=\"PrecipitationJanuary\"/>
					<s:enumeration value=\"PrecipitationJuly\"/>
					<s:enumeration value=\"PrecipitationAnnual\"/>
					<s:enumeration value=\"Languages\"/>
					<s:enumeration value=\"Religions\"/>
					<s:enumeration value=\"PopulationDensity\"/>
					<s:enumeration value=\"Parks\"/>
					<s:enumeration value=\"TimeZones\"/>
					<s:enumeration value=\"Outline\"/>
					<s:enumeration value=\"Phone\"/>
					<s:enumeration value=\"PhoneBW\"/>
					<s:enumeration value=\"Night\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"ArrayOfPushpin\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Pushpin\" nillable=\"true\" type=\"tns:Pushpin\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Pushpin\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"IconDataSource\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"IconName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Label\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PinID\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Pixel\" type=\"tns:PixelCoord\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ReturnsHotArea\" type=\"s:boolean\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"LabelNearbyRoads\" type=\"s:boolean\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"PixelCoord\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"X\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Y\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfMapView\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"MapView\" nillable=\"true\" type=\"tns:MapView\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"MapImage\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"HotAreas\" type=\"tns:ArrayOfHotArea\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"MimeData\" type=\"tns:MimeData\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"View\" type=\"tns:MapViewRepresentations\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Url\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfHotArea\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"HotArea\" nillable=\"true\" type=\"tns:HotArea\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"HotArea\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"IconRectangle\" type=\"tns:PixelRectangle\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LabelRectangle\" type=\"tns:PixelRectangle\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PinID\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"PixelRectangle\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Bottom\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Left\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Right\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Top\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"MimeData\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Bits\" type=\"s:base64Binary\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ContentID\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"MimeType\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfMapImage\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"MapImage\" nillable=\"true\" type=\"tns:MapImage\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetMapResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetMapResult\" type=\"tns:ArrayOfMapImage\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"CustomerInfoRenderHeader\" type=\"tns:CustomerInfoRenderHeader\"/>
			<s:complexType name=\"CustomerInfoRenderHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:CustomerInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"UserInfoRenderHeader\" type=\"tns:UserInfoRenderHeader\"/>
			<s:complexType name=\"UserInfoRenderHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:UserInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"ConvertToPoint\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"latLong\" type=\"tns:ArrayOfLatLong\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"view\" type=\"tns:MapView\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"width\" type=\"s:int\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"height\" type=\"s:int\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfPixelCoord\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"PixelCoord\" nillable=\"true\" type=\"tns:PixelCoord\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"ConvertToPointResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ConvertToPointResult\" type=\"tns:ArrayOfPixelCoord\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"ConvertToLatLong\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"pixels\" type=\"tns:ArrayOfPixelCoord\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"view\" type=\"tns:MapView\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"width\" type=\"s:int\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"height\" type=\"s:int\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"ConvertToLatLongResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ConvertToLatLongResult\" type=\"tns:ArrayOfLatLong\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetBestMapView\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"locations\" type=\"tns:ArrayOfLocation\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"dataSourceName\" type=\"s:string\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetBestMapViewResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetBestMapViewResult\" type=\"tns:MapViewRepresentations\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetLineDriveMap\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:LineDriveMapSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"LineDriveMapSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Route\" type=\"tns:Route\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:LineDriveMapOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"LineDriveMapOptions\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Format\" type=\"tns:ImageFormat\"/>
					<s:element default=\"ReturnImage\" maxOccurs=\"1\" minOccurs=\"0\" name=\"ReturnType\" type=\"tns:MapReturnType\"/>
					<s:element default=\"Smaller\" maxOccurs=\"1\" minOccurs=\"0\" name=\"FontSize\" type=\"tns:MapFontSize\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"PaletteType\" type=\"tns:PaletteType\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DestinationIconDataSource\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DestinationIconName\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"PaletteType\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Color\"/>
					<s:enumeration value=\"GrayScale\"/>
					<s:enumeration value=\"Monochrome\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"LineDriveMapImage\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"MimeData\" type=\"tns:MimeData\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Url\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"View\" type=\"tns:MapViewRepresentations\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"FirstDirectionID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"LastDirectionID\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfLineDriveMapImage\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"LineDriveMapImage\" nillable=\"true\" type=\"tns:LineDriveMapImage\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetLineDriveMapResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetLineDriveMapResult\" type=\"tns:ArrayOfLineDriveMapImage\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
		</s:schema>
	</wsdl:types>
	<wsdl:message name=\"GetVersionInfoSoapIn\">
		<wsdl:part element=\"tns:GetVersionInfo\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetVersionInfoSoapOut\">
		<wsdl:part element=\"tns:GetVersionInfoResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetVersionInfoCustomerInfoHeader\">
		<wsdl:part element=\"tns:CustomerInfoHeader\" name=\"CustomerInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetVersionInfoUserInfoHeader\">
		<wsdl:part element=\"tns:UserInfoHeader\" name=\"UserInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetCountryRegionInfoSoapIn\">
		<wsdl:part element=\"tns:GetCountryRegionInfo\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetCountryRegionInfoSoapOut\">
		<wsdl:part element=\"tns:GetCountryRegionInfoResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetCountryRegionInfoCustomerInfoHeader\">
		<wsdl:part element=\"tns:CustomerInfoHeader\" name=\"CustomerInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetCountryRegionInfoUserInfoHeader\">
		<wsdl:part element=\"tns:UserInfoHeader\" name=\"UserInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetEntityTypesSoapIn\">
		<wsdl:part element=\"tns:GetEntityTypes\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetEntityTypesSoapOut\">
		<wsdl:part element=\"tns:GetEntityTypesResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetEntityTypesCustomerInfoHeader\">
		<wsdl:part element=\"tns:CustomerInfoHeader\" name=\"CustomerInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetEntityTypesUserInfoHeader\">
		<wsdl:part element=\"tns:UserInfoHeader\" name=\"UserInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetDataSourceInfoSoapIn\">
		<wsdl:part element=\"tns:GetDataSourceInfo\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetDataSourceInfoSoapOut\">
		<wsdl:part element=\"tns:GetDataSourceInfoResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetDataSourceInfoCustomerInfoHeader\">
		<wsdl:part element=\"tns:CustomerInfoHeader\" name=\"CustomerInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetDataSourceInfoUserInfoHeader\">
		<wsdl:part element=\"tns:UserInfoHeader\" name=\"UserInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetGreatCircleDistancesSoapIn\">
		<wsdl:part element=\"tns:GetGreatCircleDistances\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetGreatCircleDistancesSoapOut\">
		<wsdl:part element=\"tns:GetGreatCircleDistancesResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetGreatCircleDistancesCustomerInfoHeader\">
		<wsdl:part element=\"tns:CustomerInfoHeader\" name=\"CustomerInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetGreatCircleDistancesUserInfoHeader\">
		<wsdl:part element=\"tns:UserInfoHeader\" name=\"UserInfoHeader\"/>
	</wsdl:message>
	<wsdl:portType name=\"CommonServiceSoap\">
		<wsdl:operation name=\"GetVersionInfo\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Get the MapPoint Web Service version.</documentation>
			<wsdl:input message=\"tns:GetVersionInfoSoapIn\"/>
			<wsdl:output message=\"tns:GetVersionInfoSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetCountryRegionInfo\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Retrieve information about countries or national regions.</documentation>
			<wsdl:input message=\"tns:GetCountryRegionInfoSoapIn\"/>
			<wsdl:output message=\"tns:GetCountryRegionInfoSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetEntityTypes\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Retrieve the list types and their properties in a DataSource.</documentation>
			<wsdl:input message=\"tns:GetEntityTypesSoapIn\"/>
			<wsdl:output message=\"tns:GetEntityTypesSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetDataSourceInfo\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Get a general description of data sources.</documentation>
			<wsdl:input message=\"tns:GetDataSourceInfoSoapIn\"/>
			<wsdl:output message=\"tns:GetDataSourceInfoSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetGreatCircleDistances\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Calculate pair-wise distances </documentation>
			<wsdl:input message=\"tns:GetGreatCircleDistancesSoapIn\"/>
			<wsdl:output message=\"tns:GetGreatCircleDistancesSoapOut\"/>
		</wsdl:operation>
	</wsdl:portType>
	<wsdl:binding name=\"CommonServiceSoap\" type=\"tns:CommonServiceSoap\">
		<soap:binding style=\"document\" transport=\"http://schemas.xmlsoap.org/soap/http\"/>
		<wsdl:operation name=\"GetVersionInfo\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetVersionInfo\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetVersionInfoCustomerInfoHeader\" part=\"CustomerInfoHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetVersionInfoUserInfoHeader\" part=\"UserInfoHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetCountryRegionInfo\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetCountryRegionInfo\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetCountryRegionInfoCustomerInfoHeader\" part=\"CustomerInfoHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetCountryRegionInfoUserInfoHeader\" part=\"UserInfoHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetEntityTypes\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetEntityTypes\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetEntityTypesCustomerInfoHeader\" part=\"CustomerInfoHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetEntityTypesUserInfoHeader\" part=\"UserInfoHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetDataSourceInfo\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetDataSourceInfo\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetDataSourceInfoCustomerInfoHeader\" part=\"CustomerInfoHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetDataSourceInfoUserInfoHeader\" part=\"UserInfoHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetGreatCircleDistances\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetGreatCircleDistances\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetGreatCircleDistancesCustomerInfoHeader\" part=\"CustomerInfoHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetGreatCircleDistancesUserInfoHeader\" part=\"UserInfoHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
	</wsdl:binding>
	<wsdl:service name=\"CommonService\">
		<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">The common service contains classes, methods, and properties that are common to the find, route, and render services.  The common service also provides basic utility functions that can be used in the Microsoft MapPoint Web Service applications.&lt;/p&gt;&lt;p class=&quot;intro&quot;&gt;Read the &lt;a href=&quot;default.htm&quot;&gt;formal description&lt;/a&gt; of the MapPoint Web Service for more information.</documentation>
		<wsdl:port binding=\"tns:CommonServiceSoap\" name=\"CommonServiceSoap\">
			<soap:address location=\"http://findv3.staging.mappoint.net/Find-30/Common.asmx\"/>
		</wsdl:port>
	</wsdl:service>
	<wsdl:message name=\"FindSoapIn\">
		<wsdl:part element=\"tns:Find\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindSoapOut\">
		<wsdl:part element=\"tns:FindResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindAddressSoapIn\">
		<wsdl:part element=\"tns:FindAddress\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindAddressSoapOut\">
		<wsdl:part element=\"tns:FindAddressResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindAddressCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindAddressUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ParseAddressSoapIn\">
		<wsdl:part element=\"tns:ParseAddress\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ParseAddressSoapOut\">
		<wsdl:part element=\"tns:ParseAddressResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ParseAddressCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ParseAddressUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLocationInfoSoapIn\">
		<wsdl:part element=\"tns:GetLocationInfo\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLocationInfoSoapOut\">
		<wsdl:part element=\"tns:GetLocationInfoResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLocationInfoCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLocationInfoUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearbySoapIn\">
		<wsdl:part element=\"tns:FindNearby\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearbySoapOut\">
		<wsdl:part element=\"tns:FindNearbyResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearbyCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearbyUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByPropertySoapIn\">
		<wsdl:part element=\"tns:FindByProperty\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByPropertySoapOut\">
		<wsdl:part element=\"tns:FindByPropertyResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByPropertyCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByPropertyUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByIDSoapIn\">
		<wsdl:part element=\"tns:FindByID\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByIDSoapOut\">
		<wsdl:part element=\"tns:FindByIDResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByIDCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByIDUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearRouteSoapIn\">
		<wsdl:part element=\"tns:FindNearRoute\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearRouteSoapOut\">
		<wsdl:part element=\"tns:FindNearRouteResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearRouteCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearRouteUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindPolygonSoapIn\">
		<wsdl:part element=\"tns:FindPolygon\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindPolygonSoapOut\">
		<wsdl:part element=\"tns:FindPolygonResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindPolygonCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindPolygonUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:portType name=\"FindServiceSoap\">
		<wsdl:operation name=\"Find\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds places based on the find options.</documentation>
			<wsdl:input message=\"tns:FindSoapIn\"/>
			<wsdl:output message=\"tns:FindSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindAddress\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds a list of addresses that match the input address.</documentation>
			<wsdl:input message=\"tns:FindAddressSoapIn\"/>
			<wsdl:output message=\"tns:FindAddressSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"ParseAddress\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Parses Address.FormattedAddress into its component Address pieces.</documentation>
			<wsdl:input message=\"tns:ParseAddressSoapIn\"/>
			<wsdl:output message=\"tns:ParseAddressSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetLocationInfo\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Searches around a LatLong for nearest addresses and entities.</documentation>
			<wsdl:input message=\"tns:GetLocationInfoSoapIn\"/>
			<wsdl:output message=\"tns:GetLocationInfoSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindNearby\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Find a list of POI, within a circle around a lat/long.</documentation>
			<wsdl:input message=\"tns:FindNearbySoapIn\"/>
			<wsdl:output message=\"tns:FindNearbySoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindByProperty\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds points of interest based on pre-defined or custom properties. This method is independent of the location information such as distance and latitude/logitude.</documentation>
			<wsdl:input message=\"tns:FindByPropertySoapIn\"/>
			<wsdl:output message=\"tns:FindByPropertySoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindByID\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds points of interest for a given entity ID.</documentation>
			<wsdl:input message=\"tns:FindByIDSoapIn\"/>
			<wsdl:output message=\"tns:FindByIDSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindNearRoute\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds points of interest locations within a specified distance from a route.</documentation>
			<wsdl:input message=\"tns:FindNearRouteSoapIn\"/>
			<wsdl:output message=\"tns:FindNearRouteSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindPolygon\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds polygons containing a point or intersecting a rectangle.</documentation>
			<wsdl:input message=\"tns:FindPolygonSoapIn\"/>
			<wsdl:output message=\"tns:FindPolygonSoapOut\"/>
		</wsdl:operation>
	</wsdl:portType>
	<wsdl:binding name=\"FindServiceSoap\" type=\"tns:FindServiceSoap\">
		<soap:binding style=\"document\" transport=\"http://schemas.xmlsoap.org/soap/http\"/>
		<wsdl:operation name=\"Find\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/Find\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindAddress\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindAddress\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindAddressCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindAddressUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"ParseAddress\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/ParseAddress\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:ParseAddressCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:ParseAddressUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetLocationInfo\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetLocationInfo\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetLocationInfoCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetLocationInfoUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindNearby\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindNearby\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindNearbyCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindNearbyUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindByProperty\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindByProperty\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindByPropertyCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindByPropertyUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindByID\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindByID\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindByIDCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindByIDUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindNearRoute\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindNearRoute\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindNearRouteCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindNearRouteUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindPolygon\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindPolygon\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindPolygonCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindPolygonUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
	</wsdl:binding>
	<wsdl:service name=\"FindService\">
		<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">The Find service allows you to locate addresses, places, latitude/longitude coordinates, and points of interest (from either MapPoint Web Service data or your data that we host for your use).</documentation>
		<wsdl:port binding=\"tns:FindServiceSoap\" name=\"FindServiceSoap\">
			<soap:address location=\"http://findv3.staging.mappoint.net/Find-30/FindService.asmx\"/>
		</wsdl:port>
	</wsdl:service>
	<wsdl:message name=\"CalculateSimpleRouteSoapIn\">
		<wsdl:part element=\"tns:CalculateSimpleRoute\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateSimpleRouteSoapOut\">
		<wsdl:part element=\"tns:CalculateSimpleRouteResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateSimpleRouteCustomerInfoRouteHeader\">
		<wsdl:part element=\"tns:CustomerInfoRouteHeader\" name=\"CustomerInfoRouteHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateSimpleRouteUserInfoRouteHeader\">
		<wsdl:part element=\"tns:UserInfoRouteHeader\" name=\"UserInfoRouteHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateRouteSoapIn\">
		<wsdl:part element=\"tns:CalculateRoute\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateRouteSoapOut\">
		<wsdl:part element=\"tns:CalculateRouteResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateRouteCustomerInfoRouteHeader\">
		<wsdl:part element=\"tns:CustomerInfoRouteHeader\" name=\"CustomerInfoRouteHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateRouteUserInfoRouteHeader\">
		<wsdl:part element=\"tns:UserInfoRouteHeader\" name=\"UserInfoRouteHeader\"/>
	</wsdl:message>
	<wsdl:portType name=\"RouteServiceSoap\">
		<wsdl:operation name=\"CalculateSimpleRoute\">
			<wsdl:input message=\"tns:CalculateSimpleRouteSoapIn\"/>
			<wsdl:output message=\"tns:CalculateSimpleRouteSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"CalculateRoute\">
			<wsdl:input message=\"tns:CalculateRouteSoapIn\"/>
			<wsdl:output message=\"tns:CalculateRouteSoapOut\"/>
		</wsdl:operation>
	</wsdl:portType>
	<wsdl:binding name=\"RouteServiceSoap\" type=\"tns:RouteServiceSoap\">
		<soap:binding style=\"document\" transport=\"http://schemas.xmlsoap.org/soap/http\"/>
		<wsdl:operation name=\"CalculateSimpleRoute\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/CalculateSimpleRoute\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:CalculateSimpleRouteCustomerInfoRouteHeader\" part=\"CustomerInfoRouteHeader\" use=\"literal\"/>
				<soap:header message=\"tns:CalculateSimpleRouteUserInfoRouteHeader\" part=\"UserInfoRouteHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"CalculateRoute\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/CalculateRoute\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:CalculateRouteCustomerInfoRouteHeader\" part=\"CustomerInfoRouteHeader\" use=\"literal\"/>
				<soap:header message=\"tns:CalculateRouteUserInfoRouteHeader\" part=\"UserInfoRouteHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
	</wsdl:binding>
	<wsdl:service name=\"RouteService\">
		<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">The route service allows you to generate routes, driving directions, and calculated route representations (used to render a highlighted route on the map) based on locations or waypoints, set segment and route preferences, and generate map views of segments and directions.</documentation>
		<wsdl:port binding=\"tns:RouteServiceSoap\" name=\"RouteServiceSoap\">
			<soap:address location=\"http://routev3.staging.mappoint.net/Route-30/RouteService.asmx\"/>
		</wsdl:port>
	</wsdl:service>
	<wsdl:message name=\"GetMapSoapIn\">
		<wsdl:part element=\"tns:GetMap\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetMapSoapOut\">
		<wsdl:part element=\"tns:GetMapResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetMapCustomerInfoRenderHeader\">
		<wsdl:part element=\"tns:CustomerInfoRenderHeader\" name=\"CustomerInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetMapUserInfoRenderHeader\">
		<wsdl:part element=\"tns:UserInfoRenderHeader\" name=\"UserInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToPointSoapIn\">
		<wsdl:part element=\"tns:ConvertToPoint\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToPointSoapOut\">
		<wsdl:part element=\"tns:ConvertToPointResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToPointCustomerInfoRenderHeader\">
		<wsdl:part element=\"tns:CustomerInfoRenderHeader\" name=\"CustomerInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToPointUserInfoRenderHeader\">
		<wsdl:part element=\"tns:UserInfoRenderHeader\" name=\"UserInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToLatLongSoapIn\">
		<wsdl:part element=\"tns:ConvertToLatLong\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToLatLongSoapOut\">
		<wsdl:part element=\"tns:ConvertToLatLongResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToLatLongCustomerInfoRenderHeader\">
		<wsdl:part element=\"tns:CustomerInfoRenderHeader\" name=\"CustomerInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToLatLongUserInfoRenderHeader\">
		<wsdl:part element=\"tns:UserInfoRenderHeader\" name=\"UserInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetBestMapViewSoapIn\">
		<wsdl:part element=\"tns:GetBestMapView\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetBestMapViewSoapOut\">
		<wsdl:part element=\"tns:GetBestMapViewResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetBestMapViewCustomerInfoRenderHeader\">
		<wsdl:part element=\"tns:CustomerInfoRenderHeader\" name=\"CustomerInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetBestMapViewUserInfoRenderHeader\">
		<wsdl:part element=\"tns:UserInfoRenderHeader\" name=\"UserInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLineDriveMapSoapIn\">
		<wsdl:part element=\"tns:GetLineDriveMap\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLineDriveMapSoapOut\">
		<wsdl:part element=\"tns:GetLineDriveMapResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLineDriveMapCustomerInfoRenderHeader\">
		<wsdl:part element=\"tns:CustomerInfoRenderHeader\" name=\"CustomerInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLineDriveMapUserInfoRenderHeader\">
		<wsdl:part element=\"tns:UserInfoRenderHeader\" name=\"UserInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:portType name=\"RenderServiceSoap\">
		<wsdl:operation name=\"GetMap\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Renders map images of the given MapViews</documentation>
			<wsdl:input message=\"tns:GetMapSoapIn\"/>
			<wsdl:output message=\"tns:GetMapSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"ConvertToPoint\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Convert individual LatLongs into PixelCoords as they would appear in the given MapView</documentation>
			<wsdl:input message=\"tns:ConvertToPointSoapIn\"/>
			<wsdl:output message=\"tns:ConvertToPointSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"ConvertToLatLong\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Convert individual PixelCoords into LatLongs as they would appear in the given MapView</documentation>
			<wsdl:input message=\"tns:ConvertToLatLongSoapIn\"/>
			<wsdl:output message=\"tns:ConvertToLatLongSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetBestMapView\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Get a MapView that encompasses the given locations</documentation>
			<wsdl:input message=\"tns:GetBestMapViewSoapIn\"/>
			<wsdl:output message=\"tns:GetBestMapViewSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetLineDriveMap\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Renders LineDrive map images of the given Route</documentation>
			<wsdl:input message=\"tns:GetLineDriveMapSoapIn\"/>
			<wsdl:output message=\"tns:GetLineDriveMapSoapOut\"/>
		</wsdl:operation>
	</wsdl:portType>
	<wsdl:binding name=\"RenderServiceSoap\" type=\"tns:RenderServiceSoap\">
		<soap:binding style=\"document\" transport=\"http://schemas.xmlsoap.org/soap/http\"/>
		<wsdl:operation name=\"GetMap\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetMap\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetMapCustomerInfoRenderHeader\" part=\"CustomerInfoRenderHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetMapUserInfoRenderHeader\" part=\"UserInfoRenderHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"ConvertToPoint\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/ConvertToPoint\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:ConvertToPointCustomerInfoRenderHeader\" part=\"CustomerInfoRenderHeader\" use=\"literal\"/>
				<soap:header message=\"tns:ConvertToPointUserInfoRenderHeader\" part=\"UserInfoRenderHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"ConvertToLatLong\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/ConvertToLatLong\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:ConvertToLatLongCustomerInfoRenderHeader\" part=\"CustomerInfoRenderHeader\" use=\"literal\"/>
				<soap:header message=\"tns:ConvertToLatLongUserInfoRenderHeader\" part=\"UserInfoRenderHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetBestMapView\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetBestMapView\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetBestMapViewCustomerInfoRenderHeader\" part=\"CustomerInfoRenderHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetBestMapViewUserInfoRenderHeader\" part=\"UserInfoRenderHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetLineDriveMap\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetLineDriveMap\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetLineDriveMapCustomerInfoRenderHeader\" part=\"CustomerInfoRenderHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetLineDriveMapUserInfoRenderHeader\" part=\"UserInfoRenderHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
	</wsdl:binding>
	<wsdl:service name=\"RenderService\">
		<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">The render service allows you to render maps of routes and found locations, place pushpins (using the MapPoint Web Service stock set of icons or your icons that we host for your use), set the map size and map view, select points on a map, get location information about points on a map, pan and zoom a rendered map, and create clickable maps.</documentation>
		<wsdl:port binding=\"tns:RenderServiceSoap\" name=\"RenderServiceSoap\">
			<soap:address location=\"http://renderv3.staging.mappoint.net/Render-30/RenderService.asmx\"/>
		</wsdl:port>
	</wsdl:service>
</wsdl:definitions>"""

    def __init__(self, post='/Route-30/RouteService.asmx', **kw):
        ServiceSOAPBinding.__init__(self, post)

    def soap_CalculateSimpleRoute(self, ps):
        self.request = ps.Parse(CalculateSimpleRouteSoapIn.typecode)
        return CalculateSimpleRouteSoapOut()

    soapAction['http://s.mappoint.net/mappoint-30/CalculateSimpleRoute'] = 'soap_CalculateSimpleRoute'
    root[(CalculateSimpleRouteSoapIn.typecode.nspname,CalculateSimpleRouteSoapIn.typecode.pname)] = 'soap_CalculateSimpleRoute'

    def soap_CalculateRoute(self, ps):
        self.request = ps.Parse(CalculateRouteSoapIn.typecode)
        return CalculateRouteSoapOut()

    soapAction['http://s.mappoint.net/mappoint-30/CalculateRoute'] = 'soap_CalculateRoute'
    root[(CalculateRouteSoapIn.typecode.nspname,CalculateRouteSoapIn.typecode.pname)] = 'soap_CalculateRoute'

class FindService(ServiceSOAPBinding):
    soapAction = {}
    root = {}
    _wsdl = """<?xml version=\"1.0\" ?>
<wsdl:definitions targetNamespace=\"http://s.mappoint.net/mappoint-30/\" xmlns:http=\"http://schemas.xmlsoap.org/wsdl/http/\" xmlns:mime=\"http://schemas.xmlsoap.org/wsdl/mime/\" xmlns:s=\"http://www.w3.org/2001/XMLSchema\" xmlns:soap=\"http://schemas.xmlsoap.org/wsdl/soap/\" xmlns:soapenc=\"http://schemas.xmlsoap.org/soap/encoding/\" xmlns:tm=\"http://microsoft.com/wsdl/mime/textMatching/\" xmlns:tns=\"http://s.mappoint.net/mappoint-30/\" xmlns:wsdl=\"http://schemas.xmlsoap.org/wsdl/\">
	<wsdl:types>
		<s:schema elementFormDefault=\"qualified\" targetNamespace=\"http://s.mappoint.net/mappoint-30/\">
			<s:element name=\"GetVersionInfo\">
				<s:complexType/>
			</s:element>
			<s:element name=\"GetVersionInfoResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetVersionInfoResult\" type=\"tns:ArrayOfVersionInfo\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfVersionInfo\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"VersionInfo\" nillable=\"true\" type=\"tns:VersionInfo\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"VersionInfo\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Component\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Version\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"CustomerInfoHeader\" type=\"tns:CustomerInfoHeader\"/>
			<s:complexType name=\"CustomerInfoHeader\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"CustomLogEntry\" type=\"s:short\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"UserInfoHeader\" type=\"tns:UserInfoHeader\"/>
			<s:complexType name=\"UserInfoHeader\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Culture\" type=\"tns:CultureInfo\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"DefaultDistanceUnit\" type=\"tns:DistanceUnit\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Context\" type=\"tns:CountryRegionContext\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"CultureInfo\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Lcid\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"DistanceUnit\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Kilometer\"/>
					<s:enumeration value=\"Mile\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"CountryRegionContext\">
				<s:sequence>
					<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Iso2\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetCountryRegionInfo\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"entityIDs\" type=\"tns:ArrayOfInt\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfInt\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"int\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetCountryRegionInfoResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetCountryRegionInfoResult\" type=\"tns:ArrayOfCountryRegionInfo\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfCountryRegionInfo\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"CountryRegionInfo\" nillable=\"true\" type=\"tns:CountryRegionInfo\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"CountryRegionInfo\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"EntityID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Iso2\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Iso3\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FriendlyName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"OfficialName\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"LatLong\">
				<s:sequence>
					<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Latitude\" type=\"s:double\"/>
					<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Longitude\" type=\"s:double\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetEntityTypes\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"dataSourceName\" type=\"s:string\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetEntityTypesResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetEntityTypesResult\" type=\"tns:ArrayOfEntityType\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfEntityType\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"EntityType\" nillable=\"true\" type=\"tns:EntityType\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"EntityType\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DisplayName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ParentName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Definition\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Properties\" type=\"tns:ArrayOfEntityProperty\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfEntityProperty\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Property\" nillable=\"true\" type=\"tns:EntityProperty\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"EntityProperty\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DisplayName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataType\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetDataSourceInfo\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"dataSourceNames\" type=\"tns:ArrayOfString\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfString\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"string\" nillable=\"true\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetDataSourceInfoResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetDataSourceInfoResult\" type=\"tns:ArrayOfDataSource\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfDataSource\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"DataSource\" nillable=\"true\" type=\"tns:DataSource\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"DataSource\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Version\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Description\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Capability\" type=\"tns:DataSourceCapability\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityExtent\" type=\"tns:ArrayOfInt\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"DataSourceCapability\">
				<s:list>
					<s:simpleType>
						<s:restriction base=\"s:string\">
							<s:enumeration value=\"CanDrawMaps\"/>
							<s:enumeration value=\"CanFindPlaces\"/>
							<s:enumeration value=\"CanFindNearby\"/>
							<s:enumeration value=\"CanRoute\"/>
							<s:enumeration value=\"CanFindAddress\"/>
							<s:enumeration value=\"HasIcons\"/>
							<s:enumeration value=\"DataServiceQuery\"/>
						</s:restriction>
					</s:simpleType>
				</s:list>
			</s:simpleType>
			<s:element name=\"GetGreatCircleDistances\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"latLongs\" type=\"tns:ArrayOfLatLong\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfLatLong\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"LatLong\" nillable=\"true\" type=\"tns:LatLong\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetGreatCircleDistancesResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetGreatCircleDistancesResult\" type=\"tns:ArrayOfDouble\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfDouble\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"double\" type=\"s:double\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"Find\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"InputPlace\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityTypeNames\" type=\"tns:ArrayOfString\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"FindOptions\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Range\" type=\"tns:FindRange\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"SearchContext\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ResultMask\" type=\"tns:FindResultMask\"/>
					<s:element default=\"0.85\" maxOccurs=\"1\" minOccurs=\"0\" name=\"ThresholdScore\" type=\"s:double\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"FindRange\">
				<s:sequence>
					<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"StartIndex\" type=\"s:int\"/>
					<s:element default=\"25\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Count\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"FindResultMask\">
				<s:list>
					<s:simpleType>
						<s:restriction base=\"s:string\">
							<s:enumeration value=\"LatLongFlag\"/>
							<s:enumeration value=\"EntityFlag\"/>
							<s:enumeration value=\"AddressFlag\"/>
							<s:enumeration value=\"BestMapViewFlag\"/>
							<s:enumeration value=\"MatchDetailsFlag\"/>
						</s:restriction>
					</s:simpleType>
				</s:list>
			</s:simpleType>
			<s:element name=\"FindResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindResults\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"NumberFound\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"StartIndex\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Results\" type=\"tns:ArrayOfFindResult\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"TopScore\" type=\"s:double\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfFindResult\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"FindResult\" nillable=\"true\" type=\"tns:FindResult\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"FindResult\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Score\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FoundLocation\" type=\"tns:Location\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Location\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Entity\" type=\"tns:Entity\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Address\" type=\"tns:Address\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"BestMapView\" type=\"tns:MapViewRepresentations\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Entity\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DisplayName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"TypeName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Properties\" type=\"tns:ArrayOfEntityPropertyValue\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfEntityPropertyValue\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Property\" nillable=\"true\" type=\"tns:EntityPropertyValue\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"EntityPropertyValue\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Value\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Address\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"AddressLine\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PrimaryCity\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"SecondaryCity\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Subdivision\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PostalCode\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CountryRegion\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FormattedAddress\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"MapViewRepresentations\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ByScale\" type=\"tns:ViewByScale\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ByHeightWidth\" type=\"tns:ViewByHeightWidth\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ByBoundingRectangle\" type=\"tns:ViewByBoundingRectangle\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ViewByScale\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:MapView\">
						<s:sequence>
							<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"MapScale\" type=\"s:double\"/>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CenterPoint\" type=\"tns:LatLong\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:complexType abstract=\"true\" name=\"MapView\"/>
			<s:complexType name=\"ViewByBoundingLocations\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:MapView\">
						<s:sequence>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Locations\" type=\"tns:ArrayOfLocation\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:complexType name=\"ArrayOfLocation\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Location\" nillable=\"true\" type=\"tns:Location\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ViewByHeightWidth\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:MapView\">
						<s:sequence>
							<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Height\" type=\"s:double\"/>
							<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Width\" type=\"s:double\"/>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CenterPoint\" type=\"tns:LatLong\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:complexType name=\"ViewByBoundingRectangle\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:MapView\">
						<s:sequence>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"BoundingRectangle\" type=\"tns:LatLongRectangle\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:complexType name=\"LatLongRectangle\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Southwest\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Northeast\" type=\"tns:LatLong\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"MapPointConstants\">
				<s:sequence>
					<s:element default=\"6378.2\" maxOccurs=\"1\" minOccurs=\"0\" name=\"EarthRadiusInKilometers\" type=\"s:double\"/>
					<s:element default=\"3.1415926535897931\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Pi\" type=\"s:double\"/>
					<s:element default=\"0.017453292519943295\" maxOccurs=\"1\" minOccurs=\"0\" name=\"RadiansPerDegree\" type=\"s:double\"/>
					<s:element default=\"57.295779513082323\" maxOccurs=\"1\" minOccurs=\"0\" name=\"DegreesPerRadian\" type=\"s:double\"/>
					<s:element default=\"0.621371192237334\" maxOccurs=\"1\" minOccurs=\"0\" name=\"MilesPerKilometer\" type=\"s:double\"/>
					<s:element default=\"1.609344\" maxOccurs=\"1\" minOccurs=\"0\" name=\"KilometersPerMile\" type=\"s:double\"/>
					<s:element default=\"0.0003048\" maxOccurs=\"1\" minOccurs=\"0\" name=\"KilometersPerFoot\" type=\"s:double\"/>
					<s:element default=\"3280.8398950131232\" maxOccurs=\"1\" minOccurs=\"0\" name=\"FeetPerKilometer\" type=\"s:double\"/>
					<s:element default=\"0.85\" maxOccurs=\"1\" minOccurs=\"0\" name=\"FindScoreThreshold\" type=\"s:double\"/>
					<s:element default=\"96\" maxOccurs=\"1\" minOccurs=\"0\" name=\"AssumedDpi\" type=\"s:int\"/>
					<s:element default=\"3.280839895013123\" maxOccurs=\"1\" minOccurs=\"0\" name=\"FeetPerMeter\" type=\"s:double\"/>
					<s:element default=\"0.3048\" maxOccurs=\"1\" minOccurs=\"0\" name=\"MetersPerFoot\" type=\"s:double\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType abstract=\"true\" name=\"SpatialFilter\"/>
			<s:complexType name=\"LatLongSpatialFilter\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:SpatialFilter\">
						<s:sequence>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:complexType name=\"LatLongRectangleSpatialFilter\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:SpatialFilter\">
						<s:sequence>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"BoundingRectangle\" type=\"tns:LatLongRectangle\"/>
							<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"PolygonRectangleRelation\" type=\"tns:SpatialRelation\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:simpleType name=\"SpatialRelation\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"WithinArea\"/>
					<s:enumeration value=\"TouchesArea\"/>
				</s:restriction>
			</s:simpleType>
			<s:element name=\"CustomerInfoFindHeader\" type=\"tns:CustomerInfoFindHeader\"/>
			<s:complexType name=\"CustomerInfoFindHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:CustomerInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"UserInfoFindHeader\" type=\"tns:UserInfoFindHeader\"/>
			<s:complexType name=\"UserInfoFindHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:UserInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"FindAddress\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindAddressSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindAddressSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"InputAddress\" type=\"tns:Address\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindAddressResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindAddressResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"ParseAddress\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"inputAddress\" type=\"s:string\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"countryRegion\" type=\"s:string\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"ParseAddressResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ParseAddressResult\" type=\"tns:Address\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetLocationInfo\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"location\" type=\"tns:LatLong\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"dataSourceName\" type=\"s:string\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"options\" type=\"tns:GetInfoOptions\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"GetInfoOptions\">
				<s:sequence>
					<s:element default=\"true\" maxOccurs=\"1\" minOccurs=\"0\" name=\"IncludeAddresses\" type=\"s:boolean\"/>
					<s:element default=\"true\" maxOccurs=\"1\" minOccurs=\"0\" name=\"IncludeAllEntityTypes\" type=\"s:boolean\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityTypesToReturn\" type=\"tns:ArrayOfString\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetLocationInfoResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetLocationInfoResult\" type=\"tns:ArrayOfLocation\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"FindNearby\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindNearbySpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindNearbySpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Distance\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Filter\" type=\"tns:FindFilter\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"FindFilter\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityTypeName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PropertyNames\" type=\"tns:ArrayOfString\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"WhereClause\" type=\"tns:WhereClause\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"SortProperties\" type=\"tns:ArrayOfSortProperty\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Expression\" type=\"tns:FilterExpression\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"WhereClause\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"SearchProperties\" type=\"tns:ArrayOfEntityPropertyValue\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"SearchOperator\" type=\"tns:SearchOperatorFlag\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"SearchOperatorFlag\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"And\"/>
					<s:enumeration value=\"Or\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"ArrayOfSortProperty\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"SortProperty\" nillable=\"true\" type=\"tns:SortProperty\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"SortProperty\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PropertyName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Direction\" type=\"tns:SortDirection\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"SortDirection\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Ascending\"/>
					<s:enumeration value=\"Descending\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"FilterExpression\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Text\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Parameters\" type=\"tns:ArrayOfAnyType\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfAnyType\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"anyType\" nillable=\"true\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindNearbyResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindNearbyResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"FindByProperty\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindByPropertySpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindByPropertySpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Filter\" type=\"tns:FindFilter\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindByPropertyResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindByPropertyResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"FindByID\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindByIDSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindByIDSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Filter\" type=\"tns:FindFilter\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityIDs\" type=\"tns:ArrayOfInt\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindByIDResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindByIDResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"FindNearRoute\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindNearRouteSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindNearRouteSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Distance\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Filter\" type=\"tns:FindFilter\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Route\" type=\"tns:Route\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Route\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Specification\" type=\"tns:RouteSpecification\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Itinerary\" type=\"tns:RouteItinerary\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculatedRepresentation\" type=\"tns:CalculatedRouteRepresentation\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"RouteSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Segments\" type=\"tns:ArrayOfSegmentSpecification\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ResultMask\" type=\"tns:RouteResultMask\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DriverProfile\" type=\"tns:DriverProfile\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfSegmentSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"SegmentSpecification\" nillable=\"true\" type=\"tns:SegmentSpecification\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"SegmentSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Waypoint\" type=\"tns:Waypoint\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:SegmentOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Waypoint\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Location\" type=\"tns:Location\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Snap\" type=\"tns:SnapType\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculatedLocation\" type=\"tns:Location\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"SnapType\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Normal\"/>
					<s:enumeration value=\"City\"/>
					<s:enumeration value=\"NearestRoad\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"SegmentOptions\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Preference\" type=\"tns:SegmentPreference\"/>
					<s:element default=\"true\" maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculateSegmentMapView\" type=\"s:boolean\"/>
					<s:element default=\"true\" maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculateDirectionMapView\" type=\"s:boolean\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"SegmentPreference\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Quickest\"/>
					<s:enumeration value=\"Shortest\"/>
				</s:restriction>
			</s:simpleType>
			<s:simpleType name=\"RouteResultMask\">
				<s:list>
					<s:simpleType>
						<s:restriction base=\"s:string\">
							<s:enumeration value=\"Itinerary\"/>
							<s:enumeration value=\"CalculatedRouteRepresentation\"/>
						</s:restriction>
					</s:simpleType>
				</s:list>
			</s:simpleType>
			<s:complexType name=\"DriverProfile\">
				<s:sequence>
					<s:element default=\"-1\" maxOccurs=\"1\" minOccurs=\"0\" name=\"DayStartTime\" type=\"s:int\"/>
					<s:element default=\"-1\" maxOccurs=\"1\" minOccurs=\"0\" name=\"DayEndTime\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"RouteItinerary\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Segments\" type=\"tns:ArrayOfSegment\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"TripTime\" type=\"s:long\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"DrivingTime\" type=\"s:long\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Distance\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"View\" type=\"tns:MapViewRepresentations\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfSegment\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Segment\" nillable=\"true\" type=\"tns:Segment\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Segment\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Waypoint\" type=\"tns:Waypoint\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Directions\" type=\"tns:ArrayOfDirection\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"TripTime\" type=\"s:long\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"DrivingTime\" type=\"s:long\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Distance\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"View\" type=\"tns:MapViewRepresentations\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfDirection\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Direction\" nillable=\"true\" type=\"tns:Direction\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Direction\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"DirectionType\" type=\"tns:DirectionType\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Action\" type=\"tns:DirectionAction\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"BearingOutOfTurn\" type=\"s:float\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"BearingIntoTurn\" type=\"s:float\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Duration\" type=\"s:long\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Distance\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Towards\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Instruction\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FormattedInstruction\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"View\" type=\"tns:MapViewRepresentations\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"DirectionType\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Driving\"/>
					<s:enumeration value=\"Border\"/>
					<s:enumeration value=\"StartOfDay\"/>
					<s:enumeration value=\"EndOfDay\"/>
					<s:enumeration value=\"Warning\"/>
					<s:enumeration value=\"Waypoint\"/>
				</s:restriction>
			</s:simpleType>
			<s:simpleType name=\"DirectionAction\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Other\"/>
					<s:enumeration value=\"Depart\"/>
					<s:enumeration value=\"Arrive\"/>
					<s:enumeration value=\"TurnLeft\"/>
					<s:enumeration value=\"TurnRight\"/>
					<s:enumeration value=\"BearLeft\"/>
					<s:enumeration value=\"BearRight\"/>
					<s:enumeration value=\"Merge\"/>
					<s:enumeration value=\"Continue\"/>
					<s:enumeration value=\"TurnBack\"/>
					<s:enumeration value=\"TakeRoundabout\"/>
					<s:enumeration value=\"ConstructionDelay\"/>
					<s:enumeration value=\"ConstructionStop\"/>
					<s:enumeration value=\"NameChange\"/>
					<s:enumeration value=\"LeftLeft\"/>
					<s:enumeration value=\"LeftRight\"/>
					<s:enumeration value=\"RightLeft\"/>
					<s:enumeration value=\"RightRight\"/>
					<s:enumeration value=\"TakeRamp\"/>
					<s:enumeration value=\"TakeRampLeft\"/>
					<s:enumeration value=\"TakeRampRight\"/>
					<s:enumeration value=\"KeepStraight\"/>
					<s:enumeration value=\"KeepLeft\"/>
					<s:enumeration value=\"KeepRight\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"CalculatedRouteRepresentation\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Bits\" type=\"s:base64Binary\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindNearRouteResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindNearRouteResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"FindPolygon\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindPolygonSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindPolygonSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Filter\" type=\"tns:FindFilter\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"SpatialFilter\" type=\"tns:SpatialFilter\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindPolygonResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindPolygonResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"CalculateSimpleRoute\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"latLongs\" type=\"tns:ArrayOfLatLong\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"dataSourceName\" type=\"s:string\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"preference\" type=\"tns:SegmentPreference\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"CalculateSimpleRouteResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculateSimpleRouteResult\" type=\"tns:Route\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"CustomerInfoRouteHeader\" type=\"tns:CustomerInfoRouteHeader\"/>
			<s:complexType name=\"CustomerInfoRouteHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:CustomerInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"UserInfoRouteHeader\" type=\"tns:UserInfoRouteHeader\"/>
			<s:complexType name=\"UserInfoRouteHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:UserInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"CalculateRoute\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:RouteSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"CalculateRouteResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculateRouteResult\" type=\"tns:Route\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetMap\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:MapSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"MapSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Polygons\" type=\"tns:ArrayOfPolygon\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"HighlightedEntityIDs\" type=\"tns:ArrayOfInt\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"HideEntityTypes\" type=\"tns:ArrayOfString\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:MapOptions\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Pushpins\" type=\"tns:ArrayOfPushpin\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Route\" type=\"tns:Route\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Views\" type=\"tns:ArrayOfMapView\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfPolygon\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Polygon\" nillable=\"true\" type=\"tns:Polygon\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Polygon\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"EntityID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"BorderColor\" type=\"tns:ElementColor\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FillColor\" type=\"tns:ElementColor\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Label\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ElementColor\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"A\" type=\"s:unsignedByte\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"R\" type=\"s:unsignedByte\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"G\" type=\"s:unsignedByte\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"B\" type=\"s:unsignedByte\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"MapOptions\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"RouteHighlightColor\" type=\"tns:RouteHighlightColor\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ConstructionDelayHighlightColor\" type=\"tns:RouteHighlightColor\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ConstructionClosureHighlightColor\" type=\"tns:RouteHighlightColor\"/>
					<s:element default=\"Smaller\" maxOccurs=\"1\" minOccurs=\"0\" name=\"FontSize\" type=\"tns:MapFontSize\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Format\" type=\"tns:ImageFormat\"/>
					<s:element default=\"false\" maxOccurs=\"1\" minOccurs=\"0\" name=\"IsOverviewMap\" type=\"s:boolean\"/>
					<s:element default=\"ReturnImage\" maxOccurs=\"1\" minOccurs=\"0\" name=\"ReturnType\" type=\"tns:MapReturnType\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"PanHorizontal\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"PanVertical\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Style\" type=\"tns:MapStyle\"/>
					<s:element default=\"1\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Zoom\" type=\"s:double\"/>
					<s:element default=\"false\" maxOccurs=\"1\" minOccurs=\"0\" name=\"PreventIconCollisions\" type=\"s:boolean\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"RouteHighlightColor\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"DefaultColor\"/>
					<s:enumeration value=\"Green\"/>
					<s:enumeration value=\"Yellow\"/>
					<s:enumeration value=\"Cyan\"/>
					<s:enumeration value=\"Red\"/>
				</s:restriction>
			</s:simpleType>
			<s:simpleType name=\"MapFontSize\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Smallest\"/>
					<s:enumeration value=\"Smaller\"/>
					<s:enumeration value=\"Medium\"/>
					<s:enumeration value=\"Larger\"/>
					<s:enumeration value=\"Largest\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"ImageFormat\">
				<s:sequence>
					<s:element default=\"image/gif\" maxOccurs=\"1\" minOccurs=\"0\" name=\"MimeType\" type=\"s:string\"/>
					<s:element default=\"240\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Height\" type=\"s:int\"/>
					<s:element default=\"296\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Width\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"MapReturnType\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"ReturnImage\"/>
					<s:enumeration value=\"ReturnUrl\"/>
					<s:enumeration value=\"ReturnSecureUrl\"/>
				</s:restriction>
			</s:simpleType>
			<s:simpleType name=\"MapStyle\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"DefaultStyle\"/>
					<s:enumeration value=\"Locator\"/>
					<s:enumeration value=\"Terrain\"/>
					<s:enumeration value=\"Road\"/>
					<s:enumeration value=\"Political\"/>
					<s:enumeration value=\"Small\"/>
					<s:enumeration value=\"LocatorBW\"/>
					<s:enumeration value=\"TerrainBW\"/>
					<s:enumeration value=\"RoadBW\"/>
					<s:enumeration value=\"PoliticalBW\"/>
					<s:enumeration value=\"SmallBW\"/>
					<s:enumeration value=\"Comprehensive\"/>
					<s:enumeration value=\"PhysicalFeatures\"/>
					<s:enumeration value=\"Tectonic\"/>
					<s:enumeration value=\"EarthByDay\"/>
					<s:enumeration value=\"EarthByNight\"/>
					<s:enumeration value=\"Ecoregions\"/>
					<s:enumeration value=\"Climate\"/>
					<s:enumeration value=\"TemperatureJanuary\"/>
					<s:enumeration value=\"TemperatureJuly\"/>
					<s:enumeration value=\"PrecipitationJanuary\"/>
					<s:enumeration value=\"PrecipitationJuly\"/>
					<s:enumeration value=\"PrecipitationAnnual\"/>
					<s:enumeration value=\"Languages\"/>
					<s:enumeration value=\"Religions\"/>
					<s:enumeration value=\"PopulationDensity\"/>
					<s:enumeration value=\"Parks\"/>
					<s:enumeration value=\"TimeZones\"/>
					<s:enumeration value=\"Outline\"/>
					<s:enumeration value=\"Phone\"/>
					<s:enumeration value=\"PhoneBW\"/>
					<s:enumeration value=\"Night\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"ArrayOfPushpin\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Pushpin\" nillable=\"true\" type=\"tns:Pushpin\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Pushpin\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"IconDataSource\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"IconName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Label\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PinID\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Pixel\" type=\"tns:PixelCoord\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ReturnsHotArea\" type=\"s:boolean\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"LabelNearbyRoads\" type=\"s:boolean\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"PixelCoord\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"X\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Y\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfMapView\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"MapView\" nillable=\"true\" type=\"tns:MapView\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"MapImage\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"HotAreas\" type=\"tns:ArrayOfHotArea\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"MimeData\" type=\"tns:MimeData\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"View\" type=\"tns:MapViewRepresentations\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Url\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfHotArea\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"HotArea\" nillable=\"true\" type=\"tns:HotArea\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"HotArea\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"IconRectangle\" type=\"tns:PixelRectangle\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LabelRectangle\" type=\"tns:PixelRectangle\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PinID\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"PixelRectangle\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Bottom\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Left\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Right\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Top\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"MimeData\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Bits\" type=\"s:base64Binary\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ContentID\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"MimeType\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfMapImage\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"MapImage\" nillable=\"true\" type=\"tns:MapImage\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetMapResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetMapResult\" type=\"tns:ArrayOfMapImage\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"CustomerInfoRenderHeader\" type=\"tns:CustomerInfoRenderHeader\"/>
			<s:complexType name=\"CustomerInfoRenderHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:CustomerInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"UserInfoRenderHeader\" type=\"tns:UserInfoRenderHeader\"/>
			<s:complexType name=\"UserInfoRenderHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:UserInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"ConvertToPoint\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"latLong\" type=\"tns:ArrayOfLatLong\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"view\" type=\"tns:MapView\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"width\" type=\"s:int\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"height\" type=\"s:int\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfPixelCoord\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"PixelCoord\" nillable=\"true\" type=\"tns:PixelCoord\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"ConvertToPointResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ConvertToPointResult\" type=\"tns:ArrayOfPixelCoord\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"ConvertToLatLong\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"pixels\" type=\"tns:ArrayOfPixelCoord\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"view\" type=\"tns:MapView\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"width\" type=\"s:int\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"height\" type=\"s:int\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"ConvertToLatLongResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ConvertToLatLongResult\" type=\"tns:ArrayOfLatLong\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetBestMapView\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"locations\" type=\"tns:ArrayOfLocation\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"dataSourceName\" type=\"s:string\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetBestMapViewResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetBestMapViewResult\" type=\"tns:MapViewRepresentations\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetLineDriveMap\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:LineDriveMapSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"LineDriveMapSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Route\" type=\"tns:Route\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:LineDriveMapOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"LineDriveMapOptions\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Format\" type=\"tns:ImageFormat\"/>
					<s:element default=\"ReturnImage\" maxOccurs=\"1\" minOccurs=\"0\" name=\"ReturnType\" type=\"tns:MapReturnType\"/>
					<s:element default=\"Smaller\" maxOccurs=\"1\" minOccurs=\"0\" name=\"FontSize\" type=\"tns:MapFontSize\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"PaletteType\" type=\"tns:PaletteType\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DestinationIconDataSource\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DestinationIconName\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"PaletteType\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Color\"/>
					<s:enumeration value=\"GrayScale\"/>
					<s:enumeration value=\"Monochrome\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"LineDriveMapImage\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"MimeData\" type=\"tns:MimeData\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Url\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"View\" type=\"tns:MapViewRepresentations\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"FirstDirectionID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"LastDirectionID\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfLineDriveMapImage\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"LineDriveMapImage\" nillable=\"true\" type=\"tns:LineDriveMapImage\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetLineDriveMapResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetLineDriveMapResult\" type=\"tns:ArrayOfLineDriveMapImage\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
		</s:schema>
	</wsdl:types>
	<wsdl:message name=\"GetVersionInfoSoapIn\">
		<wsdl:part element=\"tns:GetVersionInfo\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetVersionInfoSoapOut\">
		<wsdl:part element=\"tns:GetVersionInfoResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetVersionInfoCustomerInfoHeader\">
		<wsdl:part element=\"tns:CustomerInfoHeader\" name=\"CustomerInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetVersionInfoUserInfoHeader\">
		<wsdl:part element=\"tns:UserInfoHeader\" name=\"UserInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetCountryRegionInfoSoapIn\">
		<wsdl:part element=\"tns:GetCountryRegionInfo\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetCountryRegionInfoSoapOut\">
		<wsdl:part element=\"tns:GetCountryRegionInfoResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetCountryRegionInfoCustomerInfoHeader\">
		<wsdl:part element=\"tns:CustomerInfoHeader\" name=\"CustomerInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetCountryRegionInfoUserInfoHeader\">
		<wsdl:part element=\"tns:UserInfoHeader\" name=\"UserInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetEntityTypesSoapIn\">
		<wsdl:part element=\"tns:GetEntityTypes\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetEntityTypesSoapOut\">
		<wsdl:part element=\"tns:GetEntityTypesResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetEntityTypesCustomerInfoHeader\">
		<wsdl:part element=\"tns:CustomerInfoHeader\" name=\"CustomerInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetEntityTypesUserInfoHeader\">
		<wsdl:part element=\"tns:UserInfoHeader\" name=\"UserInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetDataSourceInfoSoapIn\">
		<wsdl:part element=\"tns:GetDataSourceInfo\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetDataSourceInfoSoapOut\">
		<wsdl:part element=\"tns:GetDataSourceInfoResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetDataSourceInfoCustomerInfoHeader\">
		<wsdl:part element=\"tns:CustomerInfoHeader\" name=\"CustomerInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetDataSourceInfoUserInfoHeader\">
		<wsdl:part element=\"tns:UserInfoHeader\" name=\"UserInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetGreatCircleDistancesSoapIn\">
		<wsdl:part element=\"tns:GetGreatCircleDistances\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetGreatCircleDistancesSoapOut\">
		<wsdl:part element=\"tns:GetGreatCircleDistancesResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetGreatCircleDistancesCustomerInfoHeader\">
		<wsdl:part element=\"tns:CustomerInfoHeader\" name=\"CustomerInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetGreatCircleDistancesUserInfoHeader\">
		<wsdl:part element=\"tns:UserInfoHeader\" name=\"UserInfoHeader\"/>
	</wsdl:message>
	<wsdl:portType name=\"CommonServiceSoap\">
		<wsdl:operation name=\"GetVersionInfo\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Get the MapPoint Web Service version.</documentation>
			<wsdl:input message=\"tns:GetVersionInfoSoapIn\"/>
			<wsdl:output message=\"tns:GetVersionInfoSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetCountryRegionInfo\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Retrieve information about countries or national regions.</documentation>
			<wsdl:input message=\"tns:GetCountryRegionInfoSoapIn\"/>
			<wsdl:output message=\"tns:GetCountryRegionInfoSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetEntityTypes\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Retrieve the list types and their properties in a DataSource.</documentation>
			<wsdl:input message=\"tns:GetEntityTypesSoapIn\"/>
			<wsdl:output message=\"tns:GetEntityTypesSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetDataSourceInfo\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Get a general description of data sources.</documentation>
			<wsdl:input message=\"tns:GetDataSourceInfoSoapIn\"/>
			<wsdl:output message=\"tns:GetDataSourceInfoSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetGreatCircleDistances\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Calculate pair-wise distances </documentation>
			<wsdl:input message=\"tns:GetGreatCircleDistancesSoapIn\"/>
			<wsdl:output message=\"tns:GetGreatCircleDistancesSoapOut\"/>
		</wsdl:operation>
	</wsdl:portType>
	<wsdl:binding name=\"CommonServiceSoap\" type=\"tns:CommonServiceSoap\">
		<soap:binding style=\"document\" transport=\"http://schemas.xmlsoap.org/soap/http\"/>
		<wsdl:operation name=\"GetVersionInfo\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetVersionInfo\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetVersionInfoCustomerInfoHeader\" part=\"CustomerInfoHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetVersionInfoUserInfoHeader\" part=\"UserInfoHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetCountryRegionInfo\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetCountryRegionInfo\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetCountryRegionInfoCustomerInfoHeader\" part=\"CustomerInfoHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetCountryRegionInfoUserInfoHeader\" part=\"UserInfoHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetEntityTypes\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetEntityTypes\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetEntityTypesCustomerInfoHeader\" part=\"CustomerInfoHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetEntityTypesUserInfoHeader\" part=\"UserInfoHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetDataSourceInfo\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetDataSourceInfo\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetDataSourceInfoCustomerInfoHeader\" part=\"CustomerInfoHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetDataSourceInfoUserInfoHeader\" part=\"UserInfoHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetGreatCircleDistances\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetGreatCircleDistances\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetGreatCircleDistancesCustomerInfoHeader\" part=\"CustomerInfoHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetGreatCircleDistancesUserInfoHeader\" part=\"UserInfoHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
	</wsdl:binding>
	<wsdl:service name=\"CommonService\">
		<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">The common service contains classes, methods, and properties that are common to the find, route, and render services.  The common service also provides basic utility functions that can be used in the Microsoft MapPoint Web Service applications.&lt;/p&gt;&lt;p class=&quot;intro&quot;&gt;Read the &lt;a href=&quot;default.htm&quot;&gt;formal description&lt;/a&gt; of the MapPoint Web Service for more information.</documentation>
		<wsdl:port binding=\"tns:CommonServiceSoap\" name=\"CommonServiceSoap\">
			<soap:address location=\"http://findv3.staging.mappoint.net/Find-30/Common.asmx\"/>
		</wsdl:port>
	</wsdl:service>
	<wsdl:message name=\"FindSoapIn\">
		<wsdl:part element=\"tns:Find\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindSoapOut\">
		<wsdl:part element=\"tns:FindResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindAddressSoapIn\">
		<wsdl:part element=\"tns:FindAddress\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindAddressSoapOut\">
		<wsdl:part element=\"tns:FindAddressResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindAddressCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindAddressUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ParseAddressSoapIn\">
		<wsdl:part element=\"tns:ParseAddress\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ParseAddressSoapOut\">
		<wsdl:part element=\"tns:ParseAddressResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ParseAddressCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ParseAddressUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLocationInfoSoapIn\">
		<wsdl:part element=\"tns:GetLocationInfo\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLocationInfoSoapOut\">
		<wsdl:part element=\"tns:GetLocationInfoResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLocationInfoCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLocationInfoUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearbySoapIn\">
		<wsdl:part element=\"tns:FindNearby\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearbySoapOut\">
		<wsdl:part element=\"tns:FindNearbyResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearbyCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearbyUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByPropertySoapIn\">
		<wsdl:part element=\"tns:FindByProperty\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByPropertySoapOut\">
		<wsdl:part element=\"tns:FindByPropertyResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByPropertyCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByPropertyUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByIDSoapIn\">
		<wsdl:part element=\"tns:FindByID\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByIDSoapOut\">
		<wsdl:part element=\"tns:FindByIDResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByIDCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByIDUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearRouteSoapIn\">
		<wsdl:part element=\"tns:FindNearRoute\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearRouteSoapOut\">
		<wsdl:part element=\"tns:FindNearRouteResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearRouteCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearRouteUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindPolygonSoapIn\">
		<wsdl:part element=\"tns:FindPolygon\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindPolygonSoapOut\">
		<wsdl:part element=\"tns:FindPolygonResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindPolygonCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindPolygonUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:portType name=\"FindServiceSoap\">
		<wsdl:operation name=\"Find\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds places based on the find options.</documentation>
			<wsdl:input message=\"tns:FindSoapIn\"/>
			<wsdl:output message=\"tns:FindSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindAddress\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds a list of addresses that match the input address.</documentation>
			<wsdl:input message=\"tns:FindAddressSoapIn\"/>
			<wsdl:output message=\"tns:FindAddressSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"ParseAddress\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Parses Address.FormattedAddress into its component Address pieces.</documentation>
			<wsdl:input message=\"tns:ParseAddressSoapIn\"/>
			<wsdl:output message=\"tns:ParseAddressSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetLocationInfo\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Searches around a LatLong for nearest addresses and entities.</documentation>
			<wsdl:input message=\"tns:GetLocationInfoSoapIn\"/>
			<wsdl:output message=\"tns:GetLocationInfoSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindNearby\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Find a list of POI, within a circle around a lat/long.</documentation>
			<wsdl:input message=\"tns:FindNearbySoapIn\"/>
			<wsdl:output message=\"tns:FindNearbySoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindByProperty\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds points of interest based on pre-defined or custom properties. This method is independent of the location information such as distance and latitude/logitude.</documentation>
			<wsdl:input message=\"tns:FindByPropertySoapIn\"/>
			<wsdl:output message=\"tns:FindByPropertySoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindByID\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds points of interest for a given entity ID.</documentation>
			<wsdl:input message=\"tns:FindByIDSoapIn\"/>
			<wsdl:output message=\"tns:FindByIDSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindNearRoute\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds points of interest locations within a specified distance from a route.</documentation>
			<wsdl:input message=\"tns:FindNearRouteSoapIn\"/>
			<wsdl:output message=\"tns:FindNearRouteSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindPolygon\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds polygons containing a point or intersecting a rectangle.</documentation>
			<wsdl:input message=\"tns:FindPolygonSoapIn\"/>
			<wsdl:output message=\"tns:FindPolygonSoapOut\"/>
		</wsdl:operation>
	</wsdl:portType>
	<wsdl:binding name=\"FindServiceSoap\" type=\"tns:FindServiceSoap\">
		<soap:binding style=\"document\" transport=\"http://schemas.xmlsoap.org/soap/http\"/>
		<wsdl:operation name=\"Find\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/Find\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindAddress\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindAddress\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindAddressCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindAddressUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"ParseAddress\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/ParseAddress\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:ParseAddressCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:ParseAddressUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetLocationInfo\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetLocationInfo\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetLocationInfoCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetLocationInfoUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindNearby\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindNearby\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindNearbyCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindNearbyUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindByProperty\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindByProperty\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindByPropertyCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindByPropertyUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindByID\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindByID\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindByIDCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindByIDUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindNearRoute\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindNearRoute\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindNearRouteCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindNearRouteUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindPolygon\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindPolygon\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindPolygonCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindPolygonUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
	</wsdl:binding>
	<wsdl:service name=\"FindService\">
		<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">The Find service allows you to locate addresses, places, latitude/longitude coordinates, and points of interest (from either MapPoint Web Service data or your data that we host for your use).</documentation>
		<wsdl:port binding=\"tns:FindServiceSoap\" name=\"FindServiceSoap\">
			<soap:address location=\"http://findv3.staging.mappoint.net/Find-30/FindService.asmx\"/>
		</wsdl:port>
	</wsdl:service>
	<wsdl:message name=\"CalculateSimpleRouteSoapIn\">
		<wsdl:part element=\"tns:CalculateSimpleRoute\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateSimpleRouteSoapOut\">
		<wsdl:part element=\"tns:CalculateSimpleRouteResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateSimpleRouteCustomerInfoRouteHeader\">
		<wsdl:part element=\"tns:CustomerInfoRouteHeader\" name=\"CustomerInfoRouteHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateSimpleRouteUserInfoRouteHeader\">
		<wsdl:part element=\"tns:UserInfoRouteHeader\" name=\"UserInfoRouteHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateRouteSoapIn\">
		<wsdl:part element=\"tns:CalculateRoute\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateRouteSoapOut\">
		<wsdl:part element=\"tns:CalculateRouteResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateRouteCustomerInfoRouteHeader\">
		<wsdl:part element=\"tns:CustomerInfoRouteHeader\" name=\"CustomerInfoRouteHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateRouteUserInfoRouteHeader\">
		<wsdl:part element=\"tns:UserInfoRouteHeader\" name=\"UserInfoRouteHeader\"/>
	</wsdl:message>
	<wsdl:portType name=\"RouteServiceSoap\">
		<wsdl:operation name=\"CalculateSimpleRoute\">
			<wsdl:input message=\"tns:CalculateSimpleRouteSoapIn\"/>
			<wsdl:output message=\"tns:CalculateSimpleRouteSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"CalculateRoute\">
			<wsdl:input message=\"tns:CalculateRouteSoapIn\"/>
			<wsdl:output message=\"tns:CalculateRouteSoapOut\"/>
		</wsdl:operation>
	</wsdl:portType>
	<wsdl:binding name=\"RouteServiceSoap\" type=\"tns:RouteServiceSoap\">
		<soap:binding style=\"document\" transport=\"http://schemas.xmlsoap.org/soap/http\"/>
		<wsdl:operation name=\"CalculateSimpleRoute\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/CalculateSimpleRoute\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:CalculateSimpleRouteCustomerInfoRouteHeader\" part=\"CustomerInfoRouteHeader\" use=\"literal\"/>
				<soap:header message=\"tns:CalculateSimpleRouteUserInfoRouteHeader\" part=\"UserInfoRouteHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"CalculateRoute\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/CalculateRoute\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:CalculateRouteCustomerInfoRouteHeader\" part=\"CustomerInfoRouteHeader\" use=\"literal\"/>
				<soap:header message=\"tns:CalculateRouteUserInfoRouteHeader\" part=\"UserInfoRouteHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
	</wsdl:binding>
	<wsdl:service name=\"RouteService\">
		<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">The route service allows you to generate routes, driving directions, and calculated route representations (used to render a highlighted route on the map) based on locations or waypoints, set segment and route preferences, and generate map views of segments and directions.</documentation>
		<wsdl:port binding=\"tns:RouteServiceSoap\" name=\"RouteServiceSoap\">
			<soap:address location=\"http://routev3.staging.mappoint.net/Route-30/RouteService.asmx\"/>
		</wsdl:port>
	</wsdl:service>
	<wsdl:message name=\"GetMapSoapIn\">
		<wsdl:part element=\"tns:GetMap\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetMapSoapOut\">
		<wsdl:part element=\"tns:GetMapResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetMapCustomerInfoRenderHeader\">
		<wsdl:part element=\"tns:CustomerInfoRenderHeader\" name=\"CustomerInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetMapUserInfoRenderHeader\">
		<wsdl:part element=\"tns:UserInfoRenderHeader\" name=\"UserInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToPointSoapIn\">
		<wsdl:part element=\"tns:ConvertToPoint\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToPointSoapOut\">
		<wsdl:part element=\"tns:ConvertToPointResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToPointCustomerInfoRenderHeader\">
		<wsdl:part element=\"tns:CustomerInfoRenderHeader\" name=\"CustomerInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToPointUserInfoRenderHeader\">
		<wsdl:part element=\"tns:UserInfoRenderHeader\" name=\"UserInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToLatLongSoapIn\">
		<wsdl:part element=\"tns:ConvertToLatLong\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToLatLongSoapOut\">
		<wsdl:part element=\"tns:ConvertToLatLongResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToLatLongCustomerInfoRenderHeader\">
		<wsdl:part element=\"tns:CustomerInfoRenderHeader\" name=\"CustomerInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToLatLongUserInfoRenderHeader\">
		<wsdl:part element=\"tns:UserInfoRenderHeader\" name=\"UserInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetBestMapViewSoapIn\">
		<wsdl:part element=\"tns:GetBestMapView\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetBestMapViewSoapOut\">
		<wsdl:part element=\"tns:GetBestMapViewResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetBestMapViewCustomerInfoRenderHeader\">
		<wsdl:part element=\"tns:CustomerInfoRenderHeader\" name=\"CustomerInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetBestMapViewUserInfoRenderHeader\">
		<wsdl:part element=\"tns:UserInfoRenderHeader\" name=\"UserInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLineDriveMapSoapIn\">
		<wsdl:part element=\"tns:GetLineDriveMap\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLineDriveMapSoapOut\">
		<wsdl:part element=\"tns:GetLineDriveMapResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLineDriveMapCustomerInfoRenderHeader\">
		<wsdl:part element=\"tns:CustomerInfoRenderHeader\" name=\"CustomerInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLineDriveMapUserInfoRenderHeader\">
		<wsdl:part element=\"tns:UserInfoRenderHeader\" name=\"UserInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:portType name=\"RenderServiceSoap\">
		<wsdl:operation name=\"GetMap\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Renders map images of the given MapViews</documentation>
			<wsdl:input message=\"tns:GetMapSoapIn\"/>
			<wsdl:output message=\"tns:GetMapSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"ConvertToPoint\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Convert individual LatLongs into PixelCoords as they would appear in the given MapView</documentation>
			<wsdl:input message=\"tns:ConvertToPointSoapIn\"/>
			<wsdl:output message=\"tns:ConvertToPointSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"ConvertToLatLong\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Convert individual PixelCoords into LatLongs as they would appear in the given MapView</documentation>
			<wsdl:input message=\"tns:ConvertToLatLongSoapIn\"/>
			<wsdl:output message=\"tns:ConvertToLatLongSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetBestMapView\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Get a MapView that encompasses the given locations</documentation>
			<wsdl:input message=\"tns:GetBestMapViewSoapIn\"/>
			<wsdl:output message=\"tns:GetBestMapViewSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetLineDriveMap\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Renders LineDrive map images of the given Route</documentation>
			<wsdl:input message=\"tns:GetLineDriveMapSoapIn\"/>
			<wsdl:output message=\"tns:GetLineDriveMapSoapOut\"/>
		</wsdl:operation>
	</wsdl:portType>
	<wsdl:binding name=\"RenderServiceSoap\" type=\"tns:RenderServiceSoap\">
		<soap:binding style=\"document\" transport=\"http://schemas.xmlsoap.org/soap/http\"/>
		<wsdl:operation name=\"GetMap\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetMap\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetMapCustomerInfoRenderHeader\" part=\"CustomerInfoRenderHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetMapUserInfoRenderHeader\" part=\"UserInfoRenderHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"ConvertToPoint\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/ConvertToPoint\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:ConvertToPointCustomerInfoRenderHeader\" part=\"CustomerInfoRenderHeader\" use=\"literal\"/>
				<soap:header message=\"tns:ConvertToPointUserInfoRenderHeader\" part=\"UserInfoRenderHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"ConvertToLatLong\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/ConvertToLatLong\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:ConvertToLatLongCustomerInfoRenderHeader\" part=\"CustomerInfoRenderHeader\" use=\"literal\"/>
				<soap:header message=\"tns:ConvertToLatLongUserInfoRenderHeader\" part=\"UserInfoRenderHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetBestMapView\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetBestMapView\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetBestMapViewCustomerInfoRenderHeader\" part=\"CustomerInfoRenderHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetBestMapViewUserInfoRenderHeader\" part=\"UserInfoRenderHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetLineDriveMap\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetLineDriveMap\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetLineDriveMapCustomerInfoRenderHeader\" part=\"CustomerInfoRenderHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetLineDriveMapUserInfoRenderHeader\" part=\"UserInfoRenderHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
	</wsdl:binding>
	<wsdl:service name=\"RenderService\">
		<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">The render service allows you to render maps of routes and found locations, place pushpins (using the MapPoint Web Service stock set of icons or your icons that we host for your use), set the map size and map view, select points on a map, get location information about points on a map, pan and zoom a rendered map, and create clickable maps.</documentation>
		<wsdl:port binding=\"tns:RenderServiceSoap\" name=\"RenderServiceSoap\">
			<soap:address location=\"http://renderv3.staging.mappoint.net/Render-30/RenderService.asmx\"/>
		</wsdl:port>
	</wsdl:service>
</wsdl:definitions>"""

    def __init__(self, post='/Find-30/FindService.asmx', **kw):
        ServiceSOAPBinding.__init__(self, post)

    def soap_Find(self, ps):
        self.request = ps.Parse(FindSoapIn.typecode)
        return FindSoapOut()

    soapAction['http://s.mappoint.net/mappoint-30/Find'] = 'soap_Find'
    root[(FindSoapIn.typecode.nspname,FindSoapIn.typecode.pname)] = 'soap_Find'

    def soap_FindAddress(self, ps):
        self.request = ps.Parse(FindAddressSoapIn.typecode)
        return FindAddressSoapOut()

    soapAction['http://s.mappoint.net/mappoint-30/FindAddress'] = 'soap_FindAddress'
    root[(FindAddressSoapIn.typecode.nspname,FindAddressSoapIn.typecode.pname)] = 'soap_FindAddress'

    def soap_ParseAddress(self, ps):
        self.request = ps.Parse(ParseAddressSoapIn.typecode)
        return ParseAddressSoapOut()

    soapAction['http://s.mappoint.net/mappoint-30/ParseAddress'] = 'soap_ParseAddress'
    root[(ParseAddressSoapIn.typecode.nspname,ParseAddressSoapIn.typecode.pname)] = 'soap_ParseAddress'

    def soap_GetLocationInfo(self, ps):
        self.request = ps.Parse(GetLocationInfoSoapIn.typecode)
        return GetLocationInfoSoapOut()

    soapAction['http://s.mappoint.net/mappoint-30/GetLocationInfo'] = 'soap_GetLocationInfo'
    root[(GetLocationInfoSoapIn.typecode.nspname,GetLocationInfoSoapIn.typecode.pname)] = 'soap_GetLocationInfo'

    def soap_FindNearby(self, ps):
        self.request = ps.Parse(FindNearbySoapIn.typecode)
        return FindNearbySoapOut()

    soapAction['http://s.mappoint.net/mappoint-30/FindNearby'] = 'soap_FindNearby'
    root[(FindNearbySoapIn.typecode.nspname,FindNearbySoapIn.typecode.pname)] = 'soap_FindNearby'

    def soap_FindByProperty(self, ps):
        self.request = ps.Parse(FindByPropertySoapIn.typecode)
        return FindByPropertySoapOut()

    soapAction['http://s.mappoint.net/mappoint-30/FindByProperty'] = 'soap_FindByProperty'
    root[(FindByPropertySoapIn.typecode.nspname,FindByPropertySoapIn.typecode.pname)] = 'soap_FindByProperty'

    def soap_FindByID(self, ps):
        self.request = ps.Parse(FindByIDSoapIn.typecode)
        return FindByIDSoapOut()

    soapAction['http://s.mappoint.net/mappoint-30/FindByID'] = 'soap_FindByID'
    root[(FindByIDSoapIn.typecode.nspname,FindByIDSoapIn.typecode.pname)] = 'soap_FindByID'

    def soap_FindNearRoute(self, ps):
        self.request = ps.Parse(FindNearRouteSoapIn.typecode)
        return FindNearRouteSoapOut()

    soapAction['http://s.mappoint.net/mappoint-30/FindNearRoute'] = 'soap_FindNearRoute'
    root[(FindNearRouteSoapIn.typecode.nspname,FindNearRouteSoapIn.typecode.pname)] = 'soap_FindNearRoute'

    def soap_FindPolygon(self, ps):
        self.request = ps.Parse(FindPolygonSoapIn.typecode)
        return FindPolygonSoapOut()

    soapAction['http://s.mappoint.net/mappoint-30/FindPolygon'] = 'soap_FindPolygon'
    root[(FindPolygonSoapIn.typecode.nspname,FindPolygonSoapIn.typecode.pname)] = 'soap_FindPolygon'

class RenderService(ServiceSOAPBinding):
    soapAction = {}
    root = {}
    _wsdl = """<?xml version=\"1.0\" ?>
<wsdl:definitions targetNamespace=\"http://s.mappoint.net/mappoint-30/\" xmlns:http=\"http://schemas.xmlsoap.org/wsdl/http/\" xmlns:mime=\"http://schemas.xmlsoap.org/wsdl/mime/\" xmlns:s=\"http://www.w3.org/2001/XMLSchema\" xmlns:soap=\"http://schemas.xmlsoap.org/wsdl/soap/\" xmlns:soapenc=\"http://schemas.xmlsoap.org/soap/encoding/\" xmlns:tm=\"http://microsoft.com/wsdl/mime/textMatching/\" xmlns:tns=\"http://s.mappoint.net/mappoint-30/\" xmlns:wsdl=\"http://schemas.xmlsoap.org/wsdl/\">
	<wsdl:types>
		<s:schema elementFormDefault=\"qualified\" targetNamespace=\"http://s.mappoint.net/mappoint-30/\">
			<s:element name=\"GetVersionInfo\">
				<s:complexType/>
			</s:element>
			<s:element name=\"GetVersionInfoResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetVersionInfoResult\" type=\"tns:ArrayOfVersionInfo\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfVersionInfo\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"VersionInfo\" nillable=\"true\" type=\"tns:VersionInfo\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"VersionInfo\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Component\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Version\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"CustomerInfoHeader\" type=\"tns:CustomerInfoHeader\"/>
			<s:complexType name=\"CustomerInfoHeader\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"CustomLogEntry\" type=\"s:short\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"UserInfoHeader\" type=\"tns:UserInfoHeader\"/>
			<s:complexType name=\"UserInfoHeader\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Culture\" type=\"tns:CultureInfo\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"DefaultDistanceUnit\" type=\"tns:DistanceUnit\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Context\" type=\"tns:CountryRegionContext\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"CultureInfo\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Lcid\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"DistanceUnit\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Kilometer\"/>
					<s:enumeration value=\"Mile\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"CountryRegionContext\">
				<s:sequence>
					<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Iso2\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetCountryRegionInfo\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"entityIDs\" type=\"tns:ArrayOfInt\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfInt\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"int\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetCountryRegionInfoResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetCountryRegionInfoResult\" type=\"tns:ArrayOfCountryRegionInfo\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfCountryRegionInfo\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"CountryRegionInfo\" nillable=\"true\" type=\"tns:CountryRegionInfo\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"CountryRegionInfo\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"EntityID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Iso2\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Iso3\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FriendlyName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"OfficialName\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"LatLong\">
				<s:sequence>
					<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Latitude\" type=\"s:double\"/>
					<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Longitude\" type=\"s:double\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetEntityTypes\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"dataSourceName\" type=\"s:string\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetEntityTypesResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetEntityTypesResult\" type=\"tns:ArrayOfEntityType\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfEntityType\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"EntityType\" nillable=\"true\" type=\"tns:EntityType\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"EntityType\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DisplayName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ParentName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Definition\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Properties\" type=\"tns:ArrayOfEntityProperty\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfEntityProperty\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Property\" nillable=\"true\" type=\"tns:EntityProperty\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"EntityProperty\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DisplayName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataType\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetDataSourceInfo\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"dataSourceNames\" type=\"tns:ArrayOfString\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfString\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"string\" nillable=\"true\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetDataSourceInfoResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetDataSourceInfoResult\" type=\"tns:ArrayOfDataSource\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfDataSource\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"DataSource\" nillable=\"true\" type=\"tns:DataSource\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"DataSource\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Version\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Description\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Capability\" type=\"tns:DataSourceCapability\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityExtent\" type=\"tns:ArrayOfInt\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"DataSourceCapability\">
				<s:list>
					<s:simpleType>
						<s:restriction base=\"s:string\">
							<s:enumeration value=\"CanDrawMaps\"/>
							<s:enumeration value=\"CanFindPlaces\"/>
							<s:enumeration value=\"CanFindNearby\"/>
							<s:enumeration value=\"CanRoute\"/>
							<s:enumeration value=\"CanFindAddress\"/>
							<s:enumeration value=\"HasIcons\"/>
							<s:enumeration value=\"DataServiceQuery\"/>
						</s:restriction>
					</s:simpleType>
				</s:list>
			</s:simpleType>
			<s:element name=\"GetGreatCircleDistances\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"latLongs\" type=\"tns:ArrayOfLatLong\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfLatLong\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"LatLong\" nillable=\"true\" type=\"tns:LatLong\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetGreatCircleDistancesResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetGreatCircleDistancesResult\" type=\"tns:ArrayOfDouble\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfDouble\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"double\" type=\"s:double\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"Find\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"InputPlace\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityTypeNames\" type=\"tns:ArrayOfString\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"FindOptions\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Range\" type=\"tns:FindRange\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"SearchContext\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ResultMask\" type=\"tns:FindResultMask\"/>
					<s:element default=\"0.85\" maxOccurs=\"1\" minOccurs=\"0\" name=\"ThresholdScore\" type=\"s:double\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"FindRange\">
				<s:sequence>
					<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"StartIndex\" type=\"s:int\"/>
					<s:element default=\"25\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Count\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"FindResultMask\">
				<s:list>
					<s:simpleType>
						<s:restriction base=\"s:string\">
							<s:enumeration value=\"LatLongFlag\"/>
							<s:enumeration value=\"EntityFlag\"/>
							<s:enumeration value=\"AddressFlag\"/>
							<s:enumeration value=\"BestMapViewFlag\"/>
							<s:enumeration value=\"MatchDetailsFlag\"/>
						</s:restriction>
					</s:simpleType>
				</s:list>
			</s:simpleType>
			<s:element name=\"FindResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindResults\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"NumberFound\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"StartIndex\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Results\" type=\"tns:ArrayOfFindResult\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"TopScore\" type=\"s:double\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfFindResult\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"FindResult\" nillable=\"true\" type=\"tns:FindResult\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"FindResult\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Score\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FoundLocation\" type=\"tns:Location\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Location\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Entity\" type=\"tns:Entity\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Address\" type=\"tns:Address\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"BestMapView\" type=\"tns:MapViewRepresentations\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Entity\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DisplayName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"TypeName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Properties\" type=\"tns:ArrayOfEntityPropertyValue\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfEntityPropertyValue\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Property\" nillable=\"true\" type=\"tns:EntityPropertyValue\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"EntityPropertyValue\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Value\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Address\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"AddressLine\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PrimaryCity\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"SecondaryCity\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Subdivision\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PostalCode\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CountryRegion\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FormattedAddress\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"MapViewRepresentations\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ByScale\" type=\"tns:ViewByScale\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ByHeightWidth\" type=\"tns:ViewByHeightWidth\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ByBoundingRectangle\" type=\"tns:ViewByBoundingRectangle\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ViewByScale\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:MapView\">
						<s:sequence>
							<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"MapScale\" type=\"s:double\"/>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CenterPoint\" type=\"tns:LatLong\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:complexType abstract=\"true\" name=\"MapView\"/>
			<s:complexType name=\"ViewByBoundingLocations\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:MapView\">
						<s:sequence>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Locations\" type=\"tns:ArrayOfLocation\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:complexType name=\"ArrayOfLocation\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Location\" nillable=\"true\" type=\"tns:Location\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ViewByHeightWidth\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:MapView\">
						<s:sequence>
							<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Height\" type=\"s:double\"/>
							<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Width\" type=\"s:double\"/>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CenterPoint\" type=\"tns:LatLong\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:complexType name=\"ViewByBoundingRectangle\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:MapView\">
						<s:sequence>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"BoundingRectangle\" type=\"tns:LatLongRectangle\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:complexType name=\"LatLongRectangle\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Southwest\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Northeast\" type=\"tns:LatLong\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"MapPointConstants\">
				<s:sequence>
					<s:element default=\"6378.2\" maxOccurs=\"1\" minOccurs=\"0\" name=\"EarthRadiusInKilometers\" type=\"s:double\"/>
					<s:element default=\"3.1415926535897931\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Pi\" type=\"s:double\"/>
					<s:element default=\"0.017453292519943295\" maxOccurs=\"1\" minOccurs=\"0\" name=\"RadiansPerDegree\" type=\"s:double\"/>
					<s:element default=\"57.295779513082323\" maxOccurs=\"1\" minOccurs=\"0\" name=\"DegreesPerRadian\" type=\"s:double\"/>
					<s:element default=\"0.621371192237334\" maxOccurs=\"1\" minOccurs=\"0\" name=\"MilesPerKilometer\" type=\"s:double\"/>
					<s:element default=\"1.609344\" maxOccurs=\"1\" minOccurs=\"0\" name=\"KilometersPerMile\" type=\"s:double\"/>
					<s:element default=\"0.0003048\" maxOccurs=\"1\" minOccurs=\"0\" name=\"KilometersPerFoot\" type=\"s:double\"/>
					<s:element default=\"3280.8398950131232\" maxOccurs=\"1\" minOccurs=\"0\" name=\"FeetPerKilometer\" type=\"s:double\"/>
					<s:element default=\"0.85\" maxOccurs=\"1\" minOccurs=\"0\" name=\"FindScoreThreshold\" type=\"s:double\"/>
					<s:element default=\"96\" maxOccurs=\"1\" minOccurs=\"0\" name=\"AssumedDpi\" type=\"s:int\"/>
					<s:element default=\"3.280839895013123\" maxOccurs=\"1\" minOccurs=\"0\" name=\"FeetPerMeter\" type=\"s:double\"/>
					<s:element default=\"0.3048\" maxOccurs=\"1\" minOccurs=\"0\" name=\"MetersPerFoot\" type=\"s:double\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType abstract=\"true\" name=\"SpatialFilter\"/>
			<s:complexType name=\"LatLongSpatialFilter\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:SpatialFilter\">
						<s:sequence>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:complexType name=\"LatLongRectangleSpatialFilter\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:SpatialFilter\">
						<s:sequence>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"BoundingRectangle\" type=\"tns:LatLongRectangle\"/>
							<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"PolygonRectangleRelation\" type=\"tns:SpatialRelation\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:simpleType name=\"SpatialRelation\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"WithinArea\"/>
					<s:enumeration value=\"TouchesArea\"/>
				</s:restriction>
			</s:simpleType>
			<s:element name=\"CustomerInfoFindHeader\" type=\"tns:CustomerInfoFindHeader\"/>
			<s:complexType name=\"CustomerInfoFindHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:CustomerInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"UserInfoFindHeader\" type=\"tns:UserInfoFindHeader\"/>
			<s:complexType name=\"UserInfoFindHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:UserInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"FindAddress\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindAddressSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindAddressSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"InputAddress\" type=\"tns:Address\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindAddressResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindAddressResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"ParseAddress\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"inputAddress\" type=\"s:string\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"countryRegion\" type=\"s:string\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"ParseAddressResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ParseAddressResult\" type=\"tns:Address\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetLocationInfo\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"location\" type=\"tns:LatLong\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"dataSourceName\" type=\"s:string\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"options\" type=\"tns:GetInfoOptions\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"GetInfoOptions\">
				<s:sequence>
					<s:element default=\"true\" maxOccurs=\"1\" minOccurs=\"0\" name=\"IncludeAddresses\" type=\"s:boolean\"/>
					<s:element default=\"true\" maxOccurs=\"1\" minOccurs=\"0\" name=\"IncludeAllEntityTypes\" type=\"s:boolean\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityTypesToReturn\" type=\"tns:ArrayOfString\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetLocationInfoResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetLocationInfoResult\" type=\"tns:ArrayOfLocation\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"FindNearby\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindNearbySpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindNearbySpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Distance\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Filter\" type=\"tns:FindFilter\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"FindFilter\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityTypeName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PropertyNames\" type=\"tns:ArrayOfString\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"WhereClause\" type=\"tns:WhereClause\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"SortProperties\" type=\"tns:ArrayOfSortProperty\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Expression\" type=\"tns:FilterExpression\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"WhereClause\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"SearchProperties\" type=\"tns:ArrayOfEntityPropertyValue\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"SearchOperator\" type=\"tns:SearchOperatorFlag\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"SearchOperatorFlag\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"And\"/>
					<s:enumeration value=\"Or\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"ArrayOfSortProperty\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"SortProperty\" nillable=\"true\" type=\"tns:SortProperty\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"SortProperty\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PropertyName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Direction\" type=\"tns:SortDirection\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"SortDirection\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Ascending\"/>
					<s:enumeration value=\"Descending\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"FilterExpression\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Text\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Parameters\" type=\"tns:ArrayOfAnyType\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfAnyType\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"anyType\" nillable=\"true\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindNearbyResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindNearbyResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"FindByProperty\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindByPropertySpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindByPropertySpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Filter\" type=\"tns:FindFilter\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindByPropertyResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindByPropertyResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"FindByID\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindByIDSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindByIDSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Filter\" type=\"tns:FindFilter\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityIDs\" type=\"tns:ArrayOfInt\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindByIDResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindByIDResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"FindNearRoute\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindNearRouteSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindNearRouteSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Distance\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Filter\" type=\"tns:FindFilter\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Route\" type=\"tns:Route\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Route\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Specification\" type=\"tns:RouteSpecification\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Itinerary\" type=\"tns:RouteItinerary\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculatedRepresentation\" type=\"tns:CalculatedRouteRepresentation\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"RouteSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Segments\" type=\"tns:ArrayOfSegmentSpecification\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ResultMask\" type=\"tns:RouteResultMask\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DriverProfile\" type=\"tns:DriverProfile\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfSegmentSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"SegmentSpecification\" nillable=\"true\" type=\"tns:SegmentSpecification\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"SegmentSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Waypoint\" type=\"tns:Waypoint\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:SegmentOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Waypoint\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Location\" type=\"tns:Location\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Snap\" type=\"tns:SnapType\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculatedLocation\" type=\"tns:Location\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"SnapType\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Normal\"/>
					<s:enumeration value=\"City\"/>
					<s:enumeration value=\"NearestRoad\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"SegmentOptions\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Preference\" type=\"tns:SegmentPreference\"/>
					<s:element default=\"true\" maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculateSegmentMapView\" type=\"s:boolean\"/>
					<s:element default=\"true\" maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculateDirectionMapView\" type=\"s:boolean\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"SegmentPreference\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Quickest\"/>
					<s:enumeration value=\"Shortest\"/>
				</s:restriction>
			</s:simpleType>
			<s:simpleType name=\"RouteResultMask\">
				<s:list>
					<s:simpleType>
						<s:restriction base=\"s:string\">
							<s:enumeration value=\"Itinerary\"/>
							<s:enumeration value=\"CalculatedRouteRepresentation\"/>
						</s:restriction>
					</s:simpleType>
				</s:list>
			</s:simpleType>
			<s:complexType name=\"DriverProfile\">
				<s:sequence>
					<s:element default=\"-1\" maxOccurs=\"1\" minOccurs=\"0\" name=\"DayStartTime\" type=\"s:int\"/>
					<s:element default=\"-1\" maxOccurs=\"1\" minOccurs=\"0\" name=\"DayEndTime\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"RouteItinerary\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Segments\" type=\"tns:ArrayOfSegment\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"TripTime\" type=\"s:long\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"DrivingTime\" type=\"s:long\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Distance\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"View\" type=\"tns:MapViewRepresentations\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfSegment\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Segment\" nillable=\"true\" type=\"tns:Segment\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Segment\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Waypoint\" type=\"tns:Waypoint\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Directions\" type=\"tns:ArrayOfDirection\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"TripTime\" type=\"s:long\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"DrivingTime\" type=\"s:long\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Distance\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"View\" type=\"tns:MapViewRepresentations\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfDirection\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Direction\" nillable=\"true\" type=\"tns:Direction\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Direction\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"DirectionType\" type=\"tns:DirectionType\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Action\" type=\"tns:DirectionAction\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"BearingOutOfTurn\" type=\"s:float\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"BearingIntoTurn\" type=\"s:float\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Duration\" type=\"s:long\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Distance\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Towards\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Instruction\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FormattedInstruction\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"View\" type=\"tns:MapViewRepresentations\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"DirectionType\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Driving\"/>
					<s:enumeration value=\"Border\"/>
					<s:enumeration value=\"StartOfDay\"/>
					<s:enumeration value=\"EndOfDay\"/>
					<s:enumeration value=\"Warning\"/>
					<s:enumeration value=\"Waypoint\"/>
				</s:restriction>
			</s:simpleType>
			<s:simpleType name=\"DirectionAction\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Other\"/>
					<s:enumeration value=\"Depart\"/>
					<s:enumeration value=\"Arrive\"/>
					<s:enumeration value=\"TurnLeft\"/>
					<s:enumeration value=\"TurnRight\"/>
					<s:enumeration value=\"BearLeft\"/>
					<s:enumeration value=\"BearRight\"/>
					<s:enumeration value=\"Merge\"/>
					<s:enumeration value=\"Continue\"/>
					<s:enumeration value=\"TurnBack\"/>
					<s:enumeration value=\"TakeRoundabout\"/>
					<s:enumeration value=\"ConstructionDelay\"/>
					<s:enumeration value=\"ConstructionStop\"/>
					<s:enumeration value=\"NameChange\"/>
					<s:enumeration value=\"LeftLeft\"/>
					<s:enumeration value=\"LeftRight\"/>
					<s:enumeration value=\"RightLeft\"/>
					<s:enumeration value=\"RightRight\"/>
					<s:enumeration value=\"TakeRamp\"/>
					<s:enumeration value=\"TakeRampLeft\"/>
					<s:enumeration value=\"TakeRampRight\"/>
					<s:enumeration value=\"KeepStraight\"/>
					<s:enumeration value=\"KeepLeft\"/>
					<s:enumeration value=\"KeepRight\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"CalculatedRouteRepresentation\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Bits\" type=\"s:base64Binary\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindNearRouteResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindNearRouteResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"FindPolygon\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindPolygonSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindPolygonSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Filter\" type=\"tns:FindFilter\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"SpatialFilter\" type=\"tns:SpatialFilter\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindPolygonResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindPolygonResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"CalculateSimpleRoute\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"latLongs\" type=\"tns:ArrayOfLatLong\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"dataSourceName\" type=\"s:string\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"preference\" type=\"tns:SegmentPreference\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"CalculateSimpleRouteResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculateSimpleRouteResult\" type=\"tns:Route\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"CustomerInfoRouteHeader\" type=\"tns:CustomerInfoRouteHeader\"/>
			<s:complexType name=\"CustomerInfoRouteHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:CustomerInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"UserInfoRouteHeader\" type=\"tns:UserInfoRouteHeader\"/>
			<s:complexType name=\"UserInfoRouteHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:UserInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"CalculateRoute\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:RouteSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"CalculateRouteResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculateRouteResult\" type=\"tns:Route\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetMap\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:MapSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"MapSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Polygons\" type=\"tns:ArrayOfPolygon\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"HighlightedEntityIDs\" type=\"tns:ArrayOfInt\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"HideEntityTypes\" type=\"tns:ArrayOfString\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:MapOptions\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Pushpins\" type=\"tns:ArrayOfPushpin\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Route\" type=\"tns:Route\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Views\" type=\"tns:ArrayOfMapView\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfPolygon\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Polygon\" nillable=\"true\" type=\"tns:Polygon\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Polygon\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"EntityID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"BorderColor\" type=\"tns:ElementColor\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FillColor\" type=\"tns:ElementColor\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Label\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ElementColor\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"A\" type=\"s:unsignedByte\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"R\" type=\"s:unsignedByte\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"G\" type=\"s:unsignedByte\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"B\" type=\"s:unsignedByte\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"MapOptions\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"RouteHighlightColor\" type=\"tns:RouteHighlightColor\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ConstructionDelayHighlightColor\" type=\"tns:RouteHighlightColor\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ConstructionClosureHighlightColor\" type=\"tns:RouteHighlightColor\"/>
					<s:element default=\"Smaller\" maxOccurs=\"1\" minOccurs=\"0\" name=\"FontSize\" type=\"tns:MapFontSize\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Format\" type=\"tns:ImageFormat\"/>
					<s:element default=\"false\" maxOccurs=\"1\" minOccurs=\"0\" name=\"IsOverviewMap\" type=\"s:boolean\"/>
					<s:element default=\"ReturnImage\" maxOccurs=\"1\" minOccurs=\"0\" name=\"ReturnType\" type=\"tns:MapReturnType\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"PanHorizontal\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"PanVertical\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Style\" type=\"tns:MapStyle\"/>
					<s:element default=\"1\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Zoom\" type=\"s:double\"/>
					<s:element default=\"false\" maxOccurs=\"1\" minOccurs=\"0\" name=\"PreventIconCollisions\" type=\"s:boolean\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"RouteHighlightColor\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"DefaultColor\"/>
					<s:enumeration value=\"Green\"/>
					<s:enumeration value=\"Yellow\"/>
					<s:enumeration value=\"Cyan\"/>
					<s:enumeration value=\"Red\"/>
				</s:restriction>
			</s:simpleType>
			<s:simpleType name=\"MapFontSize\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Smallest\"/>
					<s:enumeration value=\"Smaller\"/>
					<s:enumeration value=\"Medium\"/>
					<s:enumeration value=\"Larger\"/>
					<s:enumeration value=\"Largest\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"ImageFormat\">
				<s:sequence>
					<s:element default=\"image/gif\" maxOccurs=\"1\" minOccurs=\"0\" name=\"MimeType\" type=\"s:string\"/>
					<s:element default=\"240\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Height\" type=\"s:int\"/>
					<s:element default=\"296\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Width\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"MapReturnType\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"ReturnImage\"/>
					<s:enumeration value=\"ReturnUrl\"/>
					<s:enumeration value=\"ReturnSecureUrl\"/>
				</s:restriction>
			</s:simpleType>
			<s:simpleType name=\"MapStyle\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"DefaultStyle\"/>
					<s:enumeration value=\"Locator\"/>
					<s:enumeration value=\"Terrain\"/>
					<s:enumeration value=\"Road\"/>
					<s:enumeration value=\"Political\"/>
					<s:enumeration value=\"Small\"/>
					<s:enumeration value=\"LocatorBW\"/>
					<s:enumeration value=\"TerrainBW\"/>
					<s:enumeration value=\"RoadBW\"/>
					<s:enumeration value=\"PoliticalBW\"/>
					<s:enumeration value=\"SmallBW\"/>
					<s:enumeration value=\"Comprehensive\"/>
					<s:enumeration value=\"PhysicalFeatures\"/>
					<s:enumeration value=\"Tectonic\"/>
					<s:enumeration value=\"EarthByDay\"/>
					<s:enumeration value=\"EarthByNight\"/>
					<s:enumeration value=\"Ecoregions\"/>
					<s:enumeration value=\"Climate\"/>
					<s:enumeration value=\"TemperatureJanuary\"/>
					<s:enumeration value=\"TemperatureJuly\"/>
					<s:enumeration value=\"PrecipitationJanuary\"/>
					<s:enumeration value=\"PrecipitationJuly\"/>
					<s:enumeration value=\"PrecipitationAnnual\"/>
					<s:enumeration value=\"Languages\"/>
					<s:enumeration value=\"Religions\"/>
					<s:enumeration value=\"PopulationDensity\"/>
					<s:enumeration value=\"Parks\"/>
					<s:enumeration value=\"TimeZones\"/>
					<s:enumeration value=\"Outline\"/>
					<s:enumeration value=\"Phone\"/>
					<s:enumeration value=\"PhoneBW\"/>
					<s:enumeration value=\"Night\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"ArrayOfPushpin\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Pushpin\" nillable=\"true\" type=\"tns:Pushpin\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Pushpin\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"IconDataSource\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"IconName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Label\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PinID\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Pixel\" type=\"tns:PixelCoord\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ReturnsHotArea\" type=\"s:boolean\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"LabelNearbyRoads\" type=\"s:boolean\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"PixelCoord\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"X\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Y\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfMapView\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"MapView\" nillable=\"true\" type=\"tns:MapView\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"MapImage\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"HotAreas\" type=\"tns:ArrayOfHotArea\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"MimeData\" type=\"tns:MimeData\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"View\" type=\"tns:MapViewRepresentations\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Url\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfHotArea\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"HotArea\" nillable=\"true\" type=\"tns:HotArea\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"HotArea\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"IconRectangle\" type=\"tns:PixelRectangle\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LabelRectangle\" type=\"tns:PixelRectangle\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PinID\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"PixelRectangle\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Bottom\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Left\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Right\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Top\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"MimeData\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Bits\" type=\"s:base64Binary\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ContentID\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"MimeType\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfMapImage\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"MapImage\" nillable=\"true\" type=\"tns:MapImage\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetMapResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetMapResult\" type=\"tns:ArrayOfMapImage\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"CustomerInfoRenderHeader\" type=\"tns:CustomerInfoRenderHeader\"/>
			<s:complexType name=\"CustomerInfoRenderHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:CustomerInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"UserInfoRenderHeader\" type=\"tns:UserInfoRenderHeader\"/>
			<s:complexType name=\"UserInfoRenderHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:UserInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"ConvertToPoint\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"latLong\" type=\"tns:ArrayOfLatLong\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"view\" type=\"tns:MapView\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"width\" type=\"s:int\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"height\" type=\"s:int\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfPixelCoord\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"PixelCoord\" nillable=\"true\" type=\"tns:PixelCoord\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"ConvertToPointResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ConvertToPointResult\" type=\"tns:ArrayOfPixelCoord\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"ConvertToLatLong\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"pixels\" type=\"tns:ArrayOfPixelCoord\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"view\" type=\"tns:MapView\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"width\" type=\"s:int\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"height\" type=\"s:int\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"ConvertToLatLongResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ConvertToLatLongResult\" type=\"tns:ArrayOfLatLong\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetBestMapView\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"locations\" type=\"tns:ArrayOfLocation\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"dataSourceName\" type=\"s:string\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetBestMapViewResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetBestMapViewResult\" type=\"tns:MapViewRepresentations\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetLineDriveMap\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:LineDriveMapSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"LineDriveMapSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Route\" type=\"tns:Route\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:LineDriveMapOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"LineDriveMapOptions\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Format\" type=\"tns:ImageFormat\"/>
					<s:element default=\"ReturnImage\" maxOccurs=\"1\" minOccurs=\"0\" name=\"ReturnType\" type=\"tns:MapReturnType\"/>
					<s:element default=\"Smaller\" maxOccurs=\"1\" minOccurs=\"0\" name=\"FontSize\" type=\"tns:MapFontSize\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"PaletteType\" type=\"tns:PaletteType\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DestinationIconDataSource\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DestinationIconName\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"PaletteType\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Color\"/>
					<s:enumeration value=\"GrayScale\"/>
					<s:enumeration value=\"Monochrome\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"LineDriveMapImage\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"MimeData\" type=\"tns:MimeData\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Url\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"View\" type=\"tns:MapViewRepresentations\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"FirstDirectionID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"LastDirectionID\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfLineDriveMapImage\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"LineDriveMapImage\" nillable=\"true\" type=\"tns:LineDriveMapImage\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetLineDriveMapResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetLineDriveMapResult\" type=\"tns:ArrayOfLineDriveMapImage\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
		</s:schema>
	</wsdl:types>
	<wsdl:message name=\"GetVersionInfoSoapIn\">
		<wsdl:part element=\"tns:GetVersionInfo\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetVersionInfoSoapOut\">
		<wsdl:part element=\"tns:GetVersionInfoResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetVersionInfoCustomerInfoHeader\">
		<wsdl:part element=\"tns:CustomerInfoHeader\" name=\"CustomerInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetVersionInfoUserInfoHeader\">
		<wsdl:part element=\"tns:UserInfoHeader\" name=\"UserInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetCountryRegionInfoSoapIn\">
		<wsdl:part element=\"tns:GetCountryRegionInfo\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetCountryRegionInfoSoapOut\">
		<wsdl:part element=\"tns:GetCountryRegionInfoResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetCountryRegionInfoCustomerInfoHeader\">
		<wsdl:part element=\"tns:CustomerInfoHeader\" name=\"CustomerInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetCountryRegionInfoUserInfoHeader\">
		<wsdl:part element=\"tns:UserInfoHeader\" name=\"UserInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetEntityTypesSoapIn\">
		<wsdl:part element=\"tns:GetEntityTypes\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetEntityTypesSoapOut\">
		<wsdl:part element=\"tns:GetEntityTypesResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetEntityTypesCustomerInfoHeader\">
		<wsdl:part element=\"tns:CustomerInfoHeader\" name=\"CustomerInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetEntityTypesUserInfoHeader\">
		<wsdl:part element=\"tns:UserInfoHeader\" name=\"UserInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetDataSourceInfoSoapIn\">
		<wsdl:part element=\"tns:GetDataSourceInfo\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetDataSourceInfoSoapOut\">
		<wsdl:part element=\"tns:GetDataSourceInfoResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetDataSourceInfoCustomerInfoHeader\">
		<wsdl:part element=\"tns:CustomerInfoHeader\" name=\"CustomerInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetDataSourceInfoUserInfoHeader\">
		<wsdl:part element=\"tns:UserInfoHeader\" name=\"UserInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetGreatCircleDistancesSoapIn\">
		<wsdl:part element=\"tns:GetGreatCircleDistances\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetGreatCircleDistancesSoapOut\">
		<wsdl:part element=\"tns:GetGreatCircleDistancesResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetGreatCircleDistancesCustomerInfoHeader\">
		<wsdl:part element=\"tns:CustomerInfoHeader\" name=\"CustomerInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetGreatCircleDistancesUserInfoHeader\">
		<wsdl:part element=\"tns:UserInfoHeader\" name=\"UserInfoHeader\"/>
	</wsdl:message>
	<wsdl:portType name=\"CommonServiceSoap\">
		<wsdl:operation name=\"GetVersionInfo\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Get the MapPoint Web Service version.</documentation>
			<wsdl:input message=\"tns:GetVersionInfoSoapIn\"/>
			<wsdl:output message=\"tns:GetVersionInfoSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetCountryRegionInfo\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Retrieve information about countries or national regions.</documentation>
			<wsdl:input message=\"tns:GetCountryRegionInfoSoapIn\"/>
			<wsdl:output message=\"tns:GetCountryRegionInfoSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetEntityTypes\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Retrieve the list types and their properties in a DataSource.</documentation>
			<wsdl:input message=\"tns:GetEntityTypesSoapIn\"/>
			<wsdl:output message=\"tns:GetEntityTypesSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetDataSourceInfo\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Get a general description of data sources.</documentation>
			<wsdl:input message=\"tns:GetDataSourceInfoSoapIn\"/>
			<wsdl:output message=\"tns:GetDataSourceInfoSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetGreatCircleDistances\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Calculate pair-wise distances </documentation>
			<wsdl:input message=\"tns:GetGreatCircleDistancesSoapIn\"/>
			<wsdl:output message=\"tns:GetGreatCircleDistancesSoapOut\"/>
		</wsdl:operation>
	</wsdl:portType>
	<wsdl:binding name=\"CommonServiceSoap\" type=\"tns:CommonServiceSoap\">
		<soap:binding style=\"document\" transport=\"http://schemas.xmlsoap.org/soap/http\"/>
		<wsdl:operation name=\"GetVersionInfo\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetVersionInfo\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetVersionInfoCustomerInfoHeader\" part=\"CustomerInfoHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetVersionInfoUserInfoHeader\" part=\"UserInfoHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetCountryRegionInfo\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetCountryRegionInfo\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetCountryRegionInfoCustomerInfoHeader\" part=\"CustomerInfoHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetCountryRegionInfoUserInfoHeader\" part=\"UserInfoHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetEntityTypes\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetEntityTypes\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetEntityTypesCustomerInfoHeader\" part=\"CustomerInfoHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetEntityTypesUserInfoHeader\" part=\"UserInfoHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetDataSourceInfo\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetDataSourceInfo\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetDataSourceInfoCustomerInfoHeader\" part=\"CustomerInfoHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetDataSourceInfoUserInfoHeader\" part=\"UserInfoHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetGreatCircleDistances\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetGreatCircleDistances\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetGreatCircleDistancesCustomerInfoHeader\" part=\"CustomerInfoHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetGreatCircleDistancesUserInfoHeader\" part=\"UserInfoHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
	</wsdl:binding>
	<wsdl:service name=\"CommonService\">
		<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">The common service contains classes, methods, and properties that are common to the find, route, and render services.  The common service also provides basic utility functions that can be used in the Microsoft MapPoint Web Service applications.&lt;/p&gt;&lt;p class=&quot;intro&quot;&gt;Read the &lt;a href=&quot;default.htm&quot;&gt;formal description&lt;/a&gt; of the MapPoint Web Service for more information.</documentation>
		<wsdl:port binding=\"tns:CommonServiceSoap\" name=\"CommonServiceSoap\">
			<soap:address location=\"http://findv3.staging.mappoint.net/Find-30/Common.asmx\"/>
		</wsdl:port>
	</wsdl:service>
	<wsdl:message name=\"FindSoapIn\">
		<wsdl:part element=\"tns:Find\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindSoapOut\">
		<wsdl:part element=\"tns:FindResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindAddressSoapIn\">
		<wsdl:part element=\"tns:FindAddress\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindAddressSoapOut\">
		<wsdl:part element=\"tns:FindAddressResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindAddressCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindAddressUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ParseAddressSoapIn\">
		<wsdl:part element=\"tns:ParseAddress\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ParseAddressSoapOut\">
		<wsdl:part element=\"tns:ParseAddressResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ParseAddressCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ParseAddressUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLocationInfoSoapIn\">
		<wsdl:part element=\"tns:GetLocationInfo\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLocationInfoSoapOut\">
		<wsdl:part element=\"tns:GetLocationInfoResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLocationInfoCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLocationInfoUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearbySoapIn\">
		<wsdl:part element=\"tns:FindNearby\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearbySoapOut\">
		<wsdl:part element=\"tns:FindNearbyResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearbyCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearbyUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByPropertySoapIn\">
		<wsdl:part element=\"tns:FindByProperty\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByPropertySoapOut\">
		<wsdl:part element=\"tns:FindByPropertyResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByPropertyCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByPropertyUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByIDSoapIn\">
		<wsdl:part element=\"tns:FindByID\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByIDSoapOut\">
		<wsdl:part element=\"tns:FindByIDResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByIDCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByIDUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearRouteSoapIn\">
		<wsdl:part element=\"tns:FindNearRoute\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearRouteSoapOut\">
		<wsdl:part element=\"tns:FindNearRouteResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearRouteCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearRouteUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindPolygonSoapIn\">
		<wsdl:part element=\"tns:FindPolygon\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindPolygonSoapOut\">
		<wsdl:part element=\"tns:FindPolygonResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindPolygonCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindPolygonUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:portType name=\"FindServiceSoap\">
		<wsdl:operation name=\"Find\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds places based on the find options.</documentation>
			<wsdl:input message=\"tns:FindSoapIn\"/>
			<wsdl:output message=\"tns:FindSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindAddress\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds a list of addresses that match the input address.</documentation>
			<wsdl:input message=\"tns:FindAddressSoapIn\"/>
			<wsdl:output message=\"tns:FindAddressSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"ParseAddress\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Parses Address.FormattedAddress into its component Address pieces.</documentation>
			<wsdl:input message=\"tns:ParseAddressSoapIn\"/>
			<wsdl:output message=\"tns:ParseAddressSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetLocationInfo\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Searches around a LatLong for nearest addresses and entities.</documentation>
			<wsdl:input message=\"tns:GetLocationInfoSoapIn\"/>
			<wsdl:output message=\"tns:GetLocationInfoSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindNearby\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Find a list of POI, within a circle around a lat/long.</documentation>
			<wsdl:input message=\"tns:FindNearbySoapIn\"/>
			<wsdl:output message=\"tns:FindNearbySoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindByProperty\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds points of interest based on pre-defined or custom properties. This method is independent of the location information such as distance and latitude/logitude.</documentation>
			<wsdl:input message=\"tns:FindByPropertySoapIn\"/>
			<wsdl:output message=\"tns:FindByPropertySoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindByID\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds points of interest for a given entity ID.</documentation>
			<wsdl:input message=\"tns:FindByIDSoapIn\"/>
			<wsdl:output message=\"tns:FindByIDSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindNearRoute\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds points of interest locations within a specified distance from a route.</documentation>
			<wsdl:input message=\"tns:FindNearRouteSoapIn\"/>
			<wsdl:output message=\"tns:FindNearRouteSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindPolygon\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds polygons containing a point or intersecting a rectangle.</documentation>
			<wsdl:input message=\"tns:FindPolygonSoapIn\"/>
			<wsdl:output message=\"tns:FindPolygonSoapOut\"/>
		</wsdl:operation>
	</wsdl:portType>
	<wsdl:binding name=\"FindServiceSoap\" type=\"tns:FindServiceSoap\">
		<soap:binding style=\"document\" transport=\"http://schemas.xmlsoap.org/soap/http\"/>
		<wsdl:operation name=\"Find\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/Find\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindAddress\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindAddress\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindAddressCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindAddressUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"ParseAddress\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/ParseAddress\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:ParseAddressCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:ParseAddressUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetLocationInfo\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetLocationInfo\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetLocationInfoCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetLocationInfoUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindNearby\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindNearby\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindNearbyCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindNearbyUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindByProperty\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindByProperty\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindByPropertyCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindByPropertyUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindByID\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindByID\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindByIDCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindByIDUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindNearRoute\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindNearRoute\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindNearRouteCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindNearRouteUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindPolygon\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindPolygon\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindPolygonCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindPolygonUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
	</wsdl:binding>
	<wsdl:service name=\"FindService\">
		<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">The Find service allows you to locate addresses, places, latitude/longitude coordinates, and points of interest (from either MapPoint Web Service data or your data that we host for your use).</documentation>
		<wsdl:port binding=\"tns:FindServiceSoap\" name=\"FindServiceSoap\">
			<soap:address location=\"http://findv3.staging.mappoint.net/Find-30/FindService.asmx\"/>
		</wsdl:port>
	</wsdl:service>
	<wsdl:message name=\"CalculateSimpleRouteSoapIn\">
		<wsdl:part element=\"tns:CalculateSimpleRoute\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateSimpleRouteSoapOut\">
		<wsdl:part element=\"tns:CalculateSimpleRouteResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateSimpleRouteCustomerInfoRouteHeader\">
		<wsdl:part element=\"tns:CustomerInfoRouteHeader\" name=\"CustomerInfoRouteHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateSimpleRouteUserInfoRouteHeader\">
		<wsdl:part element=\"tns:UserInfoRouteHeader\" name=\"UserInfoRouteHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateRouteSoapIn\">
		<wsdl:part element=\"tns:CalculateRoute\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateRouteSoapOut\">
		<wsdl:part element=\"tns:CalculateRouteResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateRouteCustomerInfoRouteHeader\">
		<wsdl:part element=\"tns:CustomerInfoRouteHeader\" name=\"CustomerInfoRouteHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateRouteUserInfoRouteHeader\">
		<wsdl:part element=\"tns:UserInfoRouteHeader\" name=\"UserInfoRouteHeader\"/>
	</wsdl:message>
	<wsdl:portType name=\"RouteServiceSoap\">
		<wsdl:operation name=\"CalculateSimpleRoute\">
			<wsdl:input message=\"tns:CalculateSimpleRouteSoapIn\"/>
			<wsdl:output message=\"tns:CalculateSimpleRouteSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"CalculateRoute\">
			<wsdl:input message=\"tns:CalculateRouteSoapIn\"/>
			<wsdl:output message=\"tns:CalculateRouteSoapOut\"/>
		</wsdl:operation>
	</wsdl:portType>
	<wsdl:binding name=\"RouteServiceSoap\" type=\"tns:RouteServiceSoap\">
		<soap:binding style=\"document\" transport=\"http://schemas.xmlsoap.org/soap/http\"/>
		<wsdl:operation name=\"CalculateSimpleRoute\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/CalculateSimpleRoute\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:CalculateSimpleRouteCustomerInfoRouteHeader\" part=\"CustomerInfoRouteHeader\" use=\"literal\"/>
				<soap:header message=\"tns:CalculateSimpleRouteUserInfoRouteHeader\" part=\"UserInfoRouteHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"CalculateRoute\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/CalculateRoute\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:CalculateRouteCustomerInfoRouteHeader\" part=\"CustomerInfoRouteHeader\" use=\"literal\"/>
				<soap:header message=\"tns:CalculateRouteUserInfoRouteHeader\" part=\"UserInfoRouteHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
	</wsdl:binding>
	<wsdl:service name=\"RouteService\">
		<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">The route service allows you to generate routes, driving directions, and calculated route representations (used to render a highlighted route on the map) based on locations or waypoints, set segment and route preferences, and generate map views of segments and directions.</documentation>
		<wsdl:port binding=\"tns:RouteServiceSoap\" name=\"RouteServiceSoap\">
			<soap:address location=\"http://routev3.staging.mappoint.net/Route-30/RouteService.asmx\"/>
		</wsdl:port>
	</wsdl:service>
	<wsdl:message name=\"GetMapSoapIn\">
		<wsdl:part element=\"tns:GetMap\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetMapSoapOut\">
		<wsdl:part element=\"tns:GetMapResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetMapCustomerInfoRenderHeader\">
		<wsdl:part element=\"tns:CustomerInfoRenderHeader\" name=\"CustomerInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetMapUserInfoRenderHeader\">
		<wsdl:part element=\"tns:UserInfoRenderHeader\" name=\"UserInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToPointSoapIn\">
		<wsdl:part element=\"tns:ConvertToPoint\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToPointSoapOut\">
		<wsdl:part element=\"tns:ConvertToPointResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToPointCustomerInfoRenderHeader\">
		<wsdl:part element=\"tns:CustomerInfoRenderHeader\" name=\"CustomerInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToPointUserInfoRenderHeader\">
		<wsdl:part element=\"tns:UserInfoRenderHeader\" name=\"UserInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToLatLongSoapIn\">
		<wsdl:part element=\"tns:ConvertToLatLong\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToLatLongSoapOut\">
		<wsdl:part element=\"tns:ConvertToLatLongResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToLatLongCustomerInfoRenderHeader\">
		<wsdl:part element=\"tns:CustomerInfoRenderHeader\" name=\"CustomerInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToLatLongUserInfoRenderHeader\">
		<wsdl:part element=\"tns:UserInfoRenderHeader\" name=\"UserInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetBestMapViewSoapIn\">
		<wsdl:part element=\"tns:GetBestMapView\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetBestMapViewSoapOut\">
		<wsdl:part element=\"tns:GetBestMapViewResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetBestMapViewCustomerInfoRenderHeader\">
		<wsdl:part element=\"tns:CustomerInfoRenderHeader\" name=\"CustomerInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetBestMapViewUserInfoRenderHeader\">
		<wsdl:part element=\"tns:UserInfoRenderHeader\" name=\"UserInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLineDriveMapSoapIn\">
		<wsdl:part element=\"tns:GetLineDriveMap\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLineDriveMapSoapOut\">
		<wsdl:part element=\"tns:GetLineDriveMapResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLineDriveMapCustomerInfoRenderHeader\">
		<wsdl:part element=\"tns:CustomerInfoRenderHeader\" name=\"CustomerInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLineDriveMapUserInfoRenderHeader\">
		<wsdl:part element=\"tns:UserInfoRenderHeader\" name=\"UserInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:portType name=\"RenderServiceSoap\">
		<wsdl:operation name=\"GetMap\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Renders map images of the given MapViews</documentation>
			<wsdl:input message=\"tns:GetMapSoapIn\"/>
			<wsdl:output message=\"tns:GetMapSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"ConvertToPoint\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Convert individual LatLongs into PixelCoords as they would appear in the given MapView</documentation>
			<wsdl:input message=\"tns:ConvertToPointSoapIn\"/>
			<wsdl:output message=\"tns:ConvertToPointSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"ConvertToLatLong\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Convert individual PixelCoords into LatLongs as they would appear in the given MapView</documentation>
			<wsdl:input message=\"tns:ConvertToLatLongSoapIn\"/>
			<wsdl:output message=\"tns:ConvertToLatLongSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetBestMapView\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Get a MapView that encompasses the given locations</documentation>
			<wsdl:input message=\"tns:GetBestMapViewSoapIn\"/>
			<wsdl:output message=\"tns:GetBestMapViewSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetLineDriveMap\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Renders LineDrive map images of the given Route</documentation>
			<wsdl:input message=\"tns:GetLineDriveMapSoapIn\"/>
			<wsdl:output message=\"tns:GetLineDriveMapSoapOut\"/>
		</wsdl:operation>
	</wsdl:portType>
	<wsdl:binding name=\"RenderServiceSoap\" type=\"tns:RenderServiceSoap\">
		<soap:binding style=\"document\" transport=\"http://schemas.xmlsoap.org/soap/http\"/>
		<wsdl:operation name=\"GetMap\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetMap\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetMapCustomerInfoRenderHeader\" part=\"CustomerInfoRenderHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetMapUserInfoRenderHeader\" part=\"UserInfoRenderHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"ConvertToPoint\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/ConvertToPoint\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:ConvertToPointCustomerInfoRenderHeader\" part=\"CustomerInfoRenderHeader\" use=\"literal\"/>
				<soap:header message=\"tns:ConvertToPointUserInfoRenderHeader\" part=\"UserInfoRenderHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"ConvertToLatLong\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/ConvertToLatLong\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:ConvertToLatLongCustomerInfoRenderHeader\" part=\"CustomerInfoRenderHeader\" use=\"literal\"/>
				<soap:header message=\"tns:ConvertToLatLongUserInfoRenderHeader\" part=\"UserInfoRenderHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetBestMapView\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetBestMapView\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetBestMapViewCustomerInfoRenderHeader\" part=\"CustomerInfoRenderHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetBestMapViewUserInfoRenderHeader\" part=\"UserInfoRenderHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetLineDriveMap\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetLineDriveMap\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetLineDriveMapCustomerInfoRenderHeader\" part=\"CustomerInfoRenderHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetLineDriveMapUserInfoRenderHeader\" part=\"UserInfoRenderHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
	</wsdl:binding>
	<wsdl:service name=\"RenderService\">
		<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">The render service allows you to render maps of routes and found locations, place pushpins (using the MapPoint Web Service stock set of icons or your icons that we host for your use), set the map size and map view, select points on a map, get location information about points on a map, pan and zoom a rendered map, and create clickable maps.</documentation>
		<wsdl:port binding=\"tns:RenderServiceSoap\" name=\"RenderServiceSoap\">
			<soap:address location=\"http://renderv3.staging.mappoint.net/Render-30/RenderService.asmx\"/>
		</wsdl:port>
	</wsdl:service>
</wsdl:definitions>"""

    def __init__(self, post='/Render-30/RenderService.asmx', **kw):
        ServiceSOAPBinding.__init__(self, post)

    def soap_GetMap(self, ps):
        self.request = ps.Parse(GetMapSoapIn.typecode)
        return GetMapSoapOut()

    soapAction['http://s.mappoint.net/mappoint-30/GetMap'] = 'soap_GetMap'
    root[(GetMapSoapIn.typecode.nspname,GetMapSoapIn.typecode.pname)] = 'soap_GetMap'

    def soap_ConvertToPoint(self, ps):
        self.request = ps.Parse(ConvertToPointSoapIn.typecode)
        return ConvertToPointSoapOut()

    soapAction['http://s.mappoint.net/mappoint-30/ConvertToPoint'] = 'soap_ConvertToPoint'
    root[(ConvertToPointSoapIn.typecode.nspname,ConvertToPointSoapIn.typecode.pname)] = 'soap_ConvertToPoint'

    def soap_ConvertToLatLong(self, ps):
        self.request = ps.Parse(ConvertToLatLongSoapIn.typecode)
        return ConvertToLatLongSoapOut()

    soapAction['http://s.mappoint.net/mappoint-30/ConvertToLatLong'] = 'soap_ConvertToLatLong'
    root[(ConvertToLatLongSoapIn.typecode.nspname,ConvertToLatLongSoapIn.typecode.pname)] = 'soap_ConvertToLatLong'

    def soap_GetBestMapView(self, ps):
        self.request = ps.Parse(GetBestMapViewSoapIn.typecode)
        return GetBestMapViewSoapOut()

    soapAction['http://s.mappoint.net/mappoint-30/GetBestMapView'] = 'soap_GetBestMapView'
    root[(GetBestMapViewSoapIn.typecode.nspname,GetBestMapViewSoapIn.typecode.pname)] = 'soap_GetBestMapView'

    def soap_GetLineDriveMap(self, ps):
        self.request = ps.Parse(GetLineDriveMapSoapIn.typecode)
        return GetLineDriveMapSoapOut()

    soapAction['http://s.mappoint.net/mappoint-30/GetLineDriveMap'] = 'soap_GetLineDriveMap'
    root[(GetLineDriveMapSoapIn.typecode.nspname,GetLineDriveMapSoapIn.typecode.pname)] = 'soap_GetLineDriveMap'

class CommonService(ServiceSOAPBinding):
    soapAction = {}
    root = {}
    _wsdl = """<?xml version=\"1.0\" ?>
<wsdl:definitions targetNamespace=\"http://s.mappoint.net/mappoint-30/\" xmlns:http=\"http://schemas.xmlsoap.org/wsdl/http/\" xmlns:mime=\"http://schemas.xmlsoap.org/wsdl/mime/\" xmlns:s=\"http://www.w3.org/2001/XMLSchema\" xmlns:soap=\"http://schemas.xmlsoap.org/wsdl/soap/\" xmlns:soapenc=\"http://schemas.xmlsoap.org/soap/encoding/\" xmlns:tm=\"http://microsoft.com/wsdl/mime/textMatching/\" xmlns:tns=\"http://s.mappoint.net/mappoint-30/\" xmlns:wsdl=\"http://schemas.xmlsoap.org/wsdl/\">
	<wsdl:types>
		<s:schema elementFormDefault=\"qualified\" targetNamespace=\"http://s.mappoint.net/mappoint-30/\">
			<s:element name=\"GetVersionInfo\">
				<s:complexType/>
			</s:element>
			<s:element name=\"GetVersionInfoResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetVersionInfoResult\" type=\"tns:ArrayOfVersionInfo\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfVersionInfo\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"VersionInfo\" nillable=\"true\" type=\"tns:VersionInfo\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"VersionInfo\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Component\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Version\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"CustomerInfoHeader\" type=\"tns:CustomerInfoHeader\"/>
			<s:complexType name=\"CustomerInfoHeader\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"CustomLogEntry\" type=\"s:short\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"UserInfoHeader\" type=\"tns:UserInfoHeader\"/>
			<s:complexType name=\"UserInfoHeader\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Culture\" type=\"tns:CultureInfo\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"DefaultDistanceUnit\" type=\"tns:DistanceUnit\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Context\" type=\"tns:CountryRegionContext\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"CultureInfo\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Lcid\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"DistanceUnit\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Kilometer\"/>
					<s:enumeration value=\"Mile\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"CountryRegionContext\">
				<s:sequence>
					<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Iso2\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetCountryRegionInfo\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"entityIDs\" type=\"tns:ArrayOfInt\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfInt\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"int\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetCountryRegionInfoResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetCountryRegionInfoResult\" type=\"tns:ArrayOfCountryRegionInfo\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfCountryRegionInfo\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"CountryRegionInfo\" nillable=\"true\" type=\"tns:CountryRegionInfo\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"CountryRegionInfo\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"EntityID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Iso2\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Iso3\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FriendlyName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"OfficialName\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"LatLong\">
				<s:sequence>
					<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Latitude\" type=\"s:double\"/>
					<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Longitude\" type=\"s:double\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetEntityTypes\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"dataSourceName\" type=\"s:string\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetEntityTypesResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetEntityTypesResult\" type=\"tns:ArrayOfEntityType\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfEntityType\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"EntityType\" nillable=\"true\" type=\"tns:EntityType\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"EntityType\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DisplayName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ParentName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Definition\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Properties\" type=\"tns:ArrayOfEntityProperty\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfEntityProperty\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Property\" nillable=\"true\" type=\"tns:EntityProperty\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"EntityProperty\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DisplayName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataType\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetDataSourceInfo\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"dataSourceNames\" type=\"tns:ArrayOfString\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfString\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"string\" nillable=\"true\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetDataSourceInfoResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetDataSourceInfoResult\" type=\"tns:ArrayOfDataSource\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfDataSource\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"DataSource\" nillable=\"true\" type=\"tns:DataSource\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"DataSource\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Version\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Description\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Capability\" type=\"tns:DataSourceCapability\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityExtent\" type=\"tns:ArrayOfInt\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"DataSourceCapability\">
				<s:list>
					<s:simpleType>
						<s:restriction base=\"s:string\">
							<s:enumeration value=\"CanDrawMaps\"/>
							<s:enumeration value=\"CanFindPlaces\"/>
							<s:enumeration value=\"CanFindNearby\"/>
							<s:enumeration value=\"CanRoute\"/>
							<s:enumeration value=\"CanFindAddress\"/>
							<s:enumeration value=\"HasIcons\"/>
							<s:enumeration value=\"DataServiceQuery\"/>
						</s:restriction>
					</s:simpleType>
				</s:list>
			</s:simpleType>
			<s:element name=\"GetGreatCircleDistances\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"latLongs\" type=\"tns:ArrayOfLatLong\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfLatLong\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"LatLong\" nillable=\"true\" type=\"tns:LatLong\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetGreatCircleDistancesResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetGreatCircleDistancesResult\" type=\"tns:ArrayOfDouble\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfDouble\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"double\" type=\"s:double\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"Find\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"InputPlace\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityTypeNames\" type=\"tns:ArrayOfString\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"FindOptions\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Range\" type=\"tns:FindRange\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"SearchContext\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ResultMask\" type=\"tns:FindResultMask\"/>
					<s:element default=\"0.85\" maxOccurs=\"1\" minOccurs=\"0\" name=\"ThresholdScore\" type=\"s:double\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"FindRange\">
				<s:sequence>
					<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"StartIndex\" type=\"s:int\"/>
					<s:element default=\"25\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Count\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"FindResultMask\">
				<s:list>
					<s:simpleType>
						<s:restriction base=\"s:string\">
							<s:enumeration value=\"LatLongFlag\"/>
							<s:enumeration value=\"EntityFlag\"/>
							<s:enumeration value=\"AddressFlag\"/>
							<s:enumeration value=\"BestMapViewFlag\"/>
							<s:enumeration value=\"MatchDetailsFlag\"/>
						</s:restriction>
					</s:simpleType>
				</s:list>
			</s:simpleType>
			<s:element name=\"FindResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindResults\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"NumberFound\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"StartIndex\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Results\" type=\"tns:ArrayOfFindResult\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"TopScore\" type=\"s:double\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfFindResult\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"FindResult\" nillable=\"true\" type=\"tns:FindResult\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"FindResult\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Score\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FoundLocation\" type=\"tns:Location\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Location\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Entity\" type=\"tns:Entity\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Address\" type=\"tns:Address\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"BestMapView\" type=\"tns:MapViewRepresentations\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Entity\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DisplayName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"TypeName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Properties\" type=\"tns:ArrayOfEntityPropertyValue\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfEntityPropertyValue\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Property\" nillable=\"true\" type=\"tns:EntityPropertyValue\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"EntityPropertyValue\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Value\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Address\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"AddressLine\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PrimaryCity\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"SecondaryCity\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Subdivision\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PostalCode\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CountryRegion\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FormattedAddress\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"MapViewRepresentations\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ByScale\" type=\"tns:ViewByScale\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ByHeightWidth\" type=\"tns:ViewByHeightWidth\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ByBoundingRectangle\" type=\"tns:ViewByBoundingRectangle\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ViewByScale\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:MapView\">
						<s:sequence>
							<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"MapScale\" type=\"s:double\"/>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CenterPoint\" type=\"tns:LatLong\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:complexType abstract=\"true\" name=\"MapView\"/>
			<s:complexType name=\"ViewByBoundingLocations\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:MapView\">
						<s:sequence>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Locations\" type=\"tns:ArrayOfLocation\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:complexType name=\"ArrayOfLocation\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Location\" nillable=\"true\" type=\"tns:Location\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ViewByHeightWidth\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:MapView\">
						<s:sequence>
							<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Height\" type=\"s:double\"/>
							<s:element default=\"0\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Width\" type=\"s:double\"/>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CenterPoint\" type=\"tns:LatLong\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:complexType name=\"ViewByBoundingRectangle\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:MapView\">
						<s:sequence>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"BoundingRectangle\" type=\"tns:LatLongRectangle\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:complexType name=\"LatLongRectangle\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Southwest\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Northeast\" type=\"tns:LatLong\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"MapPointConstants\">
				<s:sequence>
					<s:element default=\"6378.2\" maxOccurs=\"1\" minOccurs=\"0\" name=\"EarthRadiusInKilometers\" type=\"s:double\"/>
					<s:element default=\"3.1415926535897931\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Pi\" type=\"s:double\"/>
					<s:element default=\"0.017453292519943295\" maxOccurs=\"1\" minOccurs=\"0\" name=\"RadiansPerDegree\" type=\"s:double\"/>
					<s:element default=\"57.295779513082323\" maxOccurs=\"1\" minOccurs=\"0\" name=\"DegreesPerRadian\" type=\"s:double\"/>
					<s:element default=\"0.621371192237334\" maxOccurs=\"1\" minOccurs=\"0\" name=\"MilesPerKilometer\" type=\"s:double\"/>
					<s:element default=\"1.609344\" maxOccurs=\"1\" minOccurs=\"0\" name=\"KilometersPerMile\" type=\"s:double\"/>
					<s:element default=\"0.0003048\" maxOccurs=\"1\" minOccurs=\"0\" name=\"KilometersPerFoot\" type=\"s:double\"/>
					<s:element default=\"3280.8398950131232\" maxOccurs=\"1\" minOccurs=\"0\" name=\"FeetPerKilometer\" type=\"s:double\"/>
					<s:element default=\"0.85\" maxOccurs=\"1\" minOccurs=\"0\" name=\"FindScoreThreshold\" type=\"s:double\"/>
					<s:element default=\"96\" maxOccurs=\"1\" minOccurs=\"0\" name=\"AssumedDpi\" type=\"s:int\"/>
					<s:element default=\"3.280839895013123\" maxOccurs=\"1\" minOccurs=\"0\" name=\"FeetPerMeter\" type=\"s:double\"/>
					<s:element default=\"0.3048\" maxOccurs=\"1\" minOccurs=\"0\" name=\"MetersPerFoot\" type=\"s:double\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType abstract=\"true\" name=\"SpatialFilter\"/>
			<s:complexType name=\"LatLongSpatialFilter\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:SpatialFilter\">
						<s:sequence>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:complexType name=\"LatLongRectangleSpatialFilter\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:SpatialFilter\">
						<s:sequence>
							<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"BoundingRectangle\" type=\"tns:LatLongRectangle\"/>
							<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"PolygonRectangleRelation\" type=\"tns:SpatialRelation\"/>
						</s:sequence>
					</s:extension>
				</s:complexContent>
			</s:complexType>
			<s:simpleType name=\"SpatialRelation\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"WithinArea\"/>
					<s:enumeration value=\"TouchesArea\"/>
				</s:restriction>
			</s:simpleType>
			<s:element name=\"CustomerInfoFindHeader\" type=\"tns:CustomerInfoFindHeader\"/>
			<s:complexType name=\"CustomerInfoFindHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:CustomerInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"UserInfoFindHeader\" type=\"tns:UserInfoFindHeader\"/>
			<s:complexType name=\"UserInfoFindHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:UserInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"FindAddress\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindAddressSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindAddressSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"InputAddress\" type=\"tns:Address\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindAddressResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindAddressResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"ParseAddress\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"inputAddress\" type=\"s:string\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"countryRegion\" type=\"s:string\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"ParseAddressResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ParseAddressResult\" type=\"tns:Address\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetLocationInfo\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"location\" type=\"tns:LatLong\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"dataSourceName\" type=\"s:string\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"options\" type=\"tns:GetInfoOptions\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"GetInfoOptions\">
				<s:sequence>
					<s:element default=\"true\" maxOccurs=\"1\" minOccurs=\"0\" name=\"IncludeAddresses\" type=\"s:boolean\"/>
					<s:element default=\"true\" maxOccurs=\"1\" minOccurs=\"0\" name=\"IncludeAllEntityTypes\" type=\"s:boolean\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityTypesToReturn\" type=\"tns:ArrayOfString\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetLocationInfoResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetLocationInfoResult\" type=\"tns:ArrayOfLocation\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"FindNearby\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindNearbySpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindNearbySpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Distance\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Filter\" type=\"tns:FindFilter\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"FindFilter\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityTypeName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PropertyNames\" type=\"tns:ArrayOfString\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"WhereClause\" type=\"tns:WhereClause\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"SortProperties\" type=\"tns:ArrayOfSortProperty\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Expression\" type=\"tns:FilterExpression\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"WhereClause\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"SearchProperties\" type=\"tns:ArrayOfEntityPropertyValue\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"SearchOperator\" type=\"tns:SearchOperatorFlag\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"SearchOperatorFlag\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"And\"/>
					<s:enumeration value=\"Or\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"ArrayOfSortProperty\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"SortProperty\" nillable=\"true\" type=\"tns:SortProperty\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"SortProperty\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PropertyName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Direction\" type=\"tns:SortDirection\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"SortDirection\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Ascending\"/>
					<s:enumeration value=\"Descending\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"FilterExpression\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Text\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Parameters\" type=\"tns:ArrayOfAnyType\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfAnyType\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"anyType\" nillable=\"true\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindNearbyResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindNearbyResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"FindByProperty\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindByPropertySpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindByPropertySpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Filter\" type=\"tns:FindFilter\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindByPropertyResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindByPropertyResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"FindByID\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindByIDSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindByIDSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Filter\" type=\"tns:FindFilter\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"EntityIDs\" type=\"tns:ArrayOfInt\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindByIDResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindByIDResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"FindNearRoute\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindNearRouteSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindNearRouteSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Distance\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Filter\" type=\"tns:FindFilter\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Route\" type=\"tns:Route\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Route\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Specification\" type=\"tns:RouteSpecification\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Itinerary\" type=\"tns:RouteItinerary\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculatedRepresentation\" type=\"tns:CalculatedRouteRepresentation\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"RouteSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Segments\" type=\"tns:ArrayOfSegmentSpecification\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ResultMask\" type=\"tns:RouteResultMask\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DriverProfile\" type=\"tns:DriverProfile\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfSegmentSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"SegmentSpecification\" nillable=\"true\" type=\"tns:SegmentSpecification\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"SegmentSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Waypoint\" type=\"tns:Waypoint\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:SegmentOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Waypoint\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Location\" type=\"tns:Location\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Snap\" type=\"tns:SnapType\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Name\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculatedLocation\" type=\"tns:Location\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"SnapType\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Normal\"/>
					<s:enumeration value=\"City\"/>
					<s:enumeration value=\"NearestRoad\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"SegmentOptions\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Preference\" type=\"tns:SegmentPreference\"/>
					<s:element default=\"true\" maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculateSegmentMapView\" type=\"s:boolean\"/>
					<s:element default=\"true\" maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculateDirectionMapView\" type=\"s:boolean\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"SegmentPreference\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Quickest\"/>
					<s:enumeration value=\"Shortest\"/>
				</s:restriction>
			</s:simpleType>
			<s:simpleType name=\"RouteResultMask\">
				<s:list>
					<s:simpleType>
						<s:restriction base=\"s:string\">
							<s:enumeration value=\"Itinerary\"/>
							<s:enumeration value=\"CalculatedRouteRepresentation\"/>
						</s:restriction>
					</s:simpleType>
				</s:list>
			</s:simpleType>
			<s:complexType name=\"DriverProfile\">
				<s:sequence>
					<s:element default=\"-1\" maxOccurs=\"1\" minOccurs=\"0\" name=\"DayStartTime\" type=\"s:int\"/>
					<s:element default=\"-1\" maxOccurs=\"1\" minOccurs=\"0\" name=\"DayEndTime\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"RouteItinerary\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Segments\" type=\"tns:ArrayOfSegment\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"TripTime\" type=\"s:long\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"DrivingTime\" type=\"s:long\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Distance\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"View\" type=\"tns:MapViewRepresentations\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfSegment\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Segment\" nillable=\"true\" type=\"tns:Segment\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Segment\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Waypoint\" type=\"tns:Waypoint\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Directions\" type=\"tns:ArrayOfDirection\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"TripTime\" type=\"s:long\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"DrivingTime\" type=\"s:long\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Distance\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"View\" type=\"tns:MapViewRepresentations\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfDirection\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Direction\" nillable=\"true\" type=\"tns:Direction\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Direction\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"DirectionType\" type=\"tns:DirectionType\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Action\" type=\"tns:DirectionAction\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"BearingOutOfTurn\" type=\"s:float\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"BearingIntoTurn\" type=\"s:float\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Duration\" type=\"s:long\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Distance\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Towards\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Instruction\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FormattedInstruction\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"View\" type=\"tns:MapViewRepresentations\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"DirectionType\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Driving\"/>
					<s:enumeration value=\"Border\"/>
					<s:enumeration value=\"StartOfDay\"/>
					<s:enumeration value=\"EndOfDay\"/>
					<s:enumeration value=\"Warning\"/>
					<s:enumeration value=\"Waypoint\"/>
				</s:restriction>
			</s:simpleType>
			<s:simpleType name=\"DirectionAction\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Other\"/>
					<s:enumeration value=\"Depart\"/>
					<s:enumeration value=\"Arrive\"/>
					<s:enumeration value=\"TurnLeft\"/>
					<s:enumeration value=\"TurnRight\"/>
					<s:enumeration value=\"BearLeft\"/>
					<s:enumeration value=\"BearRight\"/>
					<s:enumeration value=\"Merge\"/>
					<s:enumeration value=\"Continue\"/>
					<s:enumeration value=\"TurnBack\"/>
					<s:enumeration value=\"TakeRoundabout\"/>
					<s:enumeration value=\"ConstructionDelay\"/>
					<s:enumeration value=\"ConstructionStop\"/>
					<s:enumeration value=\"NameChange\"/>
					<s:enumeration value=\"LeftLeft\"/>
					<s:enumeration value=\"LeftRight\"/>
					<s:enumeration value=\"RightLeft\"/>
					<s:enumeration value=\"RightRight\"/>
					<s:enumeration value=\"TakeRamp\"/>
					<s:enumeration value=\"TakeRampLeft\"/>
					<s:enumeration value=\"TakeRampRight\"/>
					<s:enumeration value=\"KeepStraight\"/>
					<s:enumeration value=\"KeepLeft\"/>
					<s:enumeration value=\"KeepRight\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"CalculatedRouteRepresentation\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Bits\" type=\"s:base64Binary\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindNearRouteResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindNearRouteResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"FindPolygon\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:FindPolygonSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"FindPolygonSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Filter\" type=\"tns:FindFilter\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:FindOptions\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"SpatialFilter\" type=\"tns:SpatialFilter\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"FindPolygonResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FindPolygonResult\" type=\"tns:FindResults\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"CalculateSimpleRoute\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"latLongs\" type=\"tns:ArrayOfLatLong\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"dataSourceName\" type=\"s:string\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"preference\" type=\"tns:SegmentPreference\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"CalculateSimpleRouteResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculateSimpleRouteResult\" type=\"tns:Route\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"CustomerInfoRouteHeader\" type=\"tns:CustomerInfoRouteHeader\"/>
			<s:complexType name=\"CustomerInfoRouteHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:CustomerInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"UserInfoRouteHeader\" type=\"tns:UserInfoRouteHeader\"/>
			<s:complexType name=\"UserInfoRouteHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:UserInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"CalculateRoute\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:RouteSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"CalculateRouteResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"CalculateRouteResult\" type=\"tns:Route\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetMap\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:MapSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"MapSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Polygons\" type=\"tns:ArrayOfPolygon\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"HighlightedEntityIDs\" type=\"tns:ArrayOfInt\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"HideEntityTypes\" type=\"tns:ArrayOfString\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:MapOptions\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Pushpins\" type=\"tns:ArrayOfPushpin\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Route\" type=\"tns:Route\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Views\" type=\"tns:ArrayOfMapView\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfPolygon\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Polygon\" nillable=\"true\" type=\"tns:Polygon\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Polygon\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DataSourceName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"EntityID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"BorderColor\" type=\"tns:ElementColor\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"FillColor\" type=\"tns:ElementColor\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Label\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ElementColor\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"A\" type=\"s:unsignedByte\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"R\" type=\"s:unsignedByte\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"G\" type=\"s:unsignedByte\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"B\" type=\"s:unsignedByte\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"MapOptions\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"RouteHighlightColor\" type=\"tns:RouteHighlightColor\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ConstructionDelayHighlightColor\" type=\"tns:RouteHighlightColor\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ConstructionClosureHighlightColor\" type=\"tns:RouteHighlightColor\"/>
					<s:element default=\"Smaller\" maxOccurs=\"1\" minOccurs=\"0\" name=\"FontSize\" type=\"tns:MapFontSize\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Format\" type=\"tns:ImageFormat\"/>
					<s:element default=\"false\" maxOccurs=\"1\" minOccurs=\"0\" name=\"IsOverviewMap\" type=\"s:boolean\"/>
					<s:element default=\"ReturnImage\" maxOccurs=\"1\" minOccurs=\"0\" name=\"ReturnType\" type=\"tns:MapReturnType\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"PanHorizontal\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"PanVertical\" type=\"s:double\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Style\" type=\"tns:MapStyle\"/>
					<s:element default=\"1\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Zoom\" type=\"s:double\"/>
					<s:element default=\"false\" maxOccurs=\"1\" minOccurs=\"0\" name=\"PreventIconCollisions\" type=\"s:boolean\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"RouteHighlightColor\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"DefaultColor\"/>
					<s:enumeration value=\"Green\"/>
					<s:enumeration value=\"Yellow\"/>
					<s:enumeration value=\"Cyan\"/>
					<s:enumeration value=\"Red\"/>
				</s:restriction>
			</s:simpleType>
			<s:simpleType name=\"MapFontSize\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Smallest\"/>
					<s:enumeration value=\"Smaller\"/>
					<s:enumeration value=\"Medium\"/>
					<s:enumeration value=\"Larger\"/>
					<s:enumeration value=\"Largest\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"ImageFormat\">
				<s:sequence>
					<s:element default=\"image/gif\" maxOccurs=\"1\" minOccurs=\"0\" name=\"MimeType\" type=\"s:string\"/>
					<s:element default=\"240\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Height\" type=\"s:int\"/>
					<s:element default=\"296\" maxOccurs=\"1\" minOccurs=\"0\" name=\"Width\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"MapReturnType\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"ReturnImage\"/>
					<s:enumeration value=\"ReturnUrl\"/>
					<s:enumeration value=\"ReturnSecureUrl\"/>
				</s:restriction>
			</s:simpleType>
			<s:simpleType name=\"MapStyle\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"DefaultStyle\"/>
					<s:enumeration value=\"Locator\"/>
					<s:enumeration value=\"Terrain\"/>
					<s:enumeration value=\"Road\"/>
					<s:enumeration value=\"Political\"/>
					<s:enumeration value=\"Small\"/>
					<s:enumeration value=\"LocatorBW\"/>
					<s:enumeration value=\"TerrainBW\"/>
					<s:enumeration value=\"RoadBW\"/>
					<s:enumeration value=\"PoliticalBW\"/>
					<s:enumeration value=\"SmallBW\"/>
					<s:enumeration value=\"Comprehensive\"/>
					<s:enumeration value=\"PhysicalFeatures\"/>
					<s:enumeration value=\"Tectonic\"/>
					<s:enumeration value=\"EarthByDay\"/>
					<s:enumeration value=\"EarthByNight\"/>
					<s:enumeration value=\"Ecoregions\"/>
					<s:enumeration value=\"Climate\"/>
					<s:enumeration value=\"TemperatureJanuary\"/>
					<s:enumeration value=\"TemperatureJuly\"/>
					<s:enumeration value=\"PrecipitationJanuary\"/>
					<s:enumeration value=\"PrecipitationJuly\"/>
					<s:enumeration value=\"PrecipitationAnnual\"/>
					<s:enumeration value=\"Languages\"/>
					<s:enumeration value=\"Religions\"/>
					<s:enumeration value=\"PopulationDensity\"/>
					<s:enumeration value=\"Parks\"/>
					<s:enumeration value=\"TimeZones\"/>
					<s:enumeration value=\"Outline\"/>
					<s:enumeration value=\"Phone\"/>
					<s:enumeration value=\"PhoneBW\"/>
					<s:enumeration value=\"Night\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"ArrayOfPushpin\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"Pushpin\" nillable=\"true\" type=\"tns:Pushpin\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"Pushpin\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"IconDataSource\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"IconName\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Label\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LatLong\" type=\"tns:LatLong\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PinID\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Pixel\" type=\"tns:PixelCoord\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"ReturnsHotArea\" type=\"s:boolean\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"LabelNearbyRoads\" type=\"s:boolean\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"PixelCoord\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"X\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Y\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfMapView\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"MapView\" nillable=\"true\" type=\"tns:MapView\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"MapImage\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"HotAreas\" type=\"tns:ArrayOfHotArea\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"MimeData\" type=\"tns:MimeData\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"View\" type=\"tns:MapViewRepresentations\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Url\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfHotArea\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"HotArea\" nillable=\"true\" type=\"tns:HotArea\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"HotArea\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"IconRectangle\" type=\"tns:PixelRectangle\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"LabelRectangle\" type=\"tns:PixelRectangle\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"PinID\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"PixelRectangle\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Bottom\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Left\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Right\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"Top\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"MimeData\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Bits\" type=\"s:base64Binary\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ContentID\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"MimeType\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfMapImage\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"MapImage\" nillable=\"true\" type=\"tns:MapImage\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetMapResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetMapResult\" type=\"tns:ArrayOfMapImage\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"CustomerInfoRenderHeader\" type=\"tns:CustomerInfoRenderHeader\"/>
			<s:complexType name=\"CustomerInfoRenderHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:CustomerInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"UserInfoRenderHeader\" type=\"tns:UserInfoRenderHeader\"/>
			<s:complexType name=\"UserInfoRenderHeader\">
				<s:complexContent mixed=\"false\">
					<s:extension base=\"tns:UserInfoHeader\"/>
				</s:complexContent>
			</s:complexType>
			<s:element name=\"ConvertToPoint\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"latLong\" type=\"tns:ArrayOfLatLong\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"view\" type=\"tns:MapView\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"width\" type=\"s:int\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"height\" type=\"s:int\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"ArrayOfPixelCoord\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"PixelCoord\" nillable=\"true\" type=\"tns:PixelCoord\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"ConvertToPointResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ConvertToPointResult\" type=\"tns:ArrayOfPixelCoord\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"ConvertToLatLong\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"pixels\" type=\"tns:ArrayOfPixelCoord\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"view\" type=\"tns:MapView\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"width\" type=\"s:int\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"height\" type=\"s:int\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"ConvertToLatLongResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"ConvertToLatLongResult\" type=\"tns:ArrayOfLatLong\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetBestMapView\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"locations\" type=\"tns:ArrayOfLocation\"/>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"dataSourceName\" type=\"s:string\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetBestMapViewResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetBestMapViewResult\" type=\"tns:MapViewRepresentations\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:element name=\"GetLineDriveMap\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"specification\" type=\"tns:LineDriveMapSpecification\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
			<s:complexType name=\"LineDriveMapSpecification\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Route\" type=\"tns:Route\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Options\" type=\"tns:LineDriveMapOptions\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"LineDriveMapOptions\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Format\" type=\"tns:ImageFormat\"/>
					<s:element default=\"ReturnImage\" maxOccurs=\"1\" minOccurs=\"0\" name=\"ReturnType\" type=\"tns:MapReturnType\"/>
					<s:element default=\"Smaller\" maxOccurs=\"1\" minOccurs=\"0\" name=\"FontSize\" type=\"tns:MapFontSize\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"PaletteType\" type=\"tns:PaletteType\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DestinationIconDataSource\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"DestinationIconName\" type=\"s:string\"/>
				</s:sequence>
			</s:complexType>
			<s:simpleType name=\"PaletteType\">
				<s:restriction base=\"s:string\">
					<s:enumeration value=\"Color\"/>
					<s:enumeration value=\"GrayScale\"/>
					<s:enumeration value=\"Monochrome\"/>
				</s:restriction>
			</s:simpleType>
			<s:complexType name=\"LineDriveMapImage\">
				<s:sequence>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"MimeData\" type=\"tns:MimeData\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"Url\" type=\"s:string\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"View\" type=\"tns:MapViewRepresentations\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"FirstDirectionID\" type=\"s:int\"/>
					<s:element maxOccurs=\"1\" minOccurs=\"1\" name=\"LastDirectionID\" type=\"s:int\"/>
				</s:sequence>
			</s:complexType>
			<s:complexType name=\"ArrayOfLineDriveMapImage\">
				<s:sequence>
					<s:element maxOccurs=\"unbounded\" minOccurs=\"0\" name=\"LineDriveMapImage\" nillable=\"true\" type=\"tns:LineDriveMapImage\"/>
				</s:sequence>
			</s:complexType>
			<s:element name=\"GetLineDriveMapResponse\">
				<s:complexType>
					<s:sequence>
						<s:element maxOccurs=\"1\" minOccurs=\"0\" name=\"GetLineDriveMapResult\" type=\"tns:ArrayOfLineDriveMapImage\"/>
					</s:sequence>
				</s:complexType>
			</s:element>
		</s:schema>
	</wsdl:types>
	<wsdl:message name=\"GetVersionInfoSoapIn\">
		<wsdl:part element=\"tns:GetVersionInfo\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetVersionInfoSoapOut\">
		<wsdl:part element=\"tns:GetVersionInfoResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetVersionInfoCustomerInfoHeader\">
		<wsdl:part element=\"tns:CustomerInfoHeader\" name=\"CustomerInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetVersionInfoUserInfoHeader\">
		<wsdl:part element=\"tns:UserInfoHeader\" name=\"UserInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetCountryRegionInfoSoapIn\">
		<wsdl:part element=\"tns:GetCountryRegionInfo\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetCountryRegionInfoSoapOut\">
		<wsdl:part element=\"tns:GetCountryRegionInfoResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetCountryRegionInfoCustomerInfoHeader\">
		<wsdl:part element=\"tns:CustomerInfoHeader\" name=\"CustomerInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetCountryRegionInfoUserInfoHeader\">
		<wsdl:part element=\"tns:UserInfoHeader\" name=\"UserInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetEntityTypesSoapIn\">
		<wsdl:part element=\"tns:GetEntityTypes\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetEntityTypesSoapOut\">
		<wsdl:part element=\"tns:GetEntityTypesResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetEntityTypesCustomerInfoHeader\">
		<wsdl:part element=\"tns:CustomerInfoHeader\" name=\"CustomerInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetEntityTypesUserInfoHeader\">
		<wsdl:part element=\"tns:UserInfoHeader\" name=\"UserInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetDataSourceInfoSoapIn\">
		<wsdl:part element=\"tns:GetDataSourceInfo\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetDataSourceInfoSoapOut\">
		<wsdl:part element=\"tns:GetDataSourceInfoResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetDataSourceInfoCustomerInfoHeader\">
		<wsdl:part element=\"tns:CustomerInfoHeader\" name=\"CustomerInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetDataSourceInfoUserInfoHeader\">
		<wsdl:part element=\"tns:UserInfoHeader\" name=\"UserInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetGreatCircleDistancesSoapIn\">
		<wsdl:part element=\"tns:GetGreatCircleDistances\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetGreatCircleDistancesSoapOut\">
		<wsdl:part element=\"tns:GetGreatCircleDistancesResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetGreatCircleDistancesCustomerInfoHeader\">
		<wsdl:part element=\"tns:CustomerInfoHeader\" name=\"CustomerInfoHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetGreatCircleDistancesUserInfoHeader\">
		<wsdl:part element=\"tns:UserInfoHeader\" name=\"UserInfoHeader\"/>
	</wsdl:message>
	<wsdl:portType name=\"CommonServiceSoap\">
		<wsdl:operation name=\"GetVersionInfo\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Get the MapPoint Web Service version.</documentation>
			<wsdl:input message=\"tns:GetVersionInfoSoapIn\"/>
			<wsdl:output message=\"tns:GetVersionInfoSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetCountryRegionInfo\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Retrieve information about countries or national regions.</documentation>
			<wsdl:input message=\"tns:GetCountryRegionInfoSoapIn\"/>
			<wsdl:output message=\"tns:GetCountryRegionInfoSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetEntityTypes\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Retrieve the list types and their properties in a DataSource.</documentation>
			<wsdl:input message=\"tns:GetEntityTypesSoapIn\"/>
			<wsdl:output message=\"tns:GetEntityTypesSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetDataSourceInfo\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Get a general description of data sources.</documentation>
			<wsdl:input message=\"tns:GetDataSourceInfoSoapIn\"/>
			<wsdl:output message=\"tns:GetDataSourceInfoSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetGreatCircleDistances\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Calculate pair-wise distances </documentation>
			<wsdl:input message=\"tns:GetGreatCircleDistancesSoapIn\"/>
			<wsdl:output message=\"tns:GetGreatCircleDistancesSoapOut\"/>
		</wsdl:operation>
	</wsdl:portType>
	<wsdl:binding name=\"CommonServiceSoap\" type=\"tns:CommonServiceSoap\">
		<soap:binding style=\"document\" transport=\"http://schemas.xmlsoap.org/soap/http\"/>
		<wsdl:operation name=\"GetVersionInfo\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetVersionInfo\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetVersionInfoCustomerInfoHeader\" part=\"CustomerInfoHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetVersionInfoUserInfoHeader\" part=\"UserInfoHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetCountryRegionInfo\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetCountryRegionInfo\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetCountryRegionInfoCustomerInfoHeader\" part=\"CustomerInfoHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetCountryRegionInfoUserInfoHeader\" part=\"UserInfoHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetEntityTypes\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetEntityTypes\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetEntityTypesCustomerInfoHeader\" part=\"CustomerInfoHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetEntityTypesUserInfoHeader\" part=\"UserInfoHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetDataSourceInfo\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetDataSourceInfo\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetDataSourceInfoCustomerInfoHeader\" part=\"CustomerInfoHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetDataSourceInfoUserInfoHeader\" part=\"UserInfoHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetGreatCircleDistances\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetGreatCircleDistances\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetGreatCircleDistancesCustomerInfoHeader\" part=\"CustomerInfoHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetGreatCircleDistancesUserInfoHeader\" part=\"UserInfoHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
	</wsdl:binding>
	<wsdl:service name=\"CommonService\">
		<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">The common service contains classes, methods, and properties that are common to the find, route, and render services.  The common service also provides basic utility functions that can be used in the Microsoft MapPoint Web Service applications.&lt;/p&gt;&lt;p class=&quot;intro&quot;&gt;Read the &lt;a href=&quot;default.htm&quot;&gt;formal description&lt;/a&gt; of the MapPoint Web Service for more information.</documentation>
		<wsdl:port binding=\"tns:CommonServiceSoap\" name=\"CommonServiceSoap\">
			<soap:address location=\"http://findv3.staging.mappoint.net/Find-30/Common.asmx\"/>
		</wsdl:port>
	</wsdl:service>
	<wsdl:message name=\"FindSoapIn\">
		<wsdl:part element=\"tns:Find\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindSoapOut\">
		<wsdl:part element=\"tns:FindResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindAddressSoapIn\">
		<wsdl:part element=\"tns:FindAddress\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindAddressSoapOut\">
		<wsdl:part element=\"tns:FindAddressResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindAddressCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindAddressUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ParseAddressSoapIn\">
		<wsdl:part element=\"tns:ParseAddress\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ParseAddressSoapOut\">
		<wsdl:part element=\"tns:ParseAddressResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ParseAddressCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ParseAddressUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLocationInfoSoapIn\">
		<wsdl:part element=\"tns:GetLocationInfo\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLocationInfoSoapOut\">
		<wsdl:part element=\"tns:GetLocationInfoResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLocationInfoCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLocationInfoUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearbySoapIn\">
		<wsdl:part element=\"tns:FindNearby\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearbySoapOut\">
		<wsdl:part element=\"tns:FindNearbyResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearbyCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearbyUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByPropertySoapIn\">
		<wsdl:part element=\"tns:FindByProperty\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByPropertySoapOut\">
		<wsdl:part element=\"tns:FindByPropertyResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByPropertyCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByPropertyUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByIDSoapIn\">
		<wsdl:part element=\"tns:FindByID\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByIDSoapOut\">
		<wsdl:part element=\"tns:FindByIDResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByIDCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindByIDUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearRouteSoapIn\">
		<wsdl:part element=\"tns:FindNearRoute\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearRouteSoapOut\">
		<wsdl:part element=\"tns:FindNearRouteResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearRouteCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindNearRouteUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindPolygonSoapIn\">
		<wsdl:part element=\"tns:FindPolygon\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindPolygonSoapOut\">
		<wsdl:part element=\"tns:FindPolygonResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"FindPolygonCustomerInfoFindHeader\">
		<wsdl:part element=\"tns:CustomerInfoFindHeader\" name=\"CustomerInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"FindPolygonUserInfoFindHeader\">
		<wsdl:part element=\"tns:UserInfoFindHeader\" name=\"UserInfoFindHeader\"/>
	</wsdl:message>
	<wsdl:portType name=\"FindServiceSoap\">
		<wsdl:operation name=\"Find\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds places based on the find options.</documentation>
			<wsdl:input message=\"tns:FindSoapIn\"/>
			<wsdl:output message=\"tns:FindSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindAddress\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds a list of addresses that match the input address.</documentation>
			<wsdl:input message=\"tns:FindAddressSoapIn\"/>
			<wsdl:output message=\"tns:FindAddressSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"ParseAddress\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Parses Address.FormattedAddress into its component Address pieces.</documentation>
			<wsdl:input message=\"tns:ParseAddressSoapIn\"/>
			<wsdl:output message=\"tns:ParseAddressSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetLocationInfo\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Searches around a LatLong for nearest addresses and entities.</documentation>
			<wsdl:input message=\"tns:GetLocationInfoSoapIn\"/>
			<wsdl:output message=\"tns:GetLocationInfoSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindNearby\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Find a list of POI, within a circle around a lat/long.</documentation>
			<wsdl:input message=\"tns:FindNearbySoapIn\"/>
			<wsdl:output message=\"tns:FindNearbySoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindByProperty\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds points of interest based on pre-defined or custom properties. This method is independent of the location information such as distance and latitude/logitude.</documentation>
			<wsdl:input message=\"tns:FindByPropertySoapIn\"/>
			<wsdl:output message=\"tns:FindByPropertySoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindByID\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds points of interest for a given entity ID.</documentation>
			<wsdl:input message=\"tns:FindByIDSoapIn\"/>
			<wsdl:output message=\"tns:FindByIDSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindNearRoute\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds points of interest locations within a specified distance from a route.</documentation>
			<wsdl:input message=\"tns:FindNearRouteSoapIn\"/>
			<wsdl:output message=\"tns:FindNearRouteSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"FindPolygon\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Finds polygons containing a point or intersecting a rectangle.</documentation>
			<wsdl:input message=\"tns:FindPolygonSoapIn\"/>
			<wsdl:output message=\"tns:FindPolygonSoapOut\"/>
		</wsdl:operation>
	</wsdl:portType>
	<wsdl:binding name=\"FindServiceSoap\" type=\"tns:FindServiceSoap\">
		<soap:binding style=\"document\" transport=\"http://schemas.xmlsoap.org/soap/http\"/>
		<wsdl:operation name=\"Find\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/Find\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindAddress\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindAddress\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindAddressCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindAddressUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"ParseAddress\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/ParseAddress\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:ParseAddressCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:ParseAddressUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetLocationInfo\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetLocationInfo\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetLocationInfoCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetLocationInfoUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindNearby\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindNearby\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindNearbyCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindNearbyUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindByProperty\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindByProperty\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindByPropertyCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindByPropertyUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindByID\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindByID\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindByIDCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindByIDUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindNearRoute\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindNearRoute\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindNearRouteCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindNearRouteUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"FindPolygon\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/FindPolygon\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:FindPolygonCustomerInfoFindHeader\" part=\"CustomerInfoFindHeader\" use=\"literal\"/>
				<soap:header message=\"tns:FindPolygonUserInfoFindHeader\" part=\"UserInfoFindHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
	</wsdl:binding>
	<wsdl:service name=\"FindService\">
		<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">The Find service allows you to locate addresses, places, latitude/longitude coordinates, and points of interest (from either MapPoint Web Service data or your data that we host for your use).</documentation>
		<wsdl:port binding=\"tns:FindServiceSoap\" name=\"FindServiceSoap\">
			<soap:address location=\"http://findv3.staging.mappoint.net/Find-30/FindService.asmx\"/>
		</wsdl:port>
	</wsdl:service>
	<wsdl:message name=\"CalculateSimpleRouteSoapIn\">
		<wsdl:part element=\"tns:CalculateSimpleRoute\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateSimpleRouteSoapOut\">
		<wsdl:part element=\"tns:CalculateSimpleRouteResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateSimpleRouteCustomerInfoRouteHeader\">
		<wsdl:part element=\"tns:CustomerInfoRouteHeader\" name=\"CustomerInfoRouteHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateSimpleRouteUserInfoRouteHeader\">
		<wsdl:part element=\"tns:UserInfoRouteHeader\" name=\"UserInfoRouteHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateRouteSoapIn\">
		<wsdl:part element=\"tns:CalculateRoute\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateRouteSoapOut\">
		<wsdl:part element=\"tns:CalculateRouteResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateRouteCustomerInfoRouteHeader\">
		<wsdl:part element=\"tns:CustomerInfoRouteHeader\" name=\"CustomerInfoRouteHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"CalculateRouteUserInfoRouteHeader\">
		<wsdl:part element=\"tns:UserInfoRouteHeader\" name=\"UserInfoRouteHeader\"/>
	</wsdl:message>
	<wsdl:portType name=\"RouteServiceSoap\">
		<wsdl:operation name=\"CalculateSimpleRoute\">
			<wsdl:input message=\"tns:CalculateSimpleRouteSoapIn\"/>
			<wsdl:output message=\"tns:CalculateSimpleRouteSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"CalculateRoute\">
			<wsdl:input message=\"tns:CalculateRouteSoapIn\"/>
			<wsdl:output message=\"tns:CalculateRouteSoapOut\"/>
		</wsdl:operation>
	</wsdl:portType>
	<wsdl:binding name=\"RouteServiceSoap\" type=\"tns:RouteServiceSoap\">
		<soap:binding style=\"document\" transport=\"http://schemas.xmlsoap.org/soap/http\"/>
		<wsdl:operation name=\"CalculateSimpleRoute\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/CalculateSimpleRoute\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:CalculateSimpleRouteCustomerInfoRouteHeader\" part=\"CustomerInfoRouteHeader\" use=\"literal\"/>
				<soap:header message=\"tns:CalculateSimpleRouteUserInfoRouteHeader\" part=\"UserInfoRouteHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"CalculateRoute\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/CalculateRoute\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:CalculateRouteCustomerInfoRouteHeader\" part=\"CustomerInfoRouteHeader\" use=\"literal\"/>
				<soap:header message=\"tns:CalculateRouteUserInfoRouteHeader\" part=\"UserInfoRouteHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
	</wsdl:binding>
	<wsdl:service name=\"RouteService\">
		<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">The route service allows you to generate routes, driving directions, and calculated route representations (used to render a highlighted route on the map) based on locations or waypoints, set segment and route preferences, and generate map views of segments and directions.</documentation>
		<wsdl:port binding=\"tns:RouteServiceSoap\" name=\"RouteServiceSoap\">
			<soap:address location=\"http://routev3.staging.mappoint.net/Route-30/RouteService.asmx\"/>
		</wsdl:port>
	</wsdl:service>
	<wsdl:message name=\"GetMapSoapIn\">
		<wsdl:part element=\"tns:GetMap\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetMapSoapOut\">
		<wsdl:part element=\"tns:GetMapResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetMapCustomerInfoRenderHeader\">
		<wsdl:part element=\"tns:CustomerInfoRenderHeader\" name=\"CustomerInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetMapUserInfoRenderHeader\">
		<wsdl:part element=\"tns:UserInfoRenderHeader\" name=\"UserInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToPointSoapIn\">
		<wsdl:part element=\"tns:ConvertToPoint\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToPointSoapOut\">
		<wsdl:part element=\"tns:ConvertToPointResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToPointCustomerInfoRenderHeader\">
		<wsdl:part element=\"tns:CustomerInfoRenderHeader\" name=\"CustomerInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToPointUserInfoRenderHeader\">
		<wsdl:part element=\"tns:UserInfoRenderHeader\" name=\"UserInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToLatLongSoapIn\">
		<wsdl:part element=\"tns:ConvertToLatLong\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToLatLongSoapOut\">
		<wsdl:part element=\"tns:ConvertToLatLongResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToLatLongCustomerInfoRenderHeader\">
		<wsdl:part element=\"tns:CustomerInfoRenderHeader\" name=\"CustomerInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"ConvertToLatLongUserInfoRenderHeader\">
		<wsdl:part element=\"tns:UserInfoRenderHeader\" name=\"UserInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetBestMapViewSoapIn\">
		<wsdl:part element=\"tns:GetBestMapView\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetBestMapViewSoapOut\">
		<wsdl:part element=\"tns:GetBestMapViewResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetBestMapViewCustomerInfoRenderHeader\">
		<wsdl:part element=\"tns:CustomerInfoRenderHeader\" name=\"CustomerInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetBestMapViewUserInfoRenderHeader\">
		<wsdl:part element=\"tns:UserInfoRenderHeader\" name=\"UserInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLineDriveMapSoapIn\">
		<wsdl:part element=\"tns:GetLineDriveMap\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLineDriveMapSoapOut\">
		<wsdl:part element=\"tns:GetLineDriveMapResponse\" name=\"parameters\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLineDriveMapCustomerInfoRenderHeader\">
		<wsdl:part element=\"tns:CustomerInfoRenderHeader\" name=\"CustomerInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:message name=\"GetLineDriveMapUserInfoRenderHeader\">
		<wsdl:part element=\"tns:UserInfoRenderHeader\" name=\"UserInfoRenderHeader\"/>
	</wsdl:message>
	<wsdl:portType name=\"RenderServiceSoap\">
		<wsdl:operation name=\"GetMap\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Renders map images of the given MapViews</documentation>
			<wsdl:input message=\"tns:GetMapSoapIn\"/>
			<wsdl:output message=\"tns:GetMapSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"ConvertToPoint\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Convert individual LatLongs into PixelCoords as they would appear in the given MapView</documentation>
			<wsdl:input message=\"tns:ConvertToPointSoapIn\"/>
			<wsdl:output message=\"tns:ConvertToPointSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"ConvertToLatLong\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Convert individual PixelCoords into LatLongs as they would appear in the given MapView</documentation>
			<wsdl:input message=\"tns:ConvertToLatLongSoapIn\"/>
			<wsdl:output message=\"tns:ConvertToLatLongSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetBestMapView\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Get a MapView that encompasses the given locations</documentation>
			<wsdl:input message=\"tns:GetBestMapViewSoapIn\"/>
			<wsdl:output message=\"tns:GetBestMapViewSoapOut\"/>
		</wsdl:operation>
		<wsdl:operation name=\"GetLineDriveMap\">
			<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">Renders LineDrive map images of the given Route</documentation>
			<wsdl:input message=\"tns:GetLineDriveMapSoapIn\"/>
			<wsdl:output message=\"tns:GetLineDriveMapSoapOut\"/>
		</wsdl:operation>
	</wsdl:portType>
	<wsdl:binding name=\"RenderServiceSoap\" type=\"tns:RenderServiceSoap\">
		<soap:binding style=\"document\" transport=\"http://schemas.xmlsoap.org/soap/http\"/>
		<wsdl:operation name=\"GetMap\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetMap\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetMapCustomerInfoRenderHeader\" part=\"CustomerInfoRenderHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetMapUserInfoRenderHeader\" part=\"UserInfoRenderHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"ConvertToPoint\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/ConvertToPoint\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:ConvertToPointCustomerInfoRenderHeader\" part=\"CustomerInfoRenderHeader\" use=\"literal\"/>
				<soap:header message=\"tns:ConvertToPointUserInfoRenderHeader\" part=\"UserInfoRenderHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"ConvertToLatLong\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/ConvertToLatLong\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:ConvertToLatLongCustomerInfoRenderHeader\" part=\"CustomerInfoRenderHeader\" use=\"literal\"/>
				<soap:header message=\"tns:ConvertToLatLongUserInfoRenderHeader\" part=\"UserInfoRenderHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetBestMapView\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetBestMapView\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetBestMapViewCustomerInfoRenderHeader\" part=\"CustomerInfoRenderHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetBestMapViewUserInfoRenderHeader\" part=\"UserInfoRenderHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
		<wsdl:operation name=\"GetLineDriveMap\">
			<soap:operation soapAction=\"http://s.mappoint.net/mappoint-30/GetLineDriveMap\" style=\"document\"/>
			<wsdl:input>
				<soap:body use=\"literal\"/>
				<soap:header message=\"tns:GetLineDriveMapCustomerInfoRenderHeader\" part=\"CustomerInfoRenderHeader\" use=\"literal\"/>
				<soap:header message=\"tns:GetLineDriveMapUserInfoRenderHeader\" part=\"UserInfoRenderHeader\" use=\"literal\"/>
			</wsdl:input>
			<wsdl:output>
				<soap:body use=\"literal\"/>
			</wsdl:output>
		</wsdl:operation>
	</wsdl:binding>
	<wsdl:service name=\"RenderService\">
		<documentation xmlns=\"http://schemas.xmlsoap.org/wsdl/\">The render service allows you to render maps of routes and found locations, place pushpins (using the MapPoint Web Service stock set of icons or your icons that we host for your use), set the map size and map view, select points on a map, get location information about points on a map, pan and zoom a rendered map, and create clickable maps.</documentation>
		<wsdl:port binding=\"tns:RenderServiceSoap\" name=\"RenderServiceSoap\">
			<soap:address location=\"http://renderv3.staging.mappoint.net/Render-30/RenderService.asmx\"/>
		</wsdl:port>
	</wsdl:service>
</wsdl:definitions>"""

    def __init__(self, post='/Find-30/Common.asmx', **kw):
        ServiceSOAPBinding.__init__(self, post)

    def soap_GetVersionInfo(self, ps):
        self.request = ps.Parse(GetVersionInfoSoapIn.typecode)
        return GetVersionInfoSoapOut()

    soapAction['http://s.mappoint.net/mappoint-30/GetVersionInfo'] = 'soap_GetVersionInfo'
    root[(GetVersionInfoSoapIn.typecode.nspname,GetVersionInfoSoapIn.typecode.pname)] = 'soap_GetVersionInfo'

    def soap_GetCountryRegionInfo(self, ps):
        self.request = ps.Parse(GetCountryRegionInfoSoapIn.typecode)
        return GetCountryRegionInfoSoapOut()

    soapAction['http://s.mappoint.net/mappoint-30/GetCountryRegionInfo'] = 'soap_GetCountryRegionInfo'
    root[(GetCountryRegionInfoSoapIn.typecode.nspname,GetCountryRegionInfoSoapIn.typecode.pname)] = 'soap_GetCountryRegionInfo'

    def soap_GetEntityTypes(self, ps):
        self.request = ps.Parse(GetEntityTypesSoapIn.typecode)
        return GetEntityTypesSoapOut()

    soapAction['http://s.mappoint.net/mappoint-30/GetEntityTypes'] = 'soap_GetEntityTypes'
    root[(GetEntityTypesSoapIn.typecode.nspname,GetEntityTypesSoapIn.typecode.pname)] = 'soap_GetEntityTypes'

    def soap_GetDataSourceInfo(self, ps):
        self.request = ps.Parse(GetDataSourceInfoSoapIn.typecode)
        return GetDataSourceInfoSoapOut()

    soapAction['http://s.mappoint.net/mappoint-30/GetDataSourceInfo'] = 'soap_GetDataSourceInfo'
    root[(GetDataSourceInfoSoapIn.typecode.nspname,GetDataSourceInfoSoapIn.typecode.pname)] = 'soap_GetDataSourceInfo'

    def soap_GetGreatCircleDistances(self, ps):
        self.request = ps.Parse(GetGreatCircleDistancesSoapIn.typecode)
        return GetGreatCircleDistancesSoapOut()

    soapAction['http://s.mappoint.net/mappoint-30/GetGreatCircleDistances'] = 'soap_GetGreatCircleDistances'
    root[(GetGreatCircleDistancesSoapIn.typecode.nspname,GetGreatCircleDistancesSoapIn.typecode.pname)] = 'soap_GetGreatCircleDistances'

